/********************************************************************************
** Form generated from reading UI file 'ColorBoxWidget.ui'
**
** Created by: Qt User Interface Compiler version 6.10.2
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_COLORBOXWIDGET_H
#define UI_COLORBOXWIDGET_H

#include <QtCore/QVariant>
#include <QtGui/QIcon>
#include <QtWidgets/QApplication>
#include <QtWidgets/QLabel>
#include <QtWidgets/QPushButton>
#include <QtWidgets/QStackedWidget>
#include <QtWidgets/QWidget>

QT_BEGIN_NAMESPACE

class Ui_ColorBoxWidget
{
public:
    QLabel *secondaryColorLabel;
    QLabel *primaryColorLabel;
    QPushButton *swapColorButton;
    QStackedWidget *stackedWidget;
    QWidget *page;
    QLabel *primaryColorLabel_27;
    QLabel *primaryColorLabel_21;
    QLabel *primaryColorLabel_38;
    QLabel *primaryColorLabel_40;
    QLabel *primaryColorLabel_16;
    QLabel *primaryColorLabel_12;
    QLabel *primaryColorLabel_35;
    QLabel *primaryColorLabel_9;
    QLabel *primaryColorLabel_22;
    QLabel *primaryColorLabel_13;
    QLabel *primaryColorLabel_36;
    QLabel *primaryColorLabel_37;
    QLabel *primaryColorLabel_33;
    QLabel *primaryColorLabel_3;
    QLabel *primaryColorLabel_39;
    QLabel *primaryColorLabel_34;
    QLabel *primaryColorLabel_10;
    QLabel *primaryColorLabel_7;
    QLabel *primaryColorLabel_18;
    QLabel *primaryColorLabel_25;
    QLabel *primaryColorLabel_28;
    QLabel *primaryColorLabel_29;
    QLabel *primaryColorLabel_2;
    QLabel *primaryColorLabel_23;
    QLabel *primaryColorLabel_19;
    QLabel *primaryColorLabel_5;
    QLabel *primaryColorLabel_31;
    QLabel *primaryColorLabel_20;
    QLabel *primaryColorLabel_24;
    QLabel *primaryColorLabel_32;
    QLabel *primaryColorLabel_17;
    QLabel *primaryColorLabel_6;
    QLabel *primaryColorLabel_41;
    QLabel *primaryColorLabel_30;
    QLabel *primaryColorLabel_14;
    QLabel *primaryColorLabel_15;
    QLabel *primaryColorLabel_11;
    QLabel *primaryColorLabel_26;
    QLabel *primaryColorLabel_4;
    QLabel *primaryColorLabel_8;
    QWidget *page_2;
    QLabel *spectrumLabel;
    QWidget *page_3;
    QLabel *bwGradientLabel;
    QPushButton *prevPage;
    QPushButton *nextPage;
    QPushButton *colourManageButton;

    void setupUi(QWidget *ColorBoxWidget)
    {
        if (ColorBoxWidget->objectName().isEmpty())
            ColorBoxWidget->setObjectName("ColorBoxWidget");
        ColorBoxWidget->resize(133, 177);
        QSizePolicy sizePolicy(QSizePolicy::Policy::Fixed, QSizePolicy::Policy::Fixed);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(ColorBoxWidget->sizePolicy().hasHeightForWidth());
        ColorBoxWidget->setSizePolicy(sizePolicy);
        ColorBoxWidget->setMinimumSize(QSize(80, 40));
        ColorBoxWidget->setMaximumSize(QSize(150, 250));
        secondaryColorLabel = new QLabel(ColorBoxWidget);
        secondaryColorLabel->setObjectName("secondaryColorLabel");
        secondaryColorLabel->setGeometry(QRect(30, 30, 32, 32));
        sizePolicy.setHeightForWidth(secondaryColorLabel->sizePolicy().hasHeightForWidth());
        secondaryColorLabel->setSizePolicy(sizePolicy);
        secondaryColorLabel->setMinimumSize(QSize(32, 32));
        secondaryColorLabel->setMaximumSize(QSize(32, 32));
        secondaryColorLabel->setAutoFillBackground(true);
        secondaryColorLabel->setFrameShape(QFrame::Box);
        secondaryColorLabel->setFrameShadow(QFrame::Raised);
        primaryColorLabel = new QLabel(ColorBoxWidget);
        primaryColorLabel->setObjectName("primaryColorLabel");
        primaryColorLabel->setGeometry(QRect(10, 10, 32, 32));
        QSizePolicy sizePolicy1(QSizePolicy::Policy::Preferred, QSizePolicy::Policy::Preferred);
        sizePolicy1.setHorizontalStretch(0);
        sizePolicy1.setVerticalStretch(0);
        sizePolicy1.setHeightForWidth(primaryColorLabel->sizePolicy().hasHeightForWidth());
        primaryColorLabel->setSizePolicy(sizePolicy1);
        primaryColorLabel->setMinimumSize(QSize(32, 32));
        primaryColorLabel->setMaximumSize(QSize(32, 32));
        primaryColorLabel->setAutoFillBackground(true);
        primaryColorLabel->setFrameShape(QFrame::Box);
        primaryColorLabel->setFrameShadow(QFrame::Raised);
        swapColorButton = new QPushButton(ColorBoxWidget);
        swapColorButton->setObjectName("swapColorButton");
        swapColorButton->setGeometry(QRect(40, 10, 24, 24));
        swapColorButton->setStyleSheet(QString::fromUtf8(""));
        QIcon icon;
        icon.addFile(QString::fromUtf8(":/toolpalette_icons/icons/swap.png"), QSize(), QIcon::Mode::Normal, QIcon::State::Off);
        swapColorButton->setIcon(icon);
        swapColorButton->setFlat(true);
        stackedWidget = new QStackedWidget(ColorBoxWidget);
        stackedWidget->setObjectName("stackedWidget");
        stackedWidget->setGeometry(QRect(-10, 60, 141, 91));
        stackedWidget->setFrameShape(QFrame::NoFrame);
        stackedWidget->setFrameShadow(QFrame::Plain);
        page = new QWidget();
        page->setObjectName("page");
        primaryColorLabel_27 = new QLabel(page);
        primaryColorLabel_27->setObjectName("primaryColorLabel_27");
        primaryColorLabel_27->setGeometry(QRect(26, 56, 15, 15));
        sizePolicy1.setHeightForWidth(primaryColorLabel_27->sizePolicy().hasHeightForWidth());
        primaryColorLabel_27->setSizePolicy(sizePolicy1);
        primaryColorLabel_27->setMinimumSize(QSize(15, 15));
        primaryColorLabel_27->setMaximumSize(QSize(5, 5));
        QPalette palette;
        QBrush brush(QColor(0, 0, 0, 255));
        brush.setStyle(Qt::BrushStyle::SolidPattern);
        palette.setBrush(QPalette::ColorGroup::Active, QPalette::ColorRole::WindowText, brush);
        QBrush brush1(QColor(255, 0, 0, 255));
        brush1.setStyle(Qt::BrushStyle::SolidPattern);
        palette.setBrush(QPalette::ColorGroup::Active, QPalette::ColorRole::Button, brush1);
        QBrush brush2(QColor(255, 127, 127, 255));
        brush2.setStyle(Qt::BrushStyle::SolidPattern);
        palette.setBrush(QPalette::ColorGroup::Active, QPalette::ColorRole::Light, brush2);
        QBrush brush3(QColor(255, 63, 63, 255));
        brush3.setStyle(Qt::BrushStyle::SolidPattern);
        palette.setBrush(QPalette::ColorGroup::Active, QPalette::ColorRole::Midlight, brush3);
        QBrush brush4(QColor(127, 0, 0, 255));
        brush4.setStyle(Qt::BrushStyle::SolidPattern);
        palette.setBrush(QPalette::ColorGroup::Active, QPalette::ColorRole::Dark, brush4);
        QBrush brush5(QColor(170, 0, 0, 255));
        brush5.setStyle(Qt::BrushStyle::SolidPattern);
        palette.setBrush(QPalette::ColorGroup::Active, QPalette::ColorRole::Mid, brush5);
        palette.setBrush(QPalette::ColorGroup::Active, QPalette::ColorRole::Text, brush);
        QBrush brush6(QColor(255, 255, 255, 255));
        brush6.setStyle(Qt::BrushStyle::SolidPattern);
        palette.setBrush(QPalette::ColorGroup::Active, QPalette::ColorRole::BrightText, brush6);
        palette.setBrush(QPalette::ColorGroup::Active, QPalette::ColorRole::ButtonText, brush);
        palette.setBrush(QPalette::ColorGroup::Active, QPalette::ColorRole::Base, brush6);
        palette.setBrush(QPalette::ColorGroup::Active, QPalette::ColorRole::Window, brush1);
        palette.setBrush(QPalette::ColorGroup::Active, QPalette::ColorRole::Shadow, brush);
        palette.setBrush(QPalette::ColorGroup::Active, QPalette::ColorRole::AlternateBase, brush2);
        QBrush brush7(QColor(255, 255, 220, 255));
        brush7.setStyle(Qt::BrushStyle::SolidPattern);
        palette.setBrush(QPalette::ColorGroup::Active, QPalette::ColorRole::ToolTipBase, brush7);
        palette.setBrush(QPalette::ColorGroup::Active, QPalette::ColorRole::ToolTipText, brush);
        palette.setBrush(QPalette::ColorGroup::Inactive, QPalette::ColorRole::WindowText, brush);
        palette.setBrush(QPalette::ColorGroup::Inactive, QPalette::ColorRole::Button, brush1);
        palette.setBrush(QPalette::ColorGroup::Inactive, QPalette::ColorRole::Light, brush2);
        palette.setBrush(QPalette::ColorGroup::Inactive, QPalette::ColorRole::Midlight, brush3);
        palette.setBrush(QPalette::ColorGroup::Inactive, QPalette::ColorRole::Dark, brush4);
        palette.setBrush(QPalette::ColorGroup::Inactive, QPalette::ColorRole::Mid, brush5);
        palette.setBrush(QPalette::ColorGroup::Inactive, QPalette::ColorRole::Text, brush);
        palette.setBrush(QPalette::ColorGroup::Inactive, QPalette::ColorRole::BrightText, brush6);
        palette.setBrush(QPalette::ColorGroup::Inactive, QPalette::ColorRole::ButtonText, brush);
        palette.setBrush(QPalette::ColorGroup::Inactive, QPalette::ColorRole::Base, brush6);
        palette.setBrush(QPalette::ColorGroup::Inactive, QPalette::ColorRole::Window, brush1);
        palette.setBrush(QPalette::ColorGroup::Inactive, QPalette::ColorRole::Shadow, brush);
        palette.setBrush(QPalette::ColorGroup::Inactive, QPalette::ColorRole::AlternateBase, brush2);
        palette.setBrush(QPalette::ColorGroup::Inactive, QPalette::ColorRole::ToolTipBase, brush7);
        palette.setBrush(QPalette::ColorGroup::Inactive, QPalette::ColorRole::ToolTipText, brush);
        palette.setBrush(QPalette::ColorGroup::Disabled, QPalette::ColorRole::WindowText, brush4);
        palette.setBrush(QPalette::ColorGroup::Disabled, QPalette::ColorRole::Button, brush1);
        palette.setBrush(QPalette::ColorGroup::Disabled, QPalette::ColorRole::Light, brush2);
        palette.setBrush(QPalette::ColorGroup::Disabled, QPalette::ColorRole::Midlight, brush3);
        palette.setBrush(QPalette::ColorGroup::Disabled, QPalette::ColorRole::Dark, brush4);
        palette.setBrush(QPalette::ColorGroup::Disabled, QPalette::ColorRole::Mid, brush5);
        palette.setBrush(QPalette::ColorGroup::Disabled, QPalette::ColorRole::Text, brush4);
        palette.setBrush(QPalette::ColorGroup::Disabled, QPalette::ColorRole::BrightText, brush6);
        palette.setBrush(QPalette::ColorGroup::Disabled, QPalette::ColorRole::ButtonText, brush4);
        palette.setBrush(QPalette::ColorGroup::Disabled, QPalette::ColorRole::Base, brush1);
        palette.setBrush(QPalette::ColorGroup::Disabled, QPalette::ColorRole::Window, brush1);
        palette.setBrush(QPalette::ColorGroup::Disabled, QPalette::ColorRole::Shadow, brush);
        palette.setBrush(QPalette::ColorGroup::Disabled, QPalette::ColorRole::AlternateBase, brush1);
        palette.setBrush(QPalette::ColorGroup::Disabled, QPalette::ColorRole::ToolTipBase, brush7);
        palette.setBrush(QPalette::ColorGroup::Disabled, QPalette::ColorRole::ToolTipText, brush);
        primaryColorLabel_27->setPalette(palette);
        primaryColorLabel_27->setAutoFillBackground(true);
        primaryColorLabel_27->setFrameShape(QFrame::Panel);
        primaryColorLabel_27->setFrameShadow(QFrame::Plain);
        primaryColorLabel_27->setLineWidth(0);
        primaryColorLabel_21 = new QLabel(page);
        primaryColorLabel_21->setObjectName("primaryColorLabel_21");
        primaryColorLabel_21->setGeometry(QRect(122, 40, 15, 15));
        sizePolicy1.setHeightForWidth(primaryColorLabel_21->sizePolicy().hasHeightForWidth());
        primaryColorLabel_21->setSizePolicy(sizePolicy1);
        primaryColorLabel_21->setMinimumSize(QSize(15, 15));
        primaryColorLabel_21->setMaximumSize(QSize(5, 5));
        QPalette palette1;
        palette1.setBrush(QPalette::ColorGroup::Active, QPalette::ColorRole::WindowText, brush);
        QBrush brush8(QColor(170, 255, 255, 255));
        brush8.setStyle(Qt::BrushStyle::SolidPattern);
        palette1.setBrush(QPalette::ColorGroup::Active, QPalette::ColorRole::Button, brush8);
        palette1.setBrush(QPalette::ColorGroup::Active, QPalette::ColorRole::Light, brush6);
        QBrush brush9(QColor(212, 255, 255, 255));
        brush9.setStyle(Qt::BrushStyle::SolidPattern);
        palette1.setBrush(QPalette::ColorGroup::Active, QPalette::ColorRole::Midlight, brush9);
        QBrush brush10(QColor(85, 127, 127, 255));
        brush10.setStyle(Qt::BrushStyle::SolidPattern);
        palette1.setBrush(QPalette::ColorGroup::Active, QPalette::ColorRole::Dark, brush10);
        QBrush brush11(QColor(113, 170, 170, 255));
        brush11.setStyle(Qt::BrushStyle::SolidPattern);
        palette1.setBrush(QPalette::ColorGroup::Active, QPalette::ColorRole::Mid, brush11);
        palette1.setBrush(QPalette::ColorGroup::Active, QPalette::ColorRole::Text, brush);
        palette1.setBrush(QPalette::ColorGroup::Active, QPalette::ColorRole::BrightText, brush6);
        palette1.setBrush(QPalette::ColorGroup::Active, QPalette::ColorRole::ButtonText, brush);
        palette1.setBrush(QPalette::ColorGroup::Active, QPalette::ColorRole::Base, brush6);
        palette1.setBrush(QPalette::ColorGroup::Active, QPalette::ColorRole::Window, brush8);
        palette1.setBrush(QPalette::ColorGroup::Active, QPalette::ColorRole::Shadow, brush);
        palette1.setBrush(QPalette::ColorGroup::Active, QPalette::ColorRole::AlternateBase, brush9);
        palette1.setBrush(QPalette::ColorGroup::Active, QPalette::ColorRole::ToolTipBase, brush7);
        palette1.setBrush(QPalette::ColorGroup::Active, QPalette::ColorRole::ToolTipText, brush);
        palette1.setBrush(QPalette::ColorGroup::Inactive, QPalette::ColorRole::WindowText, brush);
        palette1.setBrush(QPalette::ColorGroup::Inactive, QPalette::ColorRole::Button, brush8);
        palette1.setBrush(QPalette::ColorGroup::Inactive, QPalette::ColorRole::Light, brush6);
        palette1.setBrush(QPalette::ColorGroup::Inactive, QPalette::ColorRole::Midlight, brush9);
        palette1.setBrush(QPalette::ColorGroup::Inactive, QPalette::ColorRole::Dark, brush10);
        palette1.setBrush(QPalette::ColorGroup::Inactive, QPalette::ColorRole::Mid, brush11);
        palette1.setBrush(QPalette::ColorGroup::Inactive, QPalette::ColorRole::Text, brush);
        palette1.setBrush(QPalette::ColorGroup::Inactive, QPalette::ColorRole::BrightText, brush6);
        palette1.setBrush(QPalette::ColorGroup::Inactive, QPalette::ColorRole::ButtonText, brush);
        palette1.setBrush(QPalette::ColorGroup::Inactive, QPalette::ColorRole::Base, brush6);
        palette1.setBrush(QPalette::ColorGroup::Inactive, QPalette::ColorRole::Window, brush8);
        palette1.setBrush(QPalette::ColorGroup::Inactive, QPalette::ColorRole::Shadow, brush);
        palette1.setBrush(QPalette::ColorGroup::Inactive, QPalette::ColorRole::AlternateBase, brush9);
        palette1.setBrush(QPalette::ColorGroup::Inactive, QPalette::ColorRole::ToolTipBase, brush7);
        palette1.setBrush(QPalette::ColorGroup::Inactive, QPalette::ColorRole::ToolTipText, brush);
        palette1.setBrush(QPalette::ColorGroup::Disabled, QPalette::ColorRole::WindowText, brush10);
        palette1.setBrush(QPalette::ColorGroup::Disabled, QPalette::ColorRole::Button, brush8);
        palette1.setBrush(QPalette::ColorGroup::Disabled, QPalette::ColorRole::Light, brush6);
        palette1.setBrush(QPalette::ColorGroup::Disabled, QPalette::ColorRole::Midlight, brush9);
        palette1.setBrush(QPalette::ColorGroup::Disabled, QPalette::ColorRole::Dark, brush10);
        palette1.setBrush(QPalette::ColorGroup::Disabled, QPalette::ColorRole::Mid, brush11);
        palette1.setBrush(QPalette::ColorGroup::Disabled, QPalette::ColorRole::Text, brush10);
        palette1.setBrush(QPalette::ColorGroup::Disabled, QPalette::ColorRole::BrightText, brush6);
        palette1.setBrush(QPalette::ColorGroup::Disabled, QPalette::ColorRole::ButtonText, brush10);
        palette1.setBrush(QPalette::ColorGroup::Disabled, QPalette::ColorRole::Base, brush8);
        palette1.setBrush(QPalette::ColorGroup::Disabled, QPalette::ColorRole::Window, brush8);
        palette1.setBrush(QPalette::ColorGroup::Disabled, QPalette::ColorRole::Shadow, brush);
        palette1.setBrush(QPalette::ColorGroup::Disabled, QPalette::ColorRole::AlternateBase, brush8);
        palette1.setBrush(QPalette::ColorGroup::Disabled, QPalette::ColorRole::ToolTipBase, brush7);
        palette1.setBrush(QPalette::ColorGroup::Disabled, QPalette::ColorRole::ToolTipText, brush);
        primaryColorLabel_21->setPalette(palette1);
        primaryColorLabel_21->setAutoFillBackground(true);
        primaryColorLabel_21->setFrameShape(QFrame::Panel);
        primaryColorLabel_21->setFrameShadow(QFrame::Plain);
        primaryColorLabel_21->setLineWidth(0);
        primaryColorLabel_38 = new QLabel(page);
        primaryColorLabel_38->setObjectName("primaryColorLabel_38");
        primaryColorLabel_38->setGeometry(QRect(106, 72, 15, 15));
        sizePolicy1.setHeightForWidth(primaryColorLabel_38->sizePolicy().hasHeightForWidth());
        primaryColorLabel_38->setSizePolicy(sizePolicy1);
        primaryColorLabel_38->setMinimumSize(QSize(15, 15));
        primaryColorLabel_38->setMaximumSize(QSize(5, 5));
        QPalette palette2;
        palette2.setBrush(QPalette::ColorGroup::Active, QPalette::ColorRole::WindowText, brush);
        QBrush brush12(QColor(85, 255, 255, 255));
        brush12.setStyle(Qt::BrushStyle::SolidPattern);
        palette2.setBrush(QPalette::ColorGroup::Active, QPalette::ColorRole::Button, brush12);
        QBrush brush13(QColor(213, 255, 255, 255));
        brush13.setStyle(Qt::BrushStyle::SolidPattern);
        palette2.setBrush(QPalette::ColorGroup::Active, QPalette::ColorRole::Light, brush13);
        QBrush brush14(QColor(149, 255, 255, 255));
        brush14.setStyle(Qt::BrushStyle::SolidPattern);
        palette2.setBrush(QPalette::ColorGroup::Active, QPalette::ColorRole::Midlight, brush14);
        QBrush brush15(QColor(42, 127, 127, 255));
        brush15.setStyle(Qt::BrushStyle::SolidPattern);
        palette2.setBrush(QPalette::ColorGroup::Active, QPalette::ColorRole::Dark, brush15);
        QBrush brush16(QColor(56, 170, 170, 255));
        brush16.setStyle(Qt::BrushStyle::SolidPattern);
        palette2.setBrush(QPalette::ColorGroup::Active, QPalette::ColorRole::Mid, brush16);
        palette2.setBrush(QPalette::ColorGroup::Active, QPalette::ColorRole::Text, brush);
        palette2.setBrush(QPalette::ColorGroup::Active, QPalette::ColorRole::BrightText, brush6);
        palette2.setBrush(QPalette::ColorGroup::Active, QPalette::ColorRole::ButtonText, brush);
        palette2.setBrush(QPalette::ColorGroup::Active, QPalette::ColorRole::Base, brush6);
        palette2.setBrush(QPalette::ColorGroup::Active, QPalette::ColorRole::Window, brush12);
        palette2.setBrush(QPalette::ColorGroup::Active, QPalette::ColorRole::Shadow, brush);
        palette2.setBrush(QPalette::ColorGroup::Active, QPalette::ColorRole::AlternateBase, brush8);
        palette2.setBrush(QPalette::ColorGroup::Active, QPalette::ColorRole::ToolTipBase, brush7);
        palette2.setBrush(QPalette::ColorGroup::Active, QPalette::ColorRole::ToolTipText, brush);
        palette2.setBrush(QPalette::ColorGroup::Inactive, QPalette::ColorRole::WindowText, brush);
        palette2.setBrush(QPalette::ColorGroup::Inactive, QPalette::ColorRole::Button, brush12);
        palette2.setBrush(QPalette::ColorGroup::Inactive, QPalette::ColorRole::Light, brush13);
        palette2.setBrush(QPalette::ColorGroup::Inactive, QPalette::ColorRole::Midlight, brush14);
        palette2.setBrush(QPalette::ColorGroup::Inactive, QPalette::ColorRole::Dark, brush15);
        palette2.setBrush(QPalette::ColorGroup::Inactive, QPalette::ColorRole::Mid, brush16);
        palette2.setBrush(QPalette::ColorGroup::Inactive, QPalette::ColorRole::Text, brush);
        palette2.setBrush(QPalette::ColorGroup::Inactive, QPalette::ColorRole::BrightText, brush6);
        palette2.setBrush(QPalette::ColorGroup::Inactive, QPalette::ColorRole::ButtonText, brush);
        palette2.setBrush(QPalette::ColorGroup::Inactive, QPalette::ColorRole::Base, brush6);
        palette2.setBrush(QPalette::ColorGroup::Inactive, QPalette::ColorRole::Window, brush12);
        palette2.setBrush(QPalette::ColorGroup::Inactive, QPalette::ColorRole::Shadow, brush);
        palette2.setBrush(QPalette::ColorGroup::Inactive, QPalette::ColorRole::AlternateBase, brush8);
        palette2.setBrush(QPalette::ColorGroup::Inactive, QPalette::ColorRole::ToolTipBase, brush7);
        palette2.setBrush(QPalette::ColorGroup::Inactive, QPalette::ColorRole::ToolTipText, brush);
        palette2.setBrush(QPalette::ColorGroup::Disabled, QPalette::ColorRole::WindowText, brush15);
        palette2.setBrush(QPalette::ColorGroup::Disabled, QPalette::ColorRole::Button, brush12);
        palette2.setBrush(QPalette::ColorGroup::Disabled, QPalette::ColorRole::Light, brush13);
        palette2.setBrush(QPalette::ColorGroup::Disabled, QPalette::ColorRole::Midlight, brush14);
        palette2.setBrush(QPalette::ColorGroup::Disabled, QPalette::ColorRole::Dark, brush15);
        palette2.setBrush(QPalette::ColorGroup::Disabled, QPalette::ColorRole::Mid, brush16);
        palette2.setBrush(QPalette::ColorGroup::Disabled, QPalette::ColorRole::Text, brush15);
        palette2.setBrush(QPalette::ColorGroup::Disabled, QPalette::ColorRole::BrightText, brush6);
        palette2.setBrush(QPalette::ColorGroup::Disabled, QPalette::ColorRole::ButtonText, brush15);
        palette2.setBrush(QPalette::ColorGroup::Disabled, QPalette::ColorRole::Base, brush12);
        palette2.setBrush(QPalette::ColorGroup::Disabled, QPalette::ColorRole::Window, brush12);
        palette2.setBrush(QPalette::ColorGroup::Disabled, QPalette::ColorRole::Shadow, brush);
        palette2.setBrush(QPalette::ColorGroup::Disabled, QPalette::ColorRole::AlternateBase, brush12);
        palette2.setBrush(QPalette::ColorGroup::Disabled, QPalette::ColorRole::ToolTipBase, brush7);
        palette2.setBrush(QPalette::ColorGroup::Disabled, QPalette::ColorRole::ToolTipText, brush);
        primaryColorLabel_38->setPalette(palette2);
        primaryColorLabel_38->setAutoFillBackground(true);
        primaryColorLabel_38->setFrameShape(QFrame::Panel);
        primaryColorLabel_38->setFrameShadow(QFrame::Plain);
        primaryColorLabel_38->setLineWidth(0);
        primaryColorLabel_40 = new QLabel(page);
        primaryColorLabel_40->setObjectName("primaryColorLabel_40");
        primaryColorLabel_40->setGeometry(QRect(42, 72, 15, 15));
        sizePolicy1.setHeightForWidth(primaryColorLabel_40->sizePolicy().hasHeightForWidth());
        primaryColorLabel_40->setSizePolicy(sizePolicy1);
        primaryColorLabel_40->setMinimumSize(QSize(15, 15));
        primaryColorLabel_40->setMaximumSize(QSize(5, 5));
        QPalette palette3;
        palette3.setBrush(QPalette::ColorGroup::Active, QPalette::ColorRole::WindowText, brush);
        QBrush brush17(QColor(85, 85, 255, 255));
        brush17.setStyle(Qt::BrushStyle::SolidPattern);
        palette3.setBrush(QPalette::ColorGroup::Active, QPalette::ColorRole::Button, brush17);
        QBrush brush18(QColor(213, 213, 255, 255));
        brush18.setStyle(Qt::BrushStyle::SolidPattern);
        palette3.setBrush(QPalette::ColorGroup::Active, QPalette::ColorRole::Light, brush18);
        QBrush brush19(QColor(149, 149, 255, 255));
        brush19.setStyle(Qt::BrushStyle::SolidPattern);
        palette3.setBrush(QPalette::ColorGroup::Active, QPalette::ColorRole::Midlight, brush19);
        QBrush brush20(QColor(42, 42, 127, 255));
        brush20.setStyle(Qt::BrushStyle::SolidPattern);
        palette3.setBrush(QPalette::ColorGroup::Active, QPalette::ColorRole::Dark, brush20);
        QBrush brush21(QColor(56, 56, 170, 255));
        brush21.setStyle(Qt::BrushStyle::SolidPattern);
        palette3.setBrush(QPalette::ColorGroup::Active, QPalette::ColorRole::Mid, brush21);
        palette3.setBrush(QPalette::ColorGroup::Active, QPalette::ColorRole::Text, brush);
        palette3.setBrush(QPalette::ColorGroup::Active, QPalette::ColorRole::BrightText, brush6);
        palette3.setBrush(QPalette::ColorGroup::Active, QPalette::ColorRole::ButtonText, brush);
        palette3.setBrush(QPalette::ColorGroup::Active, QPalette::ColorRole::Base, brush6);
        palette3.setBrush(QPalette::ColorGroup::Active, QPalette::ColorRole::Window, brush17);
        palette3.setBrush(QPalette::ColorGroup::Active, QPalette::ColorRole::Shadow, brush);
        QBrush brush22(QColor(170, 170, 255, 255));
        brush22.setStyle(Qt::BrushStyle::SolidPattern);
        palette3.setBrush(QPalette::ColorGroup::Active, QPalette::ColorRole::AlternateBase, brush22);
        palette3.setBrush(QPalette::ColorGroup::Active, QPalette::ColorRole::ToolTipBase, brush7);
        palette3.setBrush(QPalette::ColorGroup::Active, QPalette::ColorRole::ToolTipText, brush);
        palette3.setBrush(QPalette::ColorGroup::Inactive, QPalette::ColorRole::WindowText, brush);
        palette3.setBrush(QPalette::ColorGroup::Inactive, QPalette::ColorRole::Button, brush17);
        palette3.setBrush(QPalette::ColorGroup::Inactive, QPalette::ColorRole::Light, brush18);
        palette3.setBrush(QPalette::ColorGroup::Inactive, QPalette::ColorRole::Midlight, brush19);
        palette3.setBrush(QPalette::ColorGroup::Inactive, QPalette::ColorRole::Dark, brush20);
        palette3.setBrush(QPalette::ColorGroup::Inactive, QPalette::ColorRole::Mid, brush21);
        palette3.setBrush(QPalette::ColorGroup::Inactive, QPalette::ColorRole::Text, brush);
        palette3.setBrush(QPalette::ColorGroup::Inactive, QPalette::ColorRole::BrightText, brush6);
        palette3.setBrush(QPalette::ColorGroup::Inactive, QPalette::ColorRole::ButtonText, brush);
        palette3.setBrush(QPalette::ColorGroup::Inactive, QPalette::ColorRole::Base, brush6);
        palette3.setBrush(QPalette::ColorGroup::Inactive, QPalette::ColorRole::Window, brush17);
        palette3.setBrush(QPalette::ColorGroup::Inactive, QPalette::ColorRole::Shadow, brush);
        palette3.setBrush(QPalette::ColorGroup::Inactive, QPalette::ColorRole::AlternateBase, brush22);
        palette3.setBrush(QPalette::ColorGroup::Inactive, QPalette::ColorRole::ToolTipBase, brush7);
        palette3.setBrush(QPalette::ColorGroup::Inactive, QPalette::ColorRole::ToolTipText, brush);
        palette3.setBrush(QPalette::ColorGroup::Disabled, QPalette::ColorRole::WindowText, brush20);
        palette3.setBrush(QPalette::ColorGroup::Disabled, QPalette::ColorRole::Button, brush17);
        palette3.setBrush(QPalette::ColorGroup::Disabled, QPalette::ColorRole::Light, brush18);
        palette3.setBrush(QPalette::ColorGroup::Disabled, QPalette::ColorRole::Midlight, brush19);
        palette3.setBrush(QPalette::ColorGroup::Disabled, QPalette::ColorRole::Dark, brush20);
        palette3.setBrush(QPalette::ColorGroup::Disabled, QPalette::ColorRole::Mid, brush21);
        palette3.setBrush(QPalette::ColorGroup::Disabled, QPalette::ColorRole::Text, brush20);
        palette3.setBrush(QPalette::ColorGroup::Disabled, QPalette::ColorRole::BrightText, brush6);
        palette3.setBrush(QPalette::ColorGroup::Disabled, QPalette::ColorRole::ButtonText, brush20);
        palette3.setBrush(QPalette::ColorGroup::Disabled, QPalette::ColorRole::Base, brush17);
        palette3.setBrush(QPalette::ColorGroup::Disabled, QPalette::ColorRole::Window, brush17);
        palette3.setBrush(QPalette::ColorGroup::Disabled, QPalette::ColorRole::Shadow, brush);
        palette3.setBrush(QPalette::ColorGroup::Disabled, QPalette::ColorRole::AlternateBase, brush17);
        palette3.setBrush(QPalette::ColorGroup::Disabled, QPalette::ColorRole::ToolTipBase, brush7);
        palette3.setBrush(QPalette::ColorGroup::Disabled, QPalette::ColorRole::ToolTipText, brush);
        primaryColorLabel_40->setPalette(palette3);
        primaryColorLabel_40->setAutoFillBackground(true);
        primaryColorLabel_40->setFrameShape(QFrame::Panel);
        primaryColorLabel_40->setFrameShadow(QFrame::Plain);
        primaryColorLabel_40->setLineWidth(0);
        primaryColorLabel_16 = new QLabel(page);
        primaryColorLabel_16->setObjectName("primaryColorLabel_16");
        primaryColorLabel_16->setGeometry(QRect(42, 24, 15, 15));
        sizePolicy1.setHeightForWidth(primaryColorLabel_16->sizePolicy().hasHeightForWidth());
        primaryColorLabel_16->setSizePolicy(sizePolicy1);
        primaryColorLabel_16->setMinimumSize(QSize(15, 15));
        primaryColorLabel_16->setMaximumSize(QSize(5, 5));
        QPalette palette4;
        palette4.setBrush(QPalette::ColorGroup::Active, QPalette::ColorRole::WindowText, brush6);
        QBrush brush23(QColor(0, 85, 127, 255));
        brush23.setStyle(Qt::BrushStyle::SolidPattern);
        palette4.setBrush(QPalette::ColorGroup::Active, QPalette::ColorRole::Button, brush23);
        QBrush brush24(QColor(0, 128, 191, 255));
        brush24.setStyle(Qt::BrushStyle::SolidPattern);
        palette4.setBrush(QPalette::ColorGroup::Active, QPalette::ColorRole::Light, brush24);
        QBrush brush25(QColor(0, 106, 159, 255));
        brush25.setStyle(Qt::BrushStyle::SolidPattern);
        palette4.setBrush(QPalette::ColorGroup::Active, QPalette::ColorRole::Midlight, brush25);
        QBrush brush26(QColor(0, 42, 63, 255));
        brush26.setStyle(Qt::BrushStyle::SolidPattern);
        palette4.setBrush(QPalette::ColorGroup::Active, QPalette::ColorRole::Dark, brush26);
        QBrush brush27(QColor(0, 56, 84, 255));
        brush27.setStyle(Qt::BrushStyle::SolidPattern);
        palette4.setBrush(QPalette::ColorGroup::Active, QPalette::ColorRole::Mid, brush27);
        palette4.setBrush(QPalette::ColorGroup::Active, QPalette::ColorRole::Text, brush6);
        palette4.setBrush(QPalette::ColorGroup::Active, QPalette::ColorRole::BrightText, brush6);
        palette4.setBrush(QPalette::ColorGroup::Active, QPalette::ColorRole::ButtonText, brush6);
        palette4.setBrush(QPalette::ColorGroup::Active, QPalette::ColorRole::Base, brush);
        palette4.setBrush(QPalette::ColorGroup::Active, QPalette::ColorRole::Window, brush23);
        palette4.setBrush(QPalette::ColorGroup::Active, QPalette::ColorRole::Shadow, brush);
        palette4.setBrush(QPalette::ColorGroup::Active, QPalette::ColorRole::AlternateBase, brush26);
        palette4.setBrush(QPalette::ColorGroup::Active, QPalette::ColorRole::ToolTipBase, brush7);
        palette4.setBrush(QPalette::ColorGroup::Active, QPalette::ColorRole::ToolTipText, brush);
        palette4.setBrush(QPalette::ColorGroup::Inactive, QPalette::ColorRole::WindowText, brush6);
        palette4.setBrush(QPalette::ColorGroup::Inactive, QPalette::ColorRole::Button, brush23);
        palette4.setBrush(QPalette::ColorGroup::Inactive, QPalette::ColorRole::Light, brush24);
        palette4.setBrush(QPalette::ColorGroup::Inactive, QPalette::ColorRole::Midlight, brush25);
        palette4.setBrush(QPalette::ColorGroup::Inactive, QPalette::ColorRole::Dark, brush26);
        palette4.setBrush(QPalette::ColorGroup::Inactive, QPalette::ColorRole::Mid, brush27);
        palette4.setBrush(QPalette::ColorGroup::Inactive, QPalette::ColorRole::Text, brush6);
        palette4.setBrush(QPalette::ColorGroup::Inactive, QPalette::ColorRole::BrightText, brush6);
        palette4.setBrush(QPalette::ColorGroup::Inactive, QPalette::ColorRole::ButtonText, brush6);
        palette4.setBrush(QPalette::ColorGroup::Inactive, QPalette::ColorRole::Base, brush);
        palette4.setBrush(QPalette::ColorGroup::Inactive, QPalette::ColorRole::Window, brush23);
        palette4.setBrush(QPalette::ColorGroup::Inactive, QPalette::ColorRole::Shadow, brush);
        palette4.setBrush(QPalette::ColorGroup::Inactive, QPalette::ColorRole::AlternateBase, brush26);
        palette4.setBrush(QPalette::ColorGroup::Inactive, QPalette::ColorRole::ToolTipBase, brush7);
        palette4.setBrush(QPalette::ColorGroup::Inactive, QPalette::ColorRole::ToolTipText, brush);
        palette4.setBrush(QPalette::ColorGroup::Disabled, QPalette::ColorRole::WindowText, brush26);
        palette4.setBrush(QPalette::ColorGroup::Disabled, QPalette::ColorRole::Button, brush23);
        palette4.setBrush(QPalette::ColorGroup::Disabled, QPalette::ColorRole::Light, brush24);
        palette4.setBrush(QPalette::ColorGroup::Disabled, QPalette::ColorRole::Midlight, brush25);
        palette4.setBrush(QPalette::ColorGroup::Disabled, QPalette::ColorRole::Dark, brush26);
        palette4.setBrush(QPalette::ColorGroup::Disabled, QPalette::ColorRole::Mid, brush27);
        palette4.setBrush(QPalette::ColorGroup::Disabled, QPalette::ColorRole::Text, brush26);
        palette4.setBrush(QPalette::ColorGroup::Disabled, QPalette::ColorRole::BrightText, brush6);
        palette4.setBrush(QPalette::ColorGroup::Disabled, QPalette::ColorRole::ButtonText, brush26);
        palette4.setBrush(QPalette::ColorGroup::Disabled, QPalette::ColorRole::Base, brush23);
        palette4.setBrush(QPalette::ColorGroup::Disabled, QPalette::ColorRole::Window, brush23);
        palette4.setBrush(QPalette::ColorGroup::Disabled, QPalette::ColorRole::Shadow, brush);
        palette4.setBrush(QPalette::ColorGroup::Disabled, QPalette::ColorRole::AlternateBase, brush23);
        palette4.setBrush(QPalette::ColorGroup::Disabled, QPalette::ColorRole::ToolTipBase, brush7);
        palette4.setBrush(QPalette::ColorGroup::Disabled, QPalette::ColorRole::ToolTipText, brush);
        primaryColorLabel_16->setPalette(palette4);
        primaryColorLabel_16->setAutoFillBackground(true);
        primaryColorLabel_16->setFrameShape(QFrame::Panel);
        primaryColorLabel_16->setFrameShadow(QFrame::Plain);
        primaryColorLabel_16->setLineWidth(0);
        primaryColorLabel_12 = new QLabel(page);
        primaryColorLabel_12->setObjectName("primaryColorLabel_12");
        primaryColorLabel_12->setGeometry(QRect(74, 24, 15, 15));
        sizePolicy1.setHeightForWidth(primaryColorLabel_12->sizePolicy().hasHeightForWidth());
        primaryColorLabel_12->setSizePolicy(sizePolicy1);
        primaryColorLabel_12->setMinimumSize(QSize(15, 15));
        primaryColorLabel_12->setMaximumSize(QSize(5, 5));
        QPalette palette5;
        palette5.setBrush(QPalette::ColorGroup::Active, QPalette::ColorRole::WindowText, brush);
        QBrush brush28(QColor(0, 170, 127, 255));
        brush28.setStyle(Qt::BrushStyle::SolidPattern);
        palette5.setBrush(QPalette::ColorGroup::Active, QPalette::ColorRole::Button, brush28);
        QBrush brush29(QColor(0, 255, 191, 255));
        brush29.setStyle(Qt::BrushStyle::SolidPattern);
        palette5.setBrush(QPalette::ColorGroup::Active, QPalette::ColorRole::Light, brush29);
        QBrush brush30(QColor(0, 212, 159, 255));
        brush30.setStyle(Qt::BrushStyle::SolidPattern);
        palette5.setBrush(QPalette::ColorGroup::Active, QPalette::ColorRole::Midlight, brush30);
        QBrush brush31(QColor(0, 85, 63, 255));
        brush31.setStyle(Qt::BrushStyle::SolidPattern);
        palette5.setBrush(QPalette::ColorGroup::Active, QPalette::ColorRole::Dark, brush31);
        QBrush brush32(QColor(0, 113, 84, 255));
        brush32.setStyle(Qt::BrushStyle::SolidPattern);
        palette5.setBrush(QPalette::ColorGroup::Active, QPalette::ColorRole::Mid, brush32);
        palette5.setBrush(QPalette::ColorGroup::Active, QPalette::ColorRole::Text, brush);
        palette5.setBrush(QPalette::ColorGroup::Active, QPalette::ColorRole::BrightText, brush6);
        palette5.setBrush(QPalette::ColorGroup::Active, QPalette::ColorRole::ButtonText, brush);
        palette5.setBrush(QPalette::ColorGroup::Active, QPalette::ColorRole::Base, brush6);
        palette5.setBrush(QPalette::ColorGroup::Active, QPalette::ColorRole::Window, brush28);
        palette5.setBrush(QPalette::ColorGroup::Active, QPalette::ColorRole::Shadow, brush);
        QBrush brush33(QColor(127, 212, 191, 255));
        brush33.setStyle(Qt::BrushStyle::SolidPattern);
        palette5.setBrush(QPalette::ColorGroup::Active, QPalette::ColorRole::AlternateBase, brush33);
        palette5.setBrush(QPalette::ColorGroup::Active, QPalette::ColorRole::ToolTipBase, brush7);
        palette5.setBrush(QPalette::ColorGroup::Active, QPalette::ColorRole::ToolTipText, brush);
        palette5.setBrush(QPalette::ColorGroup::Inactive, QPalette::ColorRole::WindowText, brush);
        palette5.setBrush(QPalette::ColorGroup::Inactive, QPalette::ColorRole::Button, brush28);
        palette5.setBrush(QPalette::ColorGroup::Inactive, QPalette::ColorRole::Light, brush29);
        palette5.setBrush(QPalette::ColorGroup::Inactive, QPalette::ColorRole::Midlight, brush30);
        palette5.setBrush(QPalette::ColorGroup::Inactive, QPalette::ColorRole::Dark, brush31);
        palette5.setBrush(QPalette::ColorGroup::Inactive, QPalette::ColorRole::Mid, brush32);
        palette5.setBrush(QPalette::ColorGroup::Inactive, QPalette::ColorRole::Text, brush);
        palette5.setBrush(QPalette::ColorGroup::Inactive, QPalette::ColorRole::BrightText, brush6);
        palette5.setBrush(QPalette::ColorGroup::Inactive, QPalette::ColorRole::ButtonText, brush);
        palette5.setBrush(QPalette::ColorGroup::Inactive, QPalette::ColorRole::Base, brush6);
        palette5.setBrush(QPalette::ColorGroup::Inactive, QPalette::ColorRole::Window, brush28);
        palette5.setBrush(QPalette::ColorGroup::Inactive, QPalette::ColorRole::Shadow, brush);
        palette5.setBrush(QPalette::ColorGroup::Inactive, QPalette::ColorRole::AlternateBase, brush33);
        palette5.setBrush(QPalette::ColorGroup::Inactive, QPalette::ColorRole::ToolTipBase, brush7);
        palette5.setBrush(QPalette::ColorGroup::Inactive, QPalette::ColorRole::ToolTipText, brush);
        palette5.setBrush(QPalette::ColorGroup::Disabled, QPalette::ColorRole::WindowText, brush31);
        palette5.setBrush(QPalette::ColorGroup::Disabled, QPalette::ColorRole::Button, brush28);
        palette5.setBrush(QPalette::ColorGroup::Disabled, QPalette::ColorRole::Light, brush29);
        palette5.setBrush(QPalette::ColorGroup::Disabled, QPalette::ColorRole::Midlight, brush30);
        palette5.setBrush(QPalette::ColorGroup::Disabled, QPalette::ColorRole::Dark, brush31);
        palette5.setBrush(QPalette::ColorGroup::Disabled, QPalette::ColorRole::Mid, brush32);
        palette5.setBrush(QPalette::ColorGroup::Disabled, QPalette::ColorRole::Text, brush31);
        palette5.setBrush(QPalette::ColorGroup::Disabled, QPalette::ColorRole::BrightText, brush6);
        palette5.setBrush(QPalette::ColorGroup::Disabled, QPalette::ColorRole::ButtonText, brush31);
        palette5.setBrush(QPalette::ColorGroup::Disabled, QPalette::ColorRole::Base, brush28);
        palette5.setBrush(QPalette::ColorGroup::Disabled, QPalette::ColorRole::Window, brush28);
        palette5.setBrush(QPalette::ColorGroup::Disabled, QPalette::ColorRole::Shadow, brush);
        palette5.setBrush(QPalette::ColorGroup::Disabled, QPalette::ColorRole::AlternateBase, brush28);
        palette5.setBrush(QPalette::ColorGroup::Disabled, QPalette::ColorRole::ToolTipBase, brush7);
        palette5.setBrush(QPalette::ColorGroup::Disabled, QPalette::ColorRole::ToolTipText, brush);
        primaryColorLabel_12->setPalette(palette5);
        primaryColorLabel_12->setAutoFillBackground(true);
        primaryColorLabel_12->setFrameShape(QFrame::Panel);
        primaryColorLabel_12->setFrameShadow(QFrame::Plain);
        primaryColorLabel_12->setLineWidth(0);
        primaryColorLabel_35 = new QLabel(page);
        primaryColorLabel_35->setObjectName("primaryColorLabel_35");
        primaryColorLabel_35->setGeometry(QRect(26, 72, 15, 15));
        sizePolicy1.setHeightForWidth(primaryColorLabel_35->sizePolicy().hasHeightForWidth());
        primaryColorLabel_35->setSizePolicy(sizePolicy1);
        primaryColorLabel_35->setMinimumSize(QSize(15, 15));
        primaryColorLabel_35->setMaximumSize(QSize(5, 5));
        QPalette palette6;
        palette6.setBrush(QPalette::ColorGroup::Active, QPalette::ColorRole::WindowText, brush);
        QBrush brush34(QColor(255, 0, 255, 255));
        brush34.setStyle(Qt::BrushStyle::SolidPattern);
        palette6.setBrush(QPalette::ColorGroup::Active, QPalette::ColorRole::Button, brush34);
        QBrush brush35(QColor(255, 127, 255, 255));
        brush35.setStyle(Qt::BrushStyle::SolidPattern);
        palette6.setBrush(QPalette::ColorGroup::Active, QPalette::ColorRole::Light, brush35);
        QBrush brush36(QColor(255, 63, 255, 255));
        brush36.setStyle(Qt::BrushStyle::SolidPattern);
        palette6.setBrush(QPalette::ColorGroup::Active, QPalette::ColorRole::Midlight, brush36);
        QBrush brush37(QColor(127, 0, 127, 255));
        brush37.setStyle(Qt::BrushStyle::SolidPattern);
        palette6.setBrush(QPalette::ColorGroup::Active, QPalette::ColorRole::Dark, brush37);
        QBrush brush38(QColor(170, 0, 170, 255));
        brush38.setStyle(Qt::BrushStyle::SolidPattern);
        palette6.setBrush(QPalette::ColorGroup::Active, QPalette::ColorRole::Mid, brush38);
        palette6.setBrush(QPalette::ColorGroup::Active, QPalette::ColorRole::Text, brush);
        palette6.setBrush(QPalette::ColorGroup::Active, QPalette::ColorRole::BrightText, brush6);
        palette6.setBrush(QPalette::ColorGroup::Active, QPalette::ColorRole::ButtonText, brush);
        palette6.setBrush(QPalette::ColorGroup::Active, QPalette::ColorRole::Base, brush6);
        palette6.setBrush(QPalette::ColorGroup::Active, QPalette::ColorRole::Window, brush34);
        palette6.setBrush(QPalette::ColorGroup::Active, QPalette::ColorRole::Shadow, brush);
        palette6.setBrush(QPalette::ColorGroup::Active, QPalette::ColorRole::AlternateBase, brush35);
        palette6.setBrush(QPalette::ColorGroup::Active, QPalette::ColorRole::ToolTipBase, brush7);
        palette6.setBrush(QPalette::ColorGroup::Active, QPalette::ColorRole::ToolTipText, brush);
        palette6.setBrush(QPalette::ColorGroup::Inactive, QPalette::ColorRole::WindowText, brush);
        palette6.setBrush(QPalette::ColorGroup::Inactive, QPalette::ColorRole::Button, brush34);
        palette6.setBrush(QPalette::ColorGroup::Inactive, QPalette::ColorRole::Light, brush35);
        palette6.setBrush(QPalette::ColorGroup::Inactive, QPalette::ColorRole::Midlight, brush36);
        palette6.setBrush(QPalette::ColorGroup::Inactive, QPalette::ColorRole::Dark, brush37);
        palette6.setBrush(QPalette::ColorGroup::Inactive, QPalette::ColorRole::Mid, brush38);
        palette6.setBrush(QPalette::ColorGroup::Inactive, QPalette::ColorRole::Text, brush);
        palette6.setBrush(QPalette::ColorGroup::Inactive, QPalette::ColorRole::BrightText, brush6);
        palette6.setBrush(QPalette::ColorGroup::Inactive, QPalette::ColorRole::ButtonText, brush);
        palette6.setBrush(QPalette::ColorGroup::Inactive, QPalette::ColorRole::Base, brush6);
        palette6.setBrush(QPalette::ColorGroup::Inactive, QPalette::ColorRole::Window, brush34);
        palette6.setBrush(QPalette::ColorGroup::Inactive, QPalette::ColorRole::Shadow, brush);
        palette6.setBrush(QPalette::ColorGroup::Inactive, QPalette::ColorRole::AlternateBase, brush35);
        palette6.setBrush(QPalette::ColorGroup::Inactive, QPalette::ColorRole::ToolTipBase, brush7);
        palette6.setBrush(QPalette::ColorGroup::Inactive, QPalette::ColorRole::ToolTipText, brush);
        palette6.setBrush(QPalette::ColorGroup::Disabled, QPalette::ColorRole::WindowText, brush37);
        palette6.setBrush(QPalette::ColorGroup::Disabled, QPalette::ColorRole::Button, brush34);
        palette6.setBrush(QPalette::ColorGroup::Disabled, QPalette::ColorRole::Light, brush35);
        palette6.setBrush(QPalette::ColorGroup::Disabled, QPalette::ColorRole::Midlight, brush36);
        palette6.setBrush(QPalette::ColorGroup::Disabled, QPalette::ColorRole::Dark, brush37);
        palette6.setBrush(QPalette::ColorGroup::Disabled, QPalette::ColorRole::Mid, brush38);
        palette6.setBrush(QPalette::ColorGroup::Disabled, QPalette::ColorRole::Text, brush37);
        palette6.setBrush(QPalette::ColorGroup::Disabled, QPalette::ColorRole::BrightText, brush6);
        palette6.setBrush(QPalette::ColorGroup::Disabled, QPalette::ColorRole::ButtonText, brush37);
        palette6.setBrush(QPalette::ColorGroup::Disabled, QPalette::ColorRole::Base, brush34);
        palette6.setBrush(QPalette::ColorGroup::Disabled, QPalette::ColorRole::Window, brush34);
        palette6.setBrush(QPalette::ColorGroup::Disabled, QPalette::ColorRole::Shadow, brush);
        palette6.setBrush(QPalette::ColorGroup::Disabled, QPalette::ColorRole::AlternateBase, brush34);
        palette6.setBrush(QPalette::ColorGroup::Disabled, QPalette::ColorRole::ToolTipBase, brush7);
        palette6.setBrush(QPalette::ColorGroup::Disabled, QPalette::ColorRole::ToolTipText, brush);
        primaryColorLabel_35->setPalette(palette6);
        primaryColorLabel_35->setAutoFillBackground(true);
        primaryColorLabel_35->setFrameShape(QFrame::Panel);
        primaryColorLabel_35->setFrameShadow(QFrame::Plain);
        primaryColorLabel_35->setLineWidth(0);
        primaryColorLabel_9 = new QLabel(page);
        primaryColorLabel_9->setObjectName("primaryColorLabel_9");
        primaryColorLabel_9->setGeometry(QRect(106, 8, 15, 15));
        sizePolicy1.setHeightForWidth(primaryColorLabel_9->sizePolicy().hasHeightForWidth());
        primaryColorLabel_9->setSizePolicy(sizePolicy1);
        primaryColorLabel_9->setMinimumSize(QSize(15, 15));
        primaryColorLabel_9->setMaximumSize(QSize(5, 5));
        QPalette palette7;
        palette7.setBrush(QPalette::ColorGroup::Active, QPalette::ColorRole::WindowText, brush);
        QBrush brush39(QColor(0, 255, 0, 255));
        brush39.setStyle(Qt::BrushStyle::SolidPattern);
        palette7.setBrush(QPalette::ColorGroup::Active, QPalette::ColorRole::Button, brush39);
        QBrush brush40(QColor(127, 255, 127, 255));
        brush40.setStyle(Qt::BrushStyle::SolidPattern);
        palette7.setBrush(QPalette::ColorGroup::Active, QPalette::ColorRole::Light, brush40);
        QBrush brush41(QColor(63, 255, 63, 255));
        brush41.setStyle(Qt::BrushStyle::SolidPattern);
        palette7.setBrush(QPalette::ColorGroup::Active, QPalette::ColorRole::Midlight, brush41);
        QBrush brush42(QColor(0, 127, 0, 255));
        brush42.setStyle(Qt::BrushStyle::SolidPattern);
        palette7.setBrush(QPalette::ColorGroup::Active, QPalette::ColorRole::Dark, brush42);
        QBrush brush43(QColor(0, 170, 0, 255));
        brush43.setStyle(Qt::BrushStyle::SolidPattern);
        palette7.setBrush(QPalette::ColorGroup::Active, QPalette::ColorRole::Mid, brush43);
        palette7.setBrush(QPalette::ColorGroup::Active, QPalette::ColorRole::Text, brush);
        palette7.setBrush(QPalette::ColorGroup::Active, QPalette::ColorRole::BrightText, brush6);
        palette7.setBrush(QPalette::ColorGroup::Active, QPalette::ColorRole::ButtonText, brush);
        palette7.setBrush(QPalette::ColorGroup::Active, QPalette::ColorRole::Base, brush6);
        palette7.setBrush(QPalette::ColorGroup::Active, QPalette::ColorRole::Window, brush39);
        palette7.setBrush(QPalette::ColorGroup::Active, QPalette::ColorRole::Shadow, brush);
        palette7.setBrush(QPalette::ColorGroup::Active, QPalette::ColorRole::AlternateBase, brush40);
        palette7.setBrush(QPalette::ColorGroup::Active, QPalette::ColorRole::ToolTipBase, brush7);
        palette7.setBrush(QPalette::ColorGroup::Active, QPalette::ColorRole::ToolTipText, brush);
        palette7.setBrush(QPalette::ColorGroup::Inactive, QPalette::ColorRole::WindowText, brush);
        palette7.setBrush(QPalette::ColorGroup::Inactive, QPalette::ColorRole::Button, brush39);
        palette7.setBrush(QPalette::ColorGroup::Inactive, QPalette::ColorRole::Light, brush40);
        palette7.setBrush(QPalette::ColorGroup::Inactive, QPalette::ColorRole::Midlight, brush41);
        palette7.setBrush(QPalette::ColorGroup::Inactive, QPalette::ColorRole::Dark, brush42);
        palette7.setBrush(QPalette::ColorGroup::Inactive, QPalette::ColorRole::Mid, brush43);
        palette7.setBrush(QPalette::ColorGroup::Inactive, QPalette::ColorRole::Text, brush);
        palette7.setBrush(QPalette::ColorGroup::Inactive, QPalette::ColorRole::BrightText, brush6);
        palette7.setBrush(QPalette::ColorGroup::Inactive, QPalette::ColorRole::ButtonText, brush);
        palette7.setBrush(QPalette::ColorGroup::Inactive, QPalette::ColorRole::Base, brush6);
        palette7.setBrush(QPalette::ColorGroup::Inactive, QPalette::ColorRole::Window, brush39);
        palette7.setBrush(QPalette::ColorGroup::Inactive, QPalette::ColorRole::Shadow, brush);
        palette7.setBrush(QPalette::ColorGroup::Inactive, QPalette::ColorRole::AlternateBase, brush40);
        palette7.setBrush(QPalette::ColorGroup::Inactive, QPalette::ColorRole::ToolTipBase, brush7);
        palette7.setBrush(QPalette::ColorGroup::Inactive, QPalette::ColorRole::ToolTipText, brush);
        palette7.setBrush(QPalette::ColorGroup::Disabled, QPalette::ColorRole::WindowText, brush42);
        palette7.setBrush(QPalette::ColorGroup::Disabled, QPalette::ColorRole::Button, brush39);
        palette7.setBrush(QPalette::ColorGroup::Disabled, QPalette::ColorRole::Light, brush40);
        palette7.setBrush(QPalette::ColorGroup::Disabled, QPalette::ColorRole::Midlight, brush41);
        palette7.setBrush(QPalette::ColorGroup::Disabled, QPalette::ColorRole::Dark, brush42);
        palette7.setBrush(QPalette::ColorGroup::Disabled, QPalette::ColorRole::Mid, brush43);
        palette7.setBrush(QPalette::ColorGroup::Disabled, QPalette::ColorRole::Text, brush42);
        palette7.setBrush(QPalette::ColorGroup::Disabled, QPalette::ColorRole::BrightText, brush6);
        palette7.setBrush(QPalette::ColorGroup::Disabled, QPalette::ColorRole::ButtonText, brush42);
        palette7.setBrush(QPalette::ColorGroup::Disabled, QPalette::ColorRole::Base, brush39);
        palette7.setBrush(QPalette::ColorGroup::Disabled, QPalette::ColorRole::Window, brush39);
        palette7.setBrush(QPalette::ColorGroup::Disabled, QPalette::ColorRole::Shadow, brush);
        palette7.setBrush(QPalette::ColorGroup::Disabled, QPalette::ColorRole::AlternateBase, brush39);
        palette7.setBrush(QPalette::ColorGroup::Disabled, QPalette::ColorRole::ToolTipBase, brush7);
        palette7.setBrush(QPalette::ColorGroup::Disabled, QPalette::ColorRole::ToolTipText, brush);
        primaryColorLabel_9->setPalette(palette7);
        primaryColorLabel_9->setAutoFillBackground(true);
        primaryColorLabel_9->setFrameShape(QFrame::Panel);
        primaryColorLabel_9->setFrameShadow(QFrame::Plain);
        primaryColorLabel_9->setLineWidth(0);
        primaryColorLabel_22 = new QLabel(page);
        primaryColorLabel_22->setObjectName("primaryColorLabel_22");
        primaryColorLabel_22->setGeometry(QRect(106, 40, 15, 15));
        sizePolicy1.setHeightForWidth(primaryColorLabel_22->sizePolicy().hasHeightForWidth());
        primaryColorLabel_22->setSizePolicy(sizePolicy1);
        primaryColorLabel_22->setMinimumSize(QSize(15, 15));
        primaryColorLabel_22->setMaximumSize(QSize(5, 5));
        QPalette palette8;
        palette8.setBrush(QPalette::ColorGroup::Active, QPalette::ColorRole::WindowText, brush);
        QBrush brush44(QColor(0, 255, 255, 255));
        brush44.setStyle(Qt::BrushStyle::SolidPattern);
        palette8.setBrush(QPalette::ColorGroup::Active, QPalette::ColorRole::Button, brush44);
        QBrush brush45(QColor(127, 255, 255, 255));
        brush45.setStyle(Qt::BrushStyle::SolidPattern);
        palette8.setBrush(QPalette::ColorGroup::Active, QPalette::ColorRole::Light, brush45);
        QBrush brush46(QColor(63, 255, 255, 255));
        brush46.setStyle(Qt::BrushStyle::SolidPattern);
        palette8.setBrush(QPalette::ColorGroup::Active, QPalette::ColorRole::Midlight, brush46);
        QBrush brush47(QColor(0, 127, 127, 255));
        brush47.setStyle(Qt::BrushStyle::SolidPattern);
        palette8.setBrush(QPalette::ColorGroup::Active, QPalette::ColorRole::Dark, brush47);
        QBrush brush48(QColor(0, 170, 170, 255));
        brush48.setStyle(Qt::BrushStyle::SolidPattern);
        palette8.setBrush(QPalette::ColorGroup::Active, QPalette::ColorRole::Mid, brush48);
        palette8.setBrush(QPalette::ColorGroup::Active, QPalette::ColorRole::Text, brush);
        palette8.setBrush(QPalette::ColorGroup::Active, QPalette::ColorRole::BrightText, brush6);
        palette8.setBrush(QPalette::ColorGroup::Active, QPalette::ColorRole::ButtonText, brush);
        palette8.setBrush(QPalette::ColorGroup::Active, QPalette::ColorRole::Base, brush6);
        palette8.setBrush(QPalette::ColorGroup::Active, QPalette::ColorRole::Window, brush44);
        palette8.setBrush(QPalette::ColorGroup::Active, QPalette::ColorRole::Shadow, brush);
        palette8.setBrush(QPalette::ColorGroup::Active, QPalette::ColorRole::AlternateBase, brush45);
        palette8.setBrush(QPalette::ColorGroup::Active, QPalette::ColorRole::ToolTipBase, brush7);
        palette8.setBrush(QPalette::ColorGroup::Active, QPalette::ColorRole::ToolTipText, brush);
        palette8.setBrush(QPalette::ColorGroup::Inactive, QPalette::ColorRole::WindowText, brush);
        palette8.setBrush(QPalette::ColorGroup::Inactive, QPalette::ColorRole::Button, brush44);
        palette8.setBrush(QPalette::ColorGroup::Inactive, QPalette::ColorRole::Light, brush45);
        palette8.setBrush(QPalette::ColorGroup::Inactive, QPalette::ColorRole::Midlight, brush46);
        palette8.setBrush(QPalette::ColorGroup::Inactive, QPalette::ColorRole::Dark, brush47);
        palette8.setBrush(QPalette::ColorGroup::Inactive, QPalette::ColorRole::Mid, brush48);
        palette8.setBrush(QPalette::ColorGroup::Inactive, QPalette::ColorRole::Text, brush);
        palette8.setBrush(QPalette::ColorGroup::Inactive, QPalette::ColorRole::BrightText, brush6);
        palette8.setBrush(QPalette::ColorGroup::Inactive, QPalette::ColorRole::ButtonText, brush);
        palette8.setBrush(QPalette::ColorGroup::Inactive, QPalette::ColorRole::Base, brush6);
        palette8.setBrush(QPalette::ColorGroup::Inactive, QPalette::ColorRole::Window, brush44);
        palette8.setBrush(QPalette::ColorGroup::Inactive, QPalette::ColorRole::Shadow, brush);
        palette8.setBrush(QPalette::ColorGroup::Inactive, QPalette::ColorRole::AlternateBase, brush45);
        palette8.setBrush(QPalette::ColorGroup::Inactive, QPalette::ColorRole::ToolTipBase, brush7);
        palette8.setBrush(QPalette::ColorGroup::Inactive, QPalette::ColorRole::ToolTipText, brush);
        palette8.setBrush(QPalette::ColorGroup::Disabled, QPalette::ColorRole::WindowText, brush47);
        palette8.setBrush(QPalette::ColorGroup::Disabled, QPalette::ColorRole::Button, brush44);
        palette8.setBrush(QPalette::ColorGroup::Disabled, QPalette::ColorRole::Light, brush45);
        palette8.setBrush(QPalette::ColorGroup::Disabled, QPalette::ColorRole::Midlight, brush46);
        palette8.setBrush(QPalette::ColorGroup::Disabled, QPalette::ColorRole::Dark, brush47);
        palette8.setBrush(QPalette::ColorGroup::Disabled, QPalette::ColorRole::Mid, brush48);
        palette8.setBrush(QPalette::ColorGroup::Disabled, QPalette::ColorRole::Text, brush47);
        palette8.setBrush(QPalette::ColorGroup::Disabled, QPalette::ColorRole::BrightText, brush6);
        palette8.setBrush(QPalette::ColorGroup::Disabled, QPalette::ColorRole::ButtonText, brush47);
        palette8.setBrush(QPalette::ColorGroup::Disabled, QPalette::ColorRole::Base, brush44);
        palette8.setBrush(QPalette::ColorGroup::Disabled, QPalette::ColorRole::Window, brush44);
        palette8.setBrush(QPalette::ColorGroup::Disabled, QPalette::ColorRole::Shadow, brush);
        palette8.setBrush(QPalette::ColorGroup::Disabled, QPalette::ColorRole::AlternateBase, brush44);
        palette8.setBrush(QPalette::ColorGroup::Disabled, QPalette::ColorRole::ToolTipBase, brush7);
        palette8.setBrush(QPalette::ColorGroup::Disabled, QPalette::ColorRole::ToolTipText, brush);
        primaryColorLabel_22->setPalette(palette8);
        primaryColorLabel_22->setAutoFillBackground(true);
        primaryColorLabel_22->setFrameShape(QFrame::Panel);
        primaryColorLabel_22->setFrameShadow(QFrame::Plain);
        primaryColorLabel_22->setLineWidth(0);
        primaryColorLabel_13 = new QLabel(page);
        primaryColorLabel_13->setObjectName("primaryColorLabel_13");
        primaryColorLabel_13->setGeometry(QRect(122, 24, 15, 15));
        sizePolicy1.setHeightForWidth(primaryColorLabel_13->sizePolicy().hasHeightForWidth());
        primaryColorLabel_13->setSizePolicy(sizePolicy1);
        primaryColorLabel_13->setMinimumSize(QSize(15, 15));
        primaryColorLabel_13->setMaximumSize(QSize(5, 5));
        QPalette palette9;
        palette9.setBrush(QPalette::ColorGroup::Active, QPalette::ColorRole::WindowText, brush);
        QBrush brush49(QColor(170, 255, 127, 255));
        brush49.setStyle(Qt::BrushStyle::SolidPattern);
        palette9.setBrush(QPalette::ColorGroup::Active, QPalette::ColorRole::Button, brush49);
        palette9.setBrush(QPalette::ColorGroup::Active, QPalette::ColorRole::Light, brush6);
        QBrush brush50(QColor(212, 255, 191, 255));
        brush50.setStyle(Qt::BrushStyle::SolidPattern);
        palette9.setBrush(QPalette::ColorGroup::Active, QPalette::ColorRole::Midlight, brush50);
        QBrush brush51(QColor(85, 127, 63, 255));
        brush51.setStyle(Qt::BrushStyle::SolidPattern);
        palette9.setBrush(QPalette::ColorGroup::Active, QPalette::ColorRole::Dark, brush51);
        QBrush brush52(QColor(113, 170, 84, 255));
        brush52.setStyle(Qt::BrushStyle::SolidPattern);
        palette9.setBrush(QPalette::ColorGroup::Active, QPalette::ColorRole::Mid, brush52);
        palette9.setBrush(QPalette::ColorGroup::Active, QPalette::ColorRole::Text, brush);
        palette9.setBrush(QPalette::ColorGroup::Active, QPalette::ColorRole::BrightText, brush6);
        palette9.setBrush(QPalette::ColorGroup::Active, QPalette::ColorRole::ButtonText, brush);
        palette9.setBrush(QPalette::ColorGroup::Active, QPalette::ColorRole::Base, brush6);
        palette9.setBrush(QPalette::ColorGroup::Active, QPalette::ColorRole::Window, brush49);
        palette9.setBrush(QPalette::ColorGroup::Active, QPalette::ColorRole::Shadow, brush);
        palette9.setBrush(QPalette::ColorGroup::Active, QPalette::ColorRole::AlternateBase, brush50);
        palette9.setBrush(QPalette::ColorGroup::Active, QPalette::ColorRole::ToolTipBase, brush7);
        palette9.setBrush(QPalette::ColorGroup::Active, QPalette::ColorRole::ToolTipText, brush);
        palette9.setBrush(QPalette::ColorGroup::Inactive, QPalette::ColorRole::WindowText, brush);
        palette9.setBrush(QPalette::ColorGroup::Inactive, QPalette::ColorRole::Button, brush49);
        palette9.setBrush(QPalette::ColorGroup::Inactive, QPalette::ColorRole::Light, brush6);
        palette9.setBrush(QPalette::ColorGroup::Inactive, QPalette::ColorRole::Midlight, brush50);
        palette9.setBrush(QPalette::ColorGroup::Inactive, QPalette::ColorRole::Dark, brush51);
        palette9.setBrush(QPalette::ColorGroup::Inactive, QPalette::ColorRole::Mid, brush52);
        palette9.setBrush(QPalette::ColorGroup::Inactive, QPalette::ColorRole::Text, brush);
        palette9.setBrush(QPalette::ColorGroup::Inactive, QPalette::ColorRole::BrightText, brush6);
        palette9.setBrush(QPalette::ColorGroup::Inactive, QPalette::ColorRole::ButtonText, brush);
        palette9.setBrush(QPalette::ColorGroup::Inactive, QPalette::ColorRole::Base, brush6);
        palette9.setBrush(QPalette::ColorGroup::Inactive, QPalette::ColorRole::Window, brush49);
        palette9.setBrush(QPalette::ColorGroup::Inactive, QPalette::ColorRole::Shadow, brush);
        palette9.setBrush(QPalette::ColorGroup::Inactive, QPalette::ColorRole::AlternateBase, brush50);
        palette9.setBrush(QPalette::ColorGroup::Inactive, QPalette::ColorRole::ToolTipBase, brush7);
        palette9.setBrush(QPalette::ColorGroup::Inactive, QPalette::ColorRole::ToolTipText, brush);
        palette9.setBrush(QPalette::ColorGroup::Disabled, QPalette::ColorRole::WindowText, brush51);
        palette9.setBrush(QPalette::ColorGroup::Disabled, QPalette::ColorRole::Button, brush49);
        palette9.setBrush(QPalette::ColorGroup::Disabled, QPalette::ColorRole::Light, brush6);
        palette9.setBrush(QPalette::ColorGroup::Disabled, QPalette::ColorRole::Midlight, brush50);
        palette9.setBrush(QPalette::ColorGroup::Disabled, QPalette::ColorRole::Dark, brush51);
        palette9.setBrush(QPalette::ColorGroup::Disabled, QPalette::ColorRole::Mid, brush52);
        palette9.setBrush(QPalette::ColorGroup::Disabled, QPalette::ColorRole::Text, brush51);
        palette9.setBrush(QPalette::ColorGroup::Disabled, QPalette::ColorRole::BrightText, brush6);
        palette9.setBrush(QPalette::ColorGroup::Disabled, QPalette::ColorRole::ButtonText, brush51);
        palette9.setBrush(QPalette::ColorGroup::Disabled, QPalette::ColorRole::Base, brush49);
        palette9.setBrush(QPalette::ColorGroup::Disabled, QPalette::ColorRole::Window, brush49);
        palette9.setBrush(QPalette::ColorGroup::Disabled, QPalette::ColorRole::Shadow, brush);
        palette9.setBrush(QPalette::ColorGroup::Disabled, QPalette::ColorRole::AlternateBase, brush49);
        palette9.setBrush(QPalette::ColorGroup::Disabled, QPalette::ColorRole::ToolTipBase, brush7);
        palette9.setBrush(QPalette::ColorGroup::Disabled, QPalette::ColorRole::ToolTipText, brush);
        primaryColorLabel_13->setPalette(palette9);
        primaryColorLabel_13->setAutoFillBackground(true);
        primaryColorLabel_13->setFrameShape(QFrame::Panel);
        primaryColorLabel_13->setFrameShadow(QFrame::Plain);
        primaryColorLabel_13->setLineWidth(0);
        primaryColorLabel_36 = new QLabel(page);
        primaryColorLabel_36->setObjectName("primaryColorLabel_36");
        primaryColorLabel_36->setGeometry(QRect(74, 72, 15, 15));
        sizePolicy1.setHeightForWidth(primaryColorLabel_36->sizePolicy().hasHeightForWidth());
        primaryColorLabel_36->setSizePolicy(sizePolicy1);
        primaryColorLabel_36->setMinimumSize(QSize(15, 15));
        primaryColorLabel_36->setMaximumSize(QSize(5, 5));
        QPalette palette10;
        palette10.setBrush(QPalette::ColorGroup::Active, QPalette::ColorRole::WindowText, brush);
        QBrush brush53(QColor(85, 170, 255, 255));
        brush53.setStyle(Qt::BrushStyle::SolidPattern);
        palette10.setBrush(QPalette::ColorGroup::Active, QPalette::ColorRole::Button, brush53);
        QBrush brush54(QColor(213, 234, 255, 255));
        brush54.setStyle(Qt::BrushStyle::SolidPattern);
        palette10.setBrush(QPalette::ColorGroup::Active, QPalette::ColorRole::Light, brush54);
        QBrush brush55(QColor(149, 202, 255, 255));
        brush55.setStyle(Qt::BrushStyle::SolidPattern);
        palette10.setBrush(QPalette::ColorGroup::Active, QPalette::ColorRole::Midlight, brush55);
        QBrush brush56(QColor(42, 85, 127, 255));
        brush56.setStyle(Qt::BrushStyle::SolidPattern);
        palette10.setBrush(QPalette::ColorGroup::Active, QPalette::ColorRole::Dark, brush56);
        QBrush brush57(QColor(56, 113, 170, 255));
        brush57.setStyle(Qt::BrushStyle::SolidPattern);
        palette10.setBrush(QPalette::ColorGroup::Active, QPalette::ColorRole::Mid, brush57);
        palette10.setBrush(QPalette::ColorGroup::Active, QPalette::ColorRole::Text, brush);
        palette10.setBrush(QPalette::ColorGroup::Active, QPalette::ColorRole::BrightText, brush6);
        palette10.setBrush(QPalette::ColorGroup::Active, QPalette::ColorRole::ButtonText, brush);
        palette10.setBrush(QPalette::ColorGroup::Active, QPalette::ColorRole::Base, brush6);
        palette10.setBrush(QPalette::ColorGroup::Active, QPalette::ColorRole::Window, brush53);
        palette10.setBrush(QPalette::ColorGroup::Active, QPalette::ColorRole::Shadow, brush);
        QBrush brush58(QColor(170, 212, 255, 255));
        brush58.setStyle(Qt::BrushStyle::SolidPattern);
        palette10.setBrush(QPalette::ColorGroup::Active, QPalette::ColorRole::AlternateBase, brush58);
        palette10.setBrush(QPalette::ColorGroup::Active, QPalette::ColorRole::ToolTipBase, brush7);
        palette10.setBrush(QPalette::ColorGroup::Active, QPalette::ColorRole::ToolTipText, brush);
        palette10.setBrush(QPalette::ColorGroup::Inactive, QPalette::ColorRole::WindowText, brush);
        palette10.setBrush(QPalette::ColorGroup::Inactive, QPalette::ColorRole::Button, brush53);
        palette10.setBrush(QPalette::ColorGroup::Inactive, QPalette::ColorRole::Light, brush54);
        palette10.setBrush(QPalette::ColorGroup::Inactive, QPalette::ColorRole::Midlight, brush55);
        palette10.setBrush(QPalette::ColorGroup::Inactive, QPalette::ColorRole::Dark, brush56);
        palette10.setBrush(QPalette::ColorGroup::Inactive, QPalette::ColorRole::Mid, brush57);
        palette10.setBrush(QPalette::ColorGroup::Inactive, QPalette::ColorRole::Text, brush);
        palette10.setBrush(QPalette::ColorGroup::Inactive, QPalette::ColorRole::BrightText, brush6);
        palette10.setBrush(QPalette::ColorGroup::Inactive, QPalette::ColorRole::ButtonText, brush);
        palette10.setBrush(QPalette::ColorGroup::Inactive, QPalette::ColorRole::Base, brush6);
        palette10.setBrush(QPalette::ColorGroup::Inactive, QPalette::ColorRole::Window, brush53);
        palette10.setBrush(QPalette::ColorGroup::Inactive, QPalette::ColorRole::Shadow, brush);
        palette10.setBrush(QPalette::ColorGroup::Inactive, QPalette::ColorRole::AlternateBase, brush58);
        palette10.setBrush(QPalette::ColorGroup::Inactive, QPalette::ColorRole::ToolTipBase, brush7);
        palette10.setBrush(QPalette::ColorGroup::Inactive, QPalette::ColorRole::ToolTipText, brush);
        palette10.setBrush(QPalette::ColorGroup::Disabled, QPalette::ColorRole::WindowText, brush56);
        palette10.setBrush(QPalette::ColorGroup::Disabled, QPalette::ColorRole::Button, brush53);
        palette10.setBrush(QPalette::ColorGroup::Disabled, QPalette::ColorRole::Light, brush54);
        palette10.setBrush(QPalette::ColorGroup::Disabled, QPalette::ColorRole::Midlight, brush55);
        palette10.setBrush(QPalette::ColorGroup::Disabled, QPalette::ColorRole::Dark, brush56);
        palette10.setBrush(QPalette::ColorGroup::Disabled, QPalette::ColorRole::Mid, brush57);
        palette10.setBrush(QPalette::ColorGroup::Disabled, QPalette::ColorRole::Text, brush56);
        palette10.setBrush(QPalette::ColorGroup::Disabled, QPalette::ColorRole::BrightText, brush6);
        palette10.setBrush(QPalette::ColorGroup::Disabled, QPalette::ColorRole::ButtonText, brush56);
        palette10.setBrush(QPalette::ColorGroup::Disabled, QPalette::ColorRole::Base, brush53);
        palette10.setBrush(QPalette::ColorGroup::Disabled, QPalette::ColorRole::Window, brush53);
        palette10.setBrush(QPalette::ColorGroup::Disabled, QPalette::ColorRole::Shadow, brush);
        palette10.setBrush(QPalette::ColorGroup::Disabled, QPalette::ColorRole::AlternateBase, brush53);
        palette10.setBrush(QPalette::ColorGroup::Disabled, QPalette::ColorRole::ToolTipBase, brush7);
        palette10.setBrush(QPalette::ColorGroup::Disabled, QPalette::ColorRole::ToolTipText, brush);
        primaryColorLabel_36->setPalette(palette10);
        primaryColorLabel_36->setAutoFillBackground(true);
        primaryColorLabel_36->setFrameShape(QFrame::Panel);
        primaryColorLabel_36->setFrameShadow(QFrame::Plain);
        primaryColorLabel_36->setLineWidth(0);
        primaryColorLabel_37 = new QLabel(page);
        primaryColorLabel_37->setObjectName("primaryColorLabel_37");
        primaryColorLabel_37->setGeometry(QRect(122, 72, 15, 15));
        sizePolicy1.setHeightForWidth(primaryColorLabel_37->sizePolicy().hasHeightForWidth());
        primaryColorLabel_37->setSizePolicy(sizePolicy1);
        primaryColorLabel_37->setMinimumSize(QSize(15, 15));
        primaryColorLabel_37->setMaximumSize(QSize(5, 5));
        QPalette palette11;
        palette11.setBrush(QPalette::ColorGroup::Active, QPalette::ColorRole::WindowText, brush);
        palette11.setBrush(QPalette::ColorGroup::Active, QPalette::ColorRole::Button, brush6);
        palette11.setBrush(QPalette::ColorGroup::Active, QPalette::ColorRole::Light, brush6);
        palette11.setBrush(QPalette::ColorGroup::Active, QPalette::ColorRole::Midlight, brush6);
        QBrush brush59(QColor(127, 127, 127, 255));
        brush59.setStyle(Qt::BrushStyle::SolidPattern);
        palette11.setBrush(QPalette::ColorGroup::Active, QPalette::ColorRole::Dark, brush59);
        QBrush brush60(QColor(170, 170, 170, 255));
        brush60.setStyle(Qt::BrushStyle::SolidPattern);
        palette11.setBrush(QPalette::ColorGroup::Active, QPalette::ColorRole::Mid, brush60);
        palette11.setBrush(QPalette::ColorGroup::Active, QPalette::ColorRole::Text, brush);
        palette11.setBrush(QPalette::ColorGroup::Active, QPalette::ColorRole::BrightText, brush6);
        palette11.setBrush(QPalette::ColorGroup::Active, QPalette::ColorRole::ButtonText, brush);
        palette11.setBrush(QPalette::ColorGroup::Active, QPalette::ColorRole::Base, brush6);
        palette11.setBrush(QPalette::ColorGroup::Active, QPalette::ColorRole::Window, brush6);
        palette11.setBrush(QPalette::ColorGroup::Active, QPalette::ColorRole::Shadow, brush);
        palette11.setBrush(QPalette::ColorGroup::Active, QPalette::ColorRole::AlternateBase, brush6);
        palette11.setBrush(QPalette::ColorGroup::Active, QPalette::ColorRole::ToolTipBase, brush7);
        palette11.setBrush(QPalette::ColorGroup::Active, QPalette::ColorRole::ToolTipText, brush);
        palette11.setBrush(QPalette::ColorGroup::Inactive, QPalette::ColorRole::WindowText, brush);
        palette11.setBrush(QPalette::ColorGroup::Inactive, QPalette::ColorRole::Button, brush6);
        palette11.setBrush(QPalette::ColorGroup::Inactive, QPalette::ColorRole::Light, brush6);
        palette11.setBrush(QPalette::ColorGroup::Inactive, QPalette::ColorRole::Midlight, brush6);
        palette11.setBrush(QPalette::ColorGroup::Inactive, QPalette::ColorRole::Dark, brush59);
        palette11.setBrush(QPalette::ColorGroup::Inactive, QPalette::ColorRole::Mid, brush60);
        palette11.setBrush(QPalette::ColorGroup::Inactive, QPalette::ColorRole::Text, brush);
        palette11.setBrush(QPalette::ColorGroup::Inactive, QPalette::ColorRole::BrightText, brush6);
        palette11.setBrush(QPalette::ColorGroup::Inactive, QPalette::ColorRole::ButtonText, brush);
        palette11.setBrush(QPalette::ColorGroup::Inactive, QPalette::ColorRole::Base, brush6);
        palette11.setBrush(QPalette::ColorGroup::Inactive, QPalette::ColorRole::Window, brush6);
        palette11.setBrush(QPalette::ColorGroup::Inactive, QPalette::ColorRole::Shadow, brush);
        palette11.setBrush(QPalette::ColorGroup::Inactive, QPalette::ColorRole::AlternateBase, brush6);
        palette11.setBrush(QPalette::ColorGroup::Inactive, QPalette::ColorRole::ToolTipBase, brush7);
        palette11.setBrush(QPalette::ColorGroup::Inactive, QPalette::ColorRole::ToolTipText, brush);
        palette11.setBrush(QPalette::ColorGroup::Disabled, QPalette::ColorRole::WindowText, brush59);
        palette11.setBrush(QPalette::ColorGroup::Disabled, QPalette::ColorRole::Button, brush6);
        palette11.setBrush(QPalette::ColorGroup::Disabled, QPalette::ColorRole::Light, brush6);
        palette11.setBrush(QPalette::ColorGroup::Disabled, QPalette::ColorRole::Midlight, brush6);
        palette11.setBrush(QPalette::ColorGroup::Disabled, QPalette::ColorRole::Dark, brush59);
        palette11.setBrush(QPalette::ColorGroup::Disabled, QPalette::ColorRole::Mid, brush60);
        palette11.setBrush(QPalette::ColorGroup::Disabled, QPalette::ColorRole::Text, brush59);
        palette11.setBrush(QPalette::ColorGroup::Disabled, QPalette::ColorRole::BrightText, brush6);
        palette11.setBrush(QPalette::ColorGroup::Disabled, QPalette::ColorRole::ButtonText, brush59);
        palette11.setBrush(QPalette::ColorGroup::Disabled, QPalette::ColorRole::Base, brush6);
        palette11.setBrush(QPalette::ColorGroup::Disabled, QPalette::ColorRole::Window, brush6);
        palette11.setBrush(QPalette::ColorGroup::Disabled, QPalette::ColorRole::Shadow, brush);
        palette11.setBrush(QPalette::ColorGroup::Disabled, QPalette::ColorRole::AlternateBase, brush6);
        palette11.setBrush(QPalette::ColorGroup::Disabled, QPalette::ColorRole::ToolTipBase, brush7);
        palette11.setBrush(QPalette::ColorGroup::Disabled, QPalette::ColorRole::ToolTipText, brush);
        primaryColorLabel_37->setPalette(palette11);
        primaryColorLabel_37->setAutoFillBackground(true);
        primaryColorLabel_37->setFrameShape(QFrame::Panel);
        primaryColorLabel_37->setFrameShadow(QFrame::Plain);
        primaryColorLabel_37->setLineWidth(0);
        primaryColorLabel_33 = new QLabel(page);
        primaryColorLabel_33->setObjectName("primaryColorLabel_33");
        primaryColorLabel_33->setGeometry(QRect(90, 56, 15, 15));
        sizePolicy1.setHeightForWidth(primaryColorLabel_33->sizePolicy().hasHeightForWidth());
        primaryColorLabel_33->setSizePolicy(sizePolicy1);
        primaryColorLabel_33->setMinimumSize(QSize(15, 15));
        primaryColorLabel_33->setMaximumSize(QSize(5, 5));
        QPalette palette12;
        palette12.setBrush(QPalette::ColorGroup::Active, QPalette::ColorRole::WindowText, brush);
        QBrush brush61(QColor(255, 170, 0, 255));
        brush61.setStyle(Qt::BrushStyle::SolidPattern);
        palette12.setBrush(QPalette::ColorGroup::Active, QPalette::ColorRole::Button, brush61);
        QBrush brush62(QColor(255, 213, 127, 255));
        brush62.setStyle(Qt::BrushStyle::SolidPattern);
        palette12.setBrush(QPalette::ColorGroup::Active, QPalette::ColorRole::Light, brush62);
        QBrush brush63(QColor(255, 191, 63, 255));
        brush63.setStyle(Qt::BrushStyle::SolidPattern);
        palette12.setBrush(QPalette::ColorGroup::Active, QPalette::ColorRole::Midlight, brush63);
        QBrush brush64(QColor(127, 85, 0, 255));
        brush64.setStyle(Qt::BrushStyle::SolidPattern);
        palette12.setBrush(QPalette::ColorGroup::Active, QPalette::ColorRole::Dark, brush64);
        QBrush brush65(QColor(170, 113, 0, 255));
        brush65.setStyle(Qt::BrushStyle::SolidPattern);
        palette12.setBrush(QPalette::ColorGroup::Active, QPalette::ColorRole::Mid, brush65);
        palette12.setBrush(QPalette::ColorGroup::Active, QPalette::ColorRole::Text, brush);
        palette12.setBrush(QPalette::ColorGroup::Active, QPalette::ColorRole::BrightText, brush6);
        palette12.setBrush(QPalette::ColorGroup::Active, QPalette::ColorRole::ButtonText, brush);
        palette12.setBrush(QPalette::ColorGroup::Active, QPalette::ColorRole::Base, brush6);
        palette12.setBrush(QPalette::ColorGroup::Active, QPalette::ColorRole::Window, brush61);
        palette12.setBrush(QPalette::ColorGroup::Active, QPalette::ColorRole::Shadow, brush);
        QBrush brush66(QColor(255, 212, 127, 255));
        brush66.setStyle(Qt::BrushStyle::SolidPattern);
        palette12.setBrush(QPalette::ColorGroup::Active, QPalette::ColorRole::AlternateBase, brush66);
        palette12.setBrush(QPalette::ColorGroup::Active, QPalette::ColorRole::ToolTipBase, brush7);
        palette12.setBrush(QPalette::ColorGroup::Active, QPalette::ColorRole::ToolTipText, brush);
        palette12.setBrush(QPalette::ColorGroup::Inactive, QPalette::ColorRole::WindowText, brush);
        palette12.setBrush(QPalette::ColorGroup::Inactive, QPalette::ColorRole::Button, brush61);
        palette12.setBrush(QPalette::ColorGroup::Inactive, QPalette::ColorRole::Light, brush62);
        palette12.setBrush(QPalette::ColorGroup::Inactive, QPalette::ColorRole::Midlight, brush63);
        palette12.setBrush(QPalette::ColorGroup::Inactive, QPalette::ColorRole::Dark, brush64);
        palette12.setBrush(QPalette::ColorGroup::Inactive, QPalette::ColorRole::Mid, brush65);
        palette12.setBrush(QPalette::ColorGroup::Inactive, QPalette::ColorRole::Text, brush);
        palette12.setBrush(QPalette::ColorGroup::Inactive, QPalette::ColorRole::BrightText, brush6);
        palette12.setBrush(QPalette::ColorGroup::Inactive, QPalette::ColorRole::ButtonText, brush);
        palette12.setBrush(QPalette::ColorGroup::Inactive, QPalette::ColorRole::Base, brush6);
        palette12.setBrush(QPalette::ColorGroup::Inactive, QPalette::ColorRole::Window, brush61);
        palette12.setBrush(QPalette::ColorGroup::Inactive, QPalette::ColorRole::Shadow, brush);
        palette12.setBrush(QPalette::ColorGroup::Inactive, QPalette::ColorRole::AlternateBase, brush66);
        palette12.setBrush(QPalette::ColorGroup::Inactive, QPalette::ColorRole::ToolTipBase, brush7);
        palette12.setBrush(QPalette::ColorGroup::Inactive, QPalette::ColorRole::ToolTipText, brush);
        palette12.setBrush(QPalette::ColorGroup::Disabled, QPalette::ColorRole::WindowText, brush64);
        palette12.setBrush(QPalette::ColorGroup::Disabled, QPalette::ColorRole::Button, brush61);
        palette12.setBrush(QPalette::ColorGroup::Disabled, QPalette::ColorRole::Light, brush62);
        palette12.setBrush(QPalette::ColorGroup::Disabled, QPalette::ColorRole::Midlight, brush63);
        palette12.setBrush(QPalette::ColorGroup::Disabled, QPalette::ColorRole::Dark, brush64);
        palette12.setBrush(QPalette::ColorGroup::Disabled, QPalette::ColorRole::Mid, brush65);
        palette12.setBrush(QPalette::ColorGroup::Disabled, QPalette::ColorRole::Text, brush64);
        palette12.setBrush(QPalette::ColorGroup::Disabled, QPalette::ColorRole::BrightText, brush6);
        palette12.setBrush(QPalette::ColorGroup::Disabled, QPalette::ColorRole::ButtonText, brush64);
        palette12.setBrush(QPalette::ColorGroup::Disabled, QPalette::ColorRole::Base, brush61);
        palette12.setBrush(QPalette::ColorGroup::Disabled, QPalette::ColorRole::Window, brush61);
        palette12.setBrush(QPalette::ColorGroup::Disabled, QPalette::ColorRole::Shadow, brush);
        palette12.setBrush(QPalette::ColorGroup::Disabled, QPalette::ColorRole::AlternateBase, brush61);
        palette12.setBrush(QPalette::ColorGroup::Disabled, QPalette::ColorRole::ToolTipBase, brush7);
        palette12.setBrush(QPalette::ColorGroup::Disabled, QPalette::ColorRole::ToolTipText, brush);
        primaryColorLabel_33->setPalette(palette12);
        primaryColorLabel_33->setAutoFillBackground(true);
        primaryColorLabel_33->setFrameShape(QFrame::Panel);
        primaryColorLabel_33->setFrameShadow(QFrame::Plain);
        primaryColorLabel_33->setLineWidth(0);
        primaryColorLabel_3 = new QLabel(page);
        primaryColorLabel_3->setObjectName("primaryColorLabel_3");
        primaryColorLabel_3->setGeometry(QRect(26, 8, 15, 15));
        sizePolicy1.setHeightForWidth(primaryColorLabel_3->sizePolicy().hasHeightForWidth());
        primaryColorLabel_3->setSizePolicy(sizePolicy1);
        primaryColorLabel_3->setMinimumSize(QSize(15, 15));
        primaryColorLabel_3->setMaximumSize(QSize(5, 5));
        QPalette palette13;
        palette13.setBrush(QPalette::ColorGroup::Active, QPalette::ColorRole::WindowText, brush);
        palette13.setBrush(QPalette::ColorGroup::Active, QPalette::ColorRole::Button, brush5);
        palette13.setBrush(QPalette::ColorGroup::Active, QPalette::ColorRole::Light, brush1);
        QBrush brush67(QColor(212, 0, 0, 255));
        brush67.setStyle(Qt::BrushStyle::SolidPattern);
        palette13.setBrush(QPalette::ColorGroup::Active, QPalette::ColorRole::Midlight, brush67);
        QBrush brush68(QColor(85, 0, 0, 255));
        brush68.setStyle(Qt::BrushStyle::SolidPattern);
        palette13.setBrush(QPalette::ColorGroup::Active, QPalette::ColorRole::Dark, brush68);
        QBrush brush69(QColor(113, 0, 0, 255));
        brush69.setStyle(Qt::BrushStyle::SolidPattern);
        palette13.setBrush(QPalette::ColorGroup::Active, QPalette::ColorRole::Mid, brush69);
        palette13.setBrush(QPalette::ColorGroup::Active, QPalette::ColorRole::Text, brush);
        palette13.setBrush(QPalette::ColorGroup::Active, QPalette::ColorRole::BrightText, brush6);
        palette13.setBrush(QPalette::ColorGroup::Active, QPalette::ColorRole::ButtonText, brush);
        palette13.setBrush(QPalette::ColorGroup::Active, QPalette::ColorRole::Base, brush6);
        palette13.setBrush(QPalette::ColorGroup::Active, QPalette::ColorRole::Window, brush5);
        palette13.setBrush(QPalette::ColorGroup::Active, QPalette::ColorRole::Shadow, brush);
        QBrush brush70(QColor(212, 127, 127, 255));
        brush70.setStyle(Qt::BrushStyle::SolidPattern);
        palette13.setBrush(QPalette::ColorGroup::Active, QPalette::ColorRole::AlternateBase, brush70);
        palette13.setBrush(QPalette::ColorGroup::Active, QPalette::ColorRole::ToolTipBase, brush7);
        palette13.setBrush(QPalette::ColorGroup::Active, QPalette::ColorRole::ToolTipText, brush);
        palette13.setBrush(QPalette::ColorGroup::Inactive, QPalette::ColorRole::WindowText, brush);
        palette13.setBrush(QPalette::ColorGroup::Inactive, QPalette::ColorRole::Button, brush5);
        palette13.setBrush(QPalette::ColorGroup::Inactive, QPalette::ColorRole::Light, brush1);
        palette13.setBrush(QPalette::ColorGroup::Inactive, QPalette::ColorRole::Midlight, brush67);
        palette13.setBrush(QPalette::ColorGroup::Inactive, QPalette::ColorRole::Dark, brush68);
        palette13.setBrush(QPalette::ColorGroup::Inactive, QPalette::ColorRole::Mid, brush69);
        palette13.setBrush(QPalette::ColorGroup::Inactive, QPalette::ColorRole::Text, brush);
        palette13.setBrush(QPalette::ColorGroup::Inactive, QPalette::ColorRole::BrightText, brush6);
        palette13.setBrush(QPalette::ColorGroup::Inactive, QPalette::ColorRole::ButtonText, brush);
        palette13.setBrush(QPalette::ColorGroup::Inactive, QPalette::ColorRole::Base, brush6);
        palette13.setBrush(QPalette::ColorGroup::Inactive, QPalette::ColorRole::Window, brush5);
        palette13.setBrush(QPalette::ColorGroup::Inactive, QPalette::ColorRole::Shadow, brush);
        palette13.setBrush(QPalette::ColorGroup::Inactive, QPalette::ColorRole::AlternateBase, brush70);
        palette13.setBrush(QPalette::ColorGroup::Inactive, QPalette::ColorRole::ToolTipBase, brush7);
        palette13.setBrush(QPalette::ColorGroup::Inactive, QPalette::ColorRole::ToolTipText, brush);
        palette13.setBrush(QPalette::ColorGroup::Disabled, QPalette::ColorRole::WindowText, brush68);
        palette13.setBrush(QPalette::ColorGroup::Disabled, QPalette::ColorRole::Button, brush5);
        palette13.setBrush(QPalette::ColorGroup::Disabled, QPalette::ColorRole::Light, brush1);
        palette13.setBrush(QPalette::ColorGroup::Disabled, QPalette::ColorRole::Midlight, brush67);
        palette13.setBrush(QPalette::ColorGroup::Disabled, QPalette::ColorRole::Dark, brush68);
        palette13.setBrush(QPalette::ColorGroup::Disabled, QPalette::ColorRole::Mid, brush69);
        palette13.setBrush(QPalette::ColorGroup::Disabled, QPalette::ColorRole::Text, brush68);
        palette13.setBrush(QPalette::ColorGroup::Disabled, QPalette::ColorRole::BrightText, brush6);
        palette13.setBrush(QPalette::ColorGroup::Disabled, QPalette::ColorRole::ButtonText, brush68);
        palette13.setBrush(QPalette::ColorGroup::Disabled, QPalette::ColorRole::Base, brush5);
        palette13.setBrush(QPalette::ColorGroup::Disabled, QPalette::ColorRole::Window, brush5);
        palette13.setBrush(QPalette::ColorGroup::Disabled, QPalette::ColorRole::Shadow, brush);
        palette13.setBrush(QPalette::ColorGroup::Disabled, QPalette::ColorRole::AlternateBase, brush5);
        palette13.setBrush(QPalette::ColorGroup::Disabled, QPalette::ColorRole::ToolTipBase, brush7);
        palette13.setBrush(QPalette::ColorGroup::Disabled, QPalette::ColorRole::ToolTipText, brush);
        primaryColorLabel_3->setPalette(palette13);
        primaryColorLabel_3->setAutoFillBackground(true);
        primaryColorLabel_3->setFrameShape(QFrame::Panel);
        primaryColorLabel_3->setFrameShadow(QFrame::Plain);
        primaryColorLabel_3->setLineWidth(0);
        primaryColorLabel_39 = new QLabel(page);
        primaryColorLabel_39->setObjectName("primaryColorLabel_39");
        primaryColorLabel_39->setGeometry(QRect(10, 72, 15, 15));
        sizePolicy1.setHeightForWidth(primaryColorLabel_39->sizePolicy().hasHeightForWidth());
        primaryColorLabel_39->setSizePolicy(sizePolicy1);
        primaryColorLabel_39->setMinimumSize(QSize(15, 15));
        primaryColorLabel_39->setMaximumSize(QSize(5, 5));
        QPalette palette14;
        palette14.setBrush(QPalette::ColorGroup::Active, QPalette::ColorRole::WindowText, brush);
        QBrush brush71(QColor(85, 0, 255, 255));
        brush71.setStyle(Qt::BrushStyle::SolidPattern);
        palette14.setBrush(QPalette::ColorGroup::Active, QPalette::ColorRole::Button, brush71);
        QBrush brush72(QColor(170, 127, 255, 255));
        brush72.setStyle(Qt::BrushStyle::SolidPattern);
        palette14.setBrush(QPalette::ColorGroup::Active, QPalette::ColorRole::Light, brush72);
        QBrush brush73(QColor(127, 63, 255, 255));
        brush73.setStyle(Qt::BrushStyle::SolidPattern);
        palette14.setBrush(QPalette::ColorGroup::Active, QPalette::ColorRole::Midlight, brush73);
        QBrush brush74(QColor(42, 0, 127, 255));
        brush74.setStyle(Qt::BrushStyle::SolidPattern);
        palette14.setBrush(QPalette::ColorGroup::Active, QPalette::ColorRole::Dark, brush74);
        QBrush brush75(QColor(56, 0, 170, 255));
        brush75.setStyle(Qt::BrushStyle::SolidPattern);
        palette14.setBrush(QPalette::ColorGroup::Active, QPalette::ColorRole::Mid, brush75);
        palette14.setBrush(QPalette::ColorGroup::Active, QPalette::ColorRole::Text, brush);
        palette14.setBrush(QPalette::ColorGroup::Active, QPalette::ColorRole::BrightText, brush6);
        palette14.setBrush(QPalette::ColorGroup::Active, QPalette::ColorRole::ButtonText, brush);
        palette14.setBrush(QPalette::ColorGroup::Active, QPalette::ColorRole::Base, brush6);
        palette14.setBrush(QPalette::ColorGroup::Active, QPalette::ColorRole::Window, brush71);
        palette14.setBrush(QPalette::ColorGroup::Active, QPalette::ColorRole::Shadow, brush);
        palette14.setBrush(QPalette::ColorGroup::Active, QPalette::ColorRole::AlternateBase, brush72);
        palette14.setBrush(QPalette::ColorGroup::Active, QPalette::ColorRole::ToolTipBase, brush7);
        palette14.setBrush(QPalette::ColorGroup::Active, QPalette::ColorRole::ToolTipText, brush);
        palette14.setBrush(QPalette::ColorGroup::Inactive, QPalette::ColorRole::WindowText, brush);
        palette14.setBrush(QPalette::ColorGroup::Inactive, QPalette::ColorRole::Button, brush71);
        palette14.setBrush(QPalette::ColorGroup::Inactive, QPalette::ColorRole::Light, brush72);
        palette14.setBrush(QPalette::ColorGroup::Inactive, QPalette::ColorRole::Midlight, brush73);
        palette14.setBrush(QPalette::ColorGroup::Inactive, QPalette::ColorRole::Dark, brush74);
        palette14.setBrush(QPalette::ColorGroup::Inactive, QPalette::ColorRole::Mid, brush75);
        palette14.setBrush(QPalette::ColorGroup::Inactive, QPalette::ColorRole::Text, brush);
        palette14.setBrush(QPalette::ColorGroup::Inactive, QPalette::ColorRole::BrightText, brush6);
        palette14.setBrush(QPalette::ColorGroup::Inactive, QPalette::ColorRole::ButtonText, brush);
        palette14.setBrush(QPalette::ColorGroup::Inactive, QPalette::ColorRole::Base, brush6);
        palette14.setBrush(QPalette::ColorGroup::Inactive, QPalette::ColorRole::Window, brush71);
        palette14.setBrush(QPalette::ColorGroup::Inactive, QPalette::ColorRole::Shadow, brush);
        palette14.setBrush(QPalette::ColorGroup::Inactive, QPalette::ColorRole::AlternateBase, brush72);
        palette14.setBrush(QPalette::ColorGroup::Inactive, QPalette::ColorRole::ToolTipBase, brush7);
        palette14.setBrush(QPalette::ColorGroup::Inactive, QPalette::ColorRole::ToolTipText, brush);
        palette14.setBrush(QPalette::ColorGroup::Disabled, QPalette::ColorRole::WindowText, brush74);
        palette14.setBrush(QPalette::ColorGroup::Disabled, QPalette::ColorRole::Button, brush71);
        palette14.setBrush(QPalette::ColorGroup::Disabled, QPalette::ColorRole::Light, brush72);
        palette14.setBrush(QPalette::ColorGroup::Disabled, QPalette::ColorRole::Midlight, brush73);
        palette14.setBrush(QPalette::ColorGroup::Disabled, QPalette::ColorRole::Dark, brush74);
        palette14.setBrush(QPalette::ColorGroup::Disabled, QPalette::ColorRole::Mid, brush75);
        palette14.setBrush(QPalette::ColorGroup::Disabled, QPalette::ColorRole::Text, brush74);
        palette14.setBrush(QPalette::ColorGroup::Disabled, QPalette::ColorRole::BrightText, brush6);
        palette14.setBrush(QPalette::ColorGroup::Disabled, QPalette::ColorRole::ButtonText, brush74);
        palette14.setBrush(QPalette::ColorGroup::Disabled, QPalette::ColorRole::Base, brush71);
        palette14.setBrush(QPalette::ColorGroup::Disabled, QPalette::ColorRole::Window, brush71);
        palette14.setBrush(QPalette::ColorGroup::Disabled, QPalette::ColorRole::Shadow, brush);
        palette14.setBrush(QPalette::ColorGroup::Disabled, QPalette::ColorRole::AlternateBase, brush71);
        palette14.setBrush(QPalette::ColorGroup::Disabled, QPalette::ColorRole::ToolTipBase, brush7);
        palette14.setBrush(QPalette::ColorGroup::Disabled, QPalette::ColorRole::ToolTipText, brush);
        primaryColorLabel_39->setPalette(palette14);
        primaryColorLabel_39->setAutoFillBackground(true);
        primaryColorLabel_39->setFrameShape(QFrame::Panel);
        primaryColorLabel_39->setFrameShadow(QFrame::Plain);
        primaryColorLabel_39->setLineWidth(0);
        primaryColorLabel_34 = new QLabel(page);
        primaryColorLabel_34->setObjectName("primaryColorLabel_34");
        primaryColorLabel_34->setGeometry(QRect(58, 72, 15, 15));
        sizePolicy1.setHeightForWidth(primaryColorLabel_34->sizePolicy().hasHeightForWidth());
        primaryColorLabel_34->setSizePolicy(sizePolicy1);
        primaryColorLabel_34->setMinimumSize(QSize(15, 15));
        primaryColorLabel_34->setMaximumSize(QSize(5, 5));
        QPalette palette15;
        palette15.setBrush(QPalette::ColorGroup::Active, QPalette::ColorRole::WindowText, brush);
        QBrush brush76(QColor(255, 85, 255, 255));
        brush76.setStyle(Qt::BrushStyle::SolidPattern);
        palette15.setBrush(QPalette::ColorGroup::Active, QPalette::ColorRole::Button, brush76);
        QBrush brush77(QColor(255, 213, 255, 255));
        brush77.setStyle(Qt::BrushStyle::SolidPattern);
        palette15.setBrush(QPalette::ColorGroup::Active, QPalette::ColorRole::Light, brush77);
        QBrush brush78(QColor(255, 149, 255, 255));
        brush78.setStyle(Qt::BrushStyle::SolidPattern);
        palette15.setBrush(QPalette::ColorGroup::Active, QPalette::ColorRole::Midlight, brush78);
        QBrush brush79(QColor(127, 42, 127, 255));
        brush79.setStyle(Qt::BrushStyle::SolidPattern);
        palette15.setBrush(QPalette::ColorGroup::Active, QPalette::ColorRole::Dark, brush79);
        QBrush brush80(QColor(170, 56, 170, 255));
        brush80.setStyle(Qt::BrushStyle::SolidPattern);
        palette15.setBrush(QPalette::ColorGroup::Active, QPalette::ColorRole::Mid, brush80);
        palette15.setBrush(QPalette::ColorGroup::Active, QPalette::ColorRole::Text, brush);
        palette15.setBrush(QPalette::ColorGroup::Active, QPalette::ColorRole::BrightText, brush6);
        palette15.setBrush(QPalette::ColorGroup::Active, QPalette::ColorRole::ButtonText, brush);
        palette15.setBrush(QPalette::ColorGroup::Active, QPalette::ColorRole::Base, brush6);
        palette15.setBrush(QPalette::ColorGroup::Active, QPalette::ColorRole::Window, brush76);
        palette15.setBrush(QPalette::ColorGroup::Active, QPalette::ColorRole::Shadow, brush);
        QBrush brush81(QColor(255, 170, 255, 255));
        brush81.setStyle(Qt::BrushStyle::SolidPattern);
        palette15.setBrush(QPalette::ColorGroup::Active, QPalette::ColorRole::AlternateBase, brush81);
        palette15.setBrush(QPalette::ColorGroup::Active, QPalette::ColorRole::ToolTipBase, brush7);
        palette15.setBrush(QPalette::ColorGroup::Active, QPalette::ColorRole::ToolTipText, brush);
        palette15.setBrush(QPalette::ColorGroup::Inactive, QPalette::ColorRole::WindowText, brush);
        palette15.setBrush(QPalette::ColorGroup::Inactive, QPalette::ColorRole::Button, brush76);
        palette15.setBrush(QPalette::ColorGroup::Inactive, QPalette::ColorRole::Light, brush77);
        palette15.setBrush(QPalette::ColorGroup::Inactive, QPalette::ColorRole::Midlight, brush78);
        palette15.setBrush(QPalette::ColorGroup::Inactive, QPalette::ColorRole::Dark, brush79);
        palette15.setBrush(QPalette::ColorGroup::Inactive, QPalette::ColorRole::Mid, brush80);
        palette15.setBrush(QPalette::ColorGroup::Inactive, QPalette::ColorRole::Text, brush);
        palette15.setBrush(QPalette::ColorGroup::Inactive, QPalette::ColorRole::BrightText, brush6);
        palette15.setBrush(QPalette::ColorGroup::Inactive, QPalette::ColorRole::ButtonText, brush);
        palette15.setBrush(QPalette::ColorGroup::Inactive, QPalette::ColorRole::Base, brush6);
        palette15.setBrush(QPalette::ColorGroup::Inactive, QPalette::ColorRole::Window, brush76);
        palette15.setBrush(QPalette::ColorGroup::Inactive, QPalette::ColorRole::Shadow, brush);
        palette15.setBrush(QPalette::ColorGroup::Inactive, QPalette::ColorRole::AlternateBase, brush81);
        palette15.setBrush(QPalette::ColorGroup::Inactive, QPalette::ColorRole::ToolTipBase, brush7);
        palette15.setBrush(QPalette::ColorGroup::Inactive, QPalette::ColorRole::ToolTipText, brush);
        palette15.setBrush(QPalette::ColorGroup::Disabled, QPalette::ColorRole::WindowText, brush79);
        palette15.setBrush(QPalette::ColorGroup::Disabled, QPalette::ColorRole::Button, brush76);
        palette15.setBrush(QPalette::ColorGroup::Disabled, QPalette::ColorRole::Light, brush77);
        palette15.setBrush(QPalette::ColorGroup::Disabled, QPalette::ColorRole::Midlight, brush78);
        palette15.setBrush(QPalette::ColorGroup::Disabled, QPalette::ColorRole::Dark, brush79);
        palette15.setBrush(QPalette::ColorGroup::Disabled, QPalette::ColorRole::Mid, brush80);
        palette15.setBrush(QPalette::ColorGroup::Disabled, QPalette::ColorRole::Text, brush79);
        palette15.setBrush(QPalette::ColorGroup::Disabled, QPalette::ColorRole::BrightText, brush6);
        palette15.setBrush(QPalette::ColorGroup::Disabled, QPalette::ColorRole::ButtonText, brush79);
        palette15.setBrush(QPalette::ColorGroup::Disabled, QPalette::ColorRole::Base, brush76);
        palette15.setBrush(QPalette::ColorGroup::Disabled, QPalette::ColorRole::Window, brush76);
        palette15.setBrush(QPalette::ColorGroup::Disabled, QPalette::ColorRole::Shadow, brush);
        palette15.setBrush(QPalette::ColorGroup::Disabled, QPalette::ColorRole::AlternateBase, brush76);
        palette15.setBrush(QPalette::ColorGroup::Disabled, QPalette::ColorRole::ToolTipBase, brush7);
        palette15.setBrush(QPalette::ColorGroup::Disabled, QPalette::ColorRole::ToolTipText, brush);
        primaryColorLabel_34->setPalette(palette15);
        primaryColorLabel_34->setAutoFillBackground(true);
        primaryColorLabel_34->setFrameShape(QFrame::Panel);
        primaryColorLabel_34->setFrameShadow(QFrame::Plain);
        primaryColorLabel_34->setLineWidth(0);
        primaryColorLabel_10 = new QLabel(page);
        primaryColorLabel_10->setObjectName("primaryColorLabel_10");
        primaryColorLabel_10->setGeometry(QRect(58, 24, 15, 15));
        sizePolicy1.setHeightForWidth(primaryColorLabel_10->sizePolicy().hasHeightForWidth());
        primaryColorLabel_10->setSizePolicy(sizePolicy1);
        primaryColorLabel_10->setMinimumSize(QSize(15, 15));
        primaryColorLabel_10->setMaximumSize(QSize(5, 5));
        QPalette palette16;
        palette16.setBrush(QPalette::ColorGroup::Active, QPalette::ColorRole::WindowText, brush);
        QBrush brush82(QColor(170, 85, 127, 255));
        brush82.setStyle(Qt::BrushStyle::SolidPattern);
        palette16.setBrush(QPalette::ColorGroup::Active, QPalette::ColorRole::Button, brush82);
        QBrush brush83(QColor(255, 127, 191, 255));
        brush83.setStyle(Qt::BrushStyle::SolidPattern);
        palette16.setBrush(QPalette::ColorGroup::Active, QPalette::ColorRole::Light, brush83);
        QBrush brush84(QColor(212, 106, 159, 255));
        brush84.setStyle(Qt::BrushStyle::SolidPattern);
        palette16.setBrush(QPalette::ColorGroup::Active, QPalette::ColorRole::Midlight, brush84);
        QBrush brush85(QColor(85, 42, 63, 255));
        brush85.setStyle(Qt::BrushStyle::SolidPattern);
        palette16.setBrush(QPalette::ColorGroup::Active, QPalette::ColorRole::Dark, brush85);
        QBrush brush86(QColor(113, 56, 84, 255));
        brush86.setStyle(Qt::BrushStyle::SolidPattern);
        palette16.setBrush(QPalette::ColorGroup::Active, QPalette::ColorRole::Mid, brush86);
        palette16.setBrush(QPalette::ColorGroup::Active, QPalette::ColorRole::Text, brush);
        palette16.setBrush(QPalette::ColorGroup::Active, QPalette::ColorRole::BrightText, brush6);
        palette16.setBrush(QPalette::ColorGroup::Active, QPalette::ColorRole::ButtonText, brush);
        palette16.setBrush(QPalette::ColorGroup::Active, QPalette::ColorRole::Base, brush6);
        palette16.setBrush(QPalette::ColorGroup::Active, QPalette::ColorRole::Window, brush82);
        palette16.setBrush(QPalette::ColorGroup::Active, QPalette::ColorRole::Shadow, brush);
        QBrush brush87(QColor(212, 170, 191, 255));
        brush87.setStyle(Qt::BrushStyle::SolidPattern);
        palette16.setBrush(QPalette::ColorGroup::Active, QPalette::ColorRole::AlternateBase, brush87);
        palette16.setBrush(QPalette::ColorGroup::Active, QPalette::ColorRole::ToolTipBase, brush7);
        palette16.setBrush(QPalette::ColorGroup::Active, QPalette::ColorRole::ToolTipText, brush);
        palette16.setBrush(QPalette::ColorGroup::Inactive, QPalette::ColorRole::WindowText, brush);
        palette16.setBrush(QPalette::ColorGroup::Inactive, QPalette::ColorRole::Button, brush82);
        palette16.setBrush(QPalette::ColorGroup::Inactive, QPalette::ColorRole::Light, brush83);
        palette16.setBrush(QPalette::ColorGroup::Inactive, QPalette::ColorRole::Midlight, brush84);
        palette16.setBrush(QPalette::ColorGroup::Inactive, QPalette::ColorRole::Dark, brush85);
        palette16.setBrush(QPalette::ColorGroup::Inactive, QPalette::ColorRole::Mid, brush86);
        palette16.setBrush(QPalette::ColorGroup::Inactive, QPalette::ColorRole::Text, brush);
        palette16.setBrush(QPalette::ColorGroup::Inactive, QPalette::ColorRole::BrightText, brush6);
        palette16.setBrush(QPalette::ColorGroup::Inactive, QPalette::ColorRole::ButtonText, brush);
        palette16.setBrush(QPalette::ColorGroup::Inactive, QPalette::ColorRole::Base, brush6);
        palette16.setBrush(QPalette::ColorGroup::Inactive, QPalette::ColorRole::Window, brush82);
        palette16.setBrush(QPalette::ColorGroup::Inactive, QPalette::ColorRole::Shadow, brush);
        palette16.setBrush(QPalette::ColorGroup::Inactive, QPalette::ColorRole::AlternateBase, brush87);
        palette16.setBrush(QPalette::ColorGroup::Inactive, QPalette::ColorRole::ToolTipBase, brush7);
        palette16.setBrush(QPalette::ColorGroup::Inactive, QPalette::ColorRole::ToolTipText, brush);
        palette16.setBrush(QPalette::ColorGroup::Disabled, QPalette::ColorRole::WindowText, brush85);
        palette16.setBrush(QPalette::ColorGroup::Disabled, QPalette::ColorRole::Button, brush82);
        palette16.setBrush(QPalette::ColorGroup::Disabled, QPalette::ColorRole::Light, brush83);
        palette16.setBrush(QPalette::ColorGroup::Disabled, QPalette::ColorRole::Midlight, brush84);
        palette16.setBrush(QPalette::ColorGroup::Disabled, QPalette::ColorRole::Dark, brush85);
        palette16.setBrush(QPalette::ColorGroup::Disabled, QPalette::ColorRole::Mid, brush86);
        palette16.setBrush(QPalette::ColorGroup::Disabled, QPalette::ColorRole::Text, brush85);
        palette16.setBrush(QPalette::ColorGroup::Disabled, QPalette::ColorRole::BrightText, brush6);
        palette16.setBrush(QPalette::ColorGroup::Disabled, QPalette::ColorRole::ButtonText, brush85);
        palette16.setBrush(QPalette::ColorGroup::Disabled, QPalette::ColorRole::Base, brush82);
        palette16.setBrush(QPalette::ColorGroup::Disabled, QPalette::ColorRole::Window, brush82);
        palette16.setBrush(QPalette::ColorGroup::Disabled, QPalette::ColorRole::Shadow, brush);
        palette16.setBrush(QPalette::ColorGroup::Disabled, QPalette::ColorRole::AlternateBase, brush82);
        palette16.setBrush(QPalette::ColorGroup::Disabled, QPalette::ColorRole::ToolTipBase, brush7);
        palette16.setBrush(QPalette::ColorGroup::Disabled, QPalette::ColorRole::ToolTipText, brush);
        primaryColorLabel_10->setPalette(palette16);
        primaryColorLabel_10->setAutoFillBackground(true);
        primaryColorLabel_10->setFrameShape(QFrame::Panel);
        primaryColorLabel_10->setFrameShadow(QFrame::Plain);
        primaryColorLabel_10->setLineWidth(0);
        primaryColorLabel_7 = new QLabel(page);
        primaryColorLabel_7->setObjectName("primaryColorLabel_7");
        primaryColorLabel_7->setGeometry(QRect(90, 8, 15, 15));
        sizePolicy1.setHeightForWidth(primaryColorLabel_7->sizePolicy().hasHeightForWidth());
        primaryColorLabel_7->setSizePolicy(sizePolicy1);
        primaryColorLabel_7->setMinimumSize(QSize(15, 15));
        primaryColorLabel_7->setMaximumSize(QSize(5, 5));
        QPalette palette17;
        palette17.setBrush(QPalette::ColorGroup::Active, QPalette::ColorRole::WindowText, brush);
        QBrush brush88(QColor(170, 170, 0, 255));
        brush88.setStyle(Qt::BrushStyle::SolidPattern);
        palette17.setBrush(QPalette::ColorGroup::Active, QPalette::ColorRole::Button, brush88);
        QBrush brush89(QColor(255, 255, 0, 255));
        brush89.setStyle(Qt::BrushStyle::SolidPattern);
        palette17.setBrush(QPalette::ColorGroup::Active, QPalette::ColorRole::Light, brush89);
        QBrush brush90(QColor(212, 212, 0, 255));
        brush90.setStyle(Qt::BrushStyle::SolidPattern);
        palette17.setBrush(QPalette::ColorGroup::Active, QPalette::ColorRole::Midlight, brush90);
        QBrush brush91(QColor(85, 85, 0, 255));
        brush91.setStyle(Qt::BrushStyle::SolidPattern);
        palette17.setBrush(QPalette::ColorGroup::Active, QPalette::ColorRole::Dark, brush91);
        QBrush brush92(QColor(113, 113, 0, 255));
        brush92.setStyle(Qt::BrushStyle::SolidPattern);
        palette17.setBrush(QPalette::ColorGroup::Active, QPalette::ColorRole::Mid, brush92);
        palette17.setBrush(QPalette::ColorGroup::Active, QPalette::ColorRole::Text, brush);
        palette17.setBrush(QPalette::ColorGroup::Active, QPalette::ColorRole::BrightText, brush6);
        palette17.setBrush(QPalette::ColorGroup::Active, QPalette::ColorRole::ButtonText, brush);
        palette17.setBrush(QPalette::ColorGroup::Active, QPalette::ColorRole::Base, brush6);
        palette17.setBrush(QPalette::ColorGroup::Active, QPalette::ColorRole::Window, brush88);
        palette17.setBrush(QPalette::ColorGroup::Active, QPalette::ColorRole::Shadow, brush);
        QBrush brush93(QColor(212, 212, 127, 255));
        brush93.setStyle(Qt::BrushStyle::SolidPattern);
        palette17.setBrush(QPalette::ColorGroup::Active, QPalette::ColorRole::AlternateBase, brush93);
        palette17.setBrush(QPalette::ColorGroup::Active, QPalette::ColorRole::ToolTipBase, brush7);
        palette17.setBrush(QPalette::ColorGroup::Active, QPalette::ColorRole::ToolTipText, brush);
        palette17.setBrush(QPalette::ColorGroup::Inactive, QPalette::ColorRole::WindowText, brush);
        palette17.setBrush(QPalette::ColorGroup::Inactive, QPalette::ColorRole::Button, brush88);
        palette17.setBrush(QPalette::ColorGroup::Inactive, QPalette::ColorRole::Light, brush89);
        palette17.setBrush(QPalette::ColorGroup::Inactive, QPalette::ColorRole::Midlight, brush90);
        palette17.setBrush(QPalette::ColorGroup::Inactive, QPalette::ColorRole::Dark, brush91);
        palette17.setBrush(QPalette::ColorGroup::Inactive, QPalette::ColorRole::Mid, brush92);
        palette17.setBrush(QPalette::ColorGroup::Inactive, QPalette::ColorRole::Text, brush);
        palette17.setBrush(QPalette::ColorGroup::Inactive, QPalette::ColorRole::BrightText, brush6);
        palette17.setBrush(QPalette::ColorGroup::Inactive, QPalette::ColorRole::ButtonText, brush);
        palette17.setBrush(QPalette::ColorGroup::Inactive, QPalette::ColorRole::Base, brush6);
        palette17.setBrush(QPalette::ColorGroup::Inactive, QPalette::ColorRole::Window, brush88);
        palette17.setBrush(QPalette::ColorGroup::Inactive, QPalette::ColorRole::Shadow, brush);
        palette17.setBrush(QPalette::ColorGroup::Inactive, QPalette::ColorRole::AlternateBase, brush93);
        palette17.setBrush(QPalette::ColorGroup::Inactive, QPalette::ColorRole::ToolTipBase, brush7);
        palette17.setBrush(QPalette::ColorGroup::Inactive, QPalette::ColorRole::ToolTipText, brush);
        palette17.setBrush(QPalette::ColorGroup::Disabled, QPalette::ColorRole::WindowText, brush91);
        palette17.setBrush(QPalette::ColorGroup::Disabled, QPalette::ColorRole::Button, brush88);
        palette17.setBrush(QPalette::ColorGroup::Disabled, QPalette::ColorRole::Light, brush89);
        palette17.setBrush(QPalette::ColorGroup::Disabled, QPalette::ColorRole::Midlight, brush90);
        palette17.setBrush(QPalette::ColorGroup::Disabled, QPalette::ColorRole::Dark, brush91);
        palette17.setBrush(QPalette::ColorGroup::Disabled, QPalette::ColorRole::Mid, brush92);
        palette17.setBrush(QPalette::ColorGroup::Disabled, QPalette::ColorRole::Text, brush91);
        palette17.setBrush(QPalette::ColorGroup::Disabled, QPalette::ColorRole::BrightText, brush6);
        palette17.setBrush(QPalette::ColorGroup::Disabled, QPalette::ColorRole::ButtonText, brush91);
        palette17.setBrush(QPalette::ColorGroup::Disabled, QPalette::ColorRole::Base, brush88);
        palette17.setBrush(QPalette::ColorGroup::Disabled, QPalette::ColorRole::Window, brush88);
        palette17.setBrush(QPalette::ColorGroup::Disabled, QPalette::ColorRole::Shadow, brush);
        palette17.setBrush(QPalette::ColorGroup::Disabled, QPalette::ColorRole::AlternateBase, brush88);
        palette17.setBrush(QPalette::ColorGroup::Disabled, QPalette::ColorRole::ToolTipBase, brush7);
        palette17.setBrush(QPalette::ColorGroup::Disabled, QPalette::ColorRole::ToolTipText, brush);
        primaryColorLabel_7->setPalette(palette17);
        primaryColorLabel_7->setAutoFillBackground(true);
        primaryColorLabel_7->setFrameShape(QFrame::Panel);
        primaryColorLabel_7->setFrameShadow(QFrame::Plain);
        primaryColorLabel_7->setLineWidth(0);
        primaryColorLabel_18 = new QLabel(page);
        primaryColorLabel_18->setObjectName("primaryColorLabel_18");
        primaryColorLabel_18->setGeometry(QRect(58, 40, 15, 15));
        sizePolicy1.setHeightForWidth(primaryColorLabel_18->sizePolicy().hasHeightForWidth());
        primaryColorLabel_18->setSizePolicy(sizePolicy1);
        primaryColorLabel_18->setMinimumSize(QSize(15, 15));
        primaryColorLabel_18->setMaximumSize(QSize(5, 5));
        QPalette palette18;
        palette18.setBrush(QPalette::ColorGroup::Active, QPalette::ColorRole::WindowText, brush);
        QBrush brush94(QColor(170, 85, 255, 255));
        brush94.setStyle(Qt::BrushStyle::SolidPattern);
        palette18.setBrush(QPalette::ColorGroup::Active, QPalette::ColorRole::Button, brush94);
        QBrush brush95(QColor(234, 213, 255, 255));
        brush95.setStyle(Qt::BrushStyle::SolidPattern);
        palette18.setBrush(QPalette::ColorGroup::Active, QPalette::ColorRole::Light, brush95);
        QBrush brush96(QColor(202, 149, 255, 255));
        brush96.setStyle(Qt::BrushStyle::SolidPattern);
        palette18.setBrush(QPalette::ColorGroup::Active, QPalette::ColorRole::Midlight, brush96);
        QBrush brush97(QColor(85, 42, 127, 255));
        brush97.setStyle(Qt::BrushStyle::SolidPattern);
        palette18.setBrush(QPalette::ColorGroup::Active, QPalette::ColorRole::Dark, brush97);
        QBrush brush98(QColor(113, 56, 170, 255));
        brush98.setStyle(Qt::BrushStyle::SolidPattern);
        palette18.setBrush(QPalette::ColorGroup::Active, QPalette::ColorRole::Mid, brush98);
        palette18.setBrush(QPalette::ColorGroup::Active, QPalette::ColorRole::Text, brush);
        palette18.setBrush(QPalette::ColorGroup::Active, QPalette::ColorRole::BrightText, brush6);
        palette18.setBrush(QPalette::ColorGroup::Active, QPalette::ColorRole::ButtonText, brush);
        palette18.setBrush(QPalette::ColorGroup::Active, QPalette::ColorRole::Base, brush6);
        palette18.setBrush(QPalette::ColorGroup::Active, QPalette::ColorRole::Window, brush94);
        palette18.setBrush(QPalette::ColorGroup::Active, QPalette::ColorRole::Shadow, brush);
        QBrush brush99(QColor(212, 170, 255, 255));
        brush99.setStyle(Qt::BrushStyle::SolidPattern);
        palette18.setBrush(QPalette::ColorGroup::Active, QPalette::ColorRole::AlternateBase, brush99);
        palette18.setBrush(QPalette::ColorGroup::Active, QPalette::ColorRole::ToolTipBase, brush7);
        palette18.setBrush(QPalette::ColorGroup::Active, QPalette::ColorRole::ToolTipText, brush);
        palette18.setBrush(QPalette::ColorGroup::Inactive, QPalette::ColorRole::WindowText, brush);
        palette18.setBrush(QPalette::ColorGroup::Inactive, QPalette::ColorRole::Button, brush94);
        palette18.setBrush(QPalette::ColorGroup::Inactive, QPalette::ColorRole::Light, brush95);
        palette18.setBrush(QPalette::ColorGroup::Inactive, QPalette::ColorRole::Midlight, brush96);
        palette18.setBrush(QPalette::ColorGroup::Inactive, QPalette::ColorRole::Dark, brush97);
        palette18.setBrush(QPalette::ColorGroup::Inactive, QPalette::ColorRole::Mid, brush98);
        palette18.setBrush(QPalette::ColorGroup::Inactive, QPalette::ColorRole::Text, brush);
        palette18.setBrush(QPalette::ColorGroup::Inactive, QPalette::ColorRole::BrightText, brush6);
        palette18.setBrush(QPalette::ColorGroup::Inactive, QPalette::ColorRole::ButtonText, brush);
        palette18.setBrush(QPalette::ColorGroup::Inactive, QPalette::ColorRole::Base, brush6);
        palette18.setBrush(QPalette::ColorGroup::Inactive, QPalette::ColorRole::Window, brush94);
        palette18.setBrush(QPalette::ColorGroup::Inactive, QPalette::ColorRole::Shadow, brush);
        palette18.setBrush(QPalette::ColorGroup::Inactive, QPalette::ColorRole::AlternateBase, brush99);
        palette18.setBrush(QPalette::ColorGroup::Inactive, QPalette::ColorRole::ToolTipBase, brush7);
        palette18.setBrush(QPalette::ColorGroup::Inactive, QPalette::ColorRole::ToolTipText, brush);
        palette18.setBrush(QPalette::ColorGroup::Disabled, QPalette::ColorRole::WindowText, brush97);
        palette18.setBrush(QPalette::ColorGroup::Disabled, QPalette::ColorRole::Button, brush94);
        palette18.setBrush(QPalette::ColorGroup::Disabled, QPalette::ColorRole::Light, brush95);
        palette18.setBrush(QPalette::ColorGroup::Disabled, QPalette::ColorRole::Midlight, brush96);
        palette18.setBrush(QPalette::ColorGroup::Disabled, QPalette::ColorRole::Dark, brush97);
        palette18.setBrush(QPalette::ColorGroup::Disabled, QPalette::ColorRole::Mid, brush98);
        palette18.setBrush(QPalette::ColorGroup::Disabled, QPalette::ColorRole::Text, brush97);
        palette18.setBrush(QPalette::ColorGroup::Disabled, QPalette::ColorRole::BrightText, brush6);
        palette18.setBrush(QPalette::ColorGroup::Disabled, QPalette::ColorRole::ButtonText, brush97);
        palette18.setBrush(QPalette::ColorGroup::Disabled, QPalette::ColorRole::Base, brush94);
        palette18.setBrush(QPalette::ColorGroup::Disabled, QPalette::ColorRole::Window, brush94);
        palette18.setBrush(QPalette::ColorGroup::Disabled, QPalette::ColorRole::Shadow, brush);
        palette18.setBrush(QPalette::ColorGroup::Disabled, QPalette::ColorRole::AlternateBase, brush94);
        palette18.setBrush(QPalette::ColorGroup::Disabled, QPalette::ColorRole::ToolTipBase, brush7);
        palette18.setBrush(QPalette::ColorGroup::Disabled, QPalette::ColorRole::ToolTipText, brush);
        primaryColorLabel_18->setPalette(palette18);
        primaryColorLabel_18->setAutoFillBackground(true);
        primaryColorLabel_18->setFrameShape(QFrame::Panel);
        primaryColorLabel_18->setFrameShadow(QFrame::Plain);
        primaryColorLabel_18->setLineWidth(0);
        primaryColorLabel_25 = new QLabel(page);
        primaryColorLabel_25->setObjectName("primaryColorLabel_25");
        primaryColorLabel_25->setGeometry(QRect(90, 40, 15, 15));
        sizePolicy1.setHeightForWidth(primaryColorLabel_25->sizePolicy().hasHeightForWidth());
        primaryColorLabel_25->setSizePolicy(sizePolicy1);
        primaryColorLabel_25->setMinimumSize(QSize(15, 15));
        primaryColorLabel_25->setMaximumSize(QSize(5, 5));
        QPalette palette19;
        palette19.setBrush(QPalette::ColorGroup::Active, QPalette::ColorRole::WindowText, brush);
        palette19.setBrush(QPalette::ColorGroup::Active, QPalette::ColorRole::Button, brush22);
        palette19.setBrush(QPalette::ColorGroup::Active, QPalette::ColorRole::Light, brush6);
        QBrush brush100(QColor(212, 212, 255, 255));
        brush100.setStyle(Qt::BrushStyle::SolidPattern);
        palette19.setBrush(QPalette::ColorGroup::Active, QPalette::ColorRole::Midlight, brush100);
        QBrush brush101(QColor(85, 85, 127, 255));
        brush101.setStyle(Qt::BrushStyle::SolidPattern);
        palette19.setBrush(QPalette::ColorGroup::Active, QPalette::ColorRole::Dark, brush101);
        QBrush brush102(QColor(113, 113, 170, 255));
        brush102.setStyle(Qt::BrushStyle::SolidPattern);
        palette19.setBrush(QPalette::ColorGroup::Active, QPalette::ColorRole::Mid, brush102);
        palette19.setBrush(QPalette::ColorGroup::Active, QPalette::ColorRole::Text, brush);
        palette19.setBrush(QPalette::ColorGroup::Active, QPalette::ColorRole::BrightText, brush6);
        palette19.setBrush(QPalette::ColorGroup::Active, QPalette::ColorRole::ButtonText, brush);
        palette19.setBrush(QPalette::ColorGroup::Active, QPalette::ColorRole::Base, brush6);
        palette19.setBrush(QPalette::ColorGroup::Active, QPalette::ColorRole::Window, brush22);
        palette19.setBrush(QPalette::ColorGroup::Active, QPalette::ColorRole::Shadow, brush);
        palette19.setBrush(QPalette::ColorGroup::Active, QPalette::ColorRole::AlternateBase, brush100);
        palette19.setBrush(QPalette::ColorGroup::Active, QPalette::ColorRole::ToolTipBase, brush7);
        palette19.setBrush(QPalette::ColorGroup::Active, QPalette::ColorRole::ToolTipText, brush);
        palette19.setBrush(QPalette::ColorGroup::Inactive, QPalette::ColorRole::WindowText, brush);
        palette19.setBrush(QPalette::ColorGroup::Inactive, QPalette::ColorRole::Button, brush22);
        palette19.setBrush(QPalette::ColorGroup::Inactive, QPalette::ColorRole::Light, brush6);
        palette19.setBrush(QPalette::ColorGroup::Inactive, QPalette::ColorRole::Midlight, brush100);
        palette19.setBrush(QPalette::ColorGroup::Inactive, QPalette::ColorRole::Dark, brush101);
        palette19.setBrush(QPalette::ColorGroup::Inactive, QPalette::ColorRole::Mid, brush102);
        palette19.setBrush(QPalette::ColorGroup::Inactive, QPalette::ColorRole::Text, brush);
        palette19.setBrush(QPalette::ColorGroup::Inactive, QPalette::ColorRole::BrightText, brush6);
        palette19.setBrush(QPalette::ColorGroup::Inactive, QPalette::ColorRole::ButtonText, brush);
        palette19.setBrush(QPalette::ColorGroup::Inactive, QPalette::ColorRole::Base, brush6);
        palette19.setBrush(QPalette::ColorGroup::Inactive, QPalette::ColorRole::Window, brush22);
        palette19.setBrush(QPalette::ColorGroup::Inactive, QPalette::ColorRole::Shadow, brush);
        palette19.setBrush(QPalette::ColorGroup::Inactive, QPalette::ColorRole::AlternateBase, brush100);
        palette19.setBrush(QPalette::ColorGroup::Inactive, QPalette::ColorRole::ToolTipBase, brush7);
        palette19.setBrush(QPalette::ColorGroup::Inactive, QPalette::ColorRole::ToolTipText, brush);
        palette19.setBrush(QPalette::ColorGroup::Disabled, QPalette::ColorRole::WindowText, brush101);
        palette19.setBrush(QPalette::ColorGroup::Disabled, QPalette::ColorRole::Button, brush22);
        palette19.setBrush(QPalette::ColorGroup::Disabled, QPalette::ColorRole::Light, brush6);
        palette19.setBrush(QPalette::ColorGroup::Disabled, QPalette::ColorRole::Midlight, brush100);
        palette19.setBrush(QPalette::ColorGroup::Disabled, QPalette::ColorRole::Dark, brush101);
        palette19.setBrush(QPalette::ColorGroup::Disabled, QPalette::ColorRole::Mid, brush102);
        palette19.setBrush(QPalette::ColorGroup::Disabled, QPalette::ColorRole::Text, brush101);
        palette19.setBrush(QPalette::ColorGroup::Disabled, QPalette::ColorRole::BrightText, brush6);
        palette19.setBrush(QPalette::ColorGroup::Disabled, QPalette::ColorRole::ButtonText, brush101);
        palette19.setBrush(QPalette::ColorGroup::Disabled, QPalette::ColorRole::Base, brush22);
        palette19.setBrush(QPalette::ColorGroup::Disabled, QPalette::ColorRole::Window, brush22);
        palette19.setBrush(QPalette::ColorGroup::Disabled, QPalette::ColorRole::Shadow, brush);
        palette19.setBrush(QPalette::ColorGroup::Disabled, QPalette::ColorRole::AlternateBase, brush22);
        palette19.setBrush(QPalette::ColorGroup::Disabled, QPalette::ColorRole::ToolTipBase, brush7);
        palette19.setBrush(QPalette::ColorGroup::Disabled, QPalette::ColorRole::ToolTipText, brush);
        primaryColorLabel_25->setPalette(palette19);
        primaryColorLabel_25->setAutoFillBackground(true);
        primaryColorLabel_25->setFrameShape(QFrame::Panel);
        primaryColorLabel_25->setFrameShadow(QFrame::Plain);
        primaryColorLabel_25->setLineWidth(0);
        primaryColorLabel_28 = new QLabel(page);
        primaryColorLabel_28->setObjectName("primaryColorLabel_28");
        primaryColorLabel_28->setGeometry(QRect(74, 56, 15, 15));
        sizePolicy1.setHeightForWidth(primaryColorLabel_28->sizePolicy().hasHeightForWidth());
        primaryColorLabel_28->setSizePolicy(sizePolicy1);
        primaryColorLabel_28->setMinimumSize(QSize(15, 15));
        primaryColorLabel_28->setMaximumSize(QSize(5, 5));
        QPalette palette20;
        palette20.setBrush(QPalette::ColorGroup::Active, QPalette::ColorRole::WindowText, brush);
        QBrush brush103(QColor(85, 170, 0, 255));
        brush103.setStyle(Qt::BrushStyle::SolidPattern);
        palette20.setBrush(QPalette::ColorGroup::Active, QPalette::ColorRole::Button, brush103);
        QBrush brush104(QColor(128, 255, 0, 255));
        brush104.setStyle(Qt::BrushStyle::SolidPattern);
        palette20.setBrush(QPalette::ColorGroup::Active, QPalette::ColorRole::Light, brush104);
        QBrush brush105(QColor(106, 212, 0, 255));
        brush105.setStyle(Qt::BrushStyle::SolidPattern);
        palette20.setBrush(QPalette::ColorGroup::Active, QPalette::ColorRole::Midlight, brush105);
        QBrush brush106(QColor(42, 85, 0, 255));
        brush106.setStyle(Qt::BrushStyle::SolidPattern);
        palette20.setBrush(QPalette::ColorGroup::Active, QPalette::ColorRole::Dark, brush106);
        QBrush brush107(QColor(56, 113, 0, 255));
        brush107.setStyle(Qt::BrushStyle::SolidPattern);
        palette20.setBrush(QPalette::ColorGroup::Active, QPalette::ColorRole::Mid, brush107);
        palette20.setBrush(QPalette::ColorGroup::Active, QPalette::ColorRole::Text, brush);
        palette20.setBrush(QPalette::ColorGroup::Active, QPalette::ColorRole::BrightText, brush6);
        palette20.setBrush(QPalette::ColorGroup::Active, QPalette::ColorRole::ButtonText, brush);
        palette20.setBrush(QPalette::ColorGroup::Active, QPalette::ColorRole::Base, brush6);
        palette20.setBrush(QPalette::ColorGroup::Active, QPalette::ColorRole::Window, brush103);
        palette20.setBrush(QPalette::ColorGroup::Active, QPalette::ColorRole::Shadow, brush);
        QBrush brush108(QColor(170, 212, 127, 255));
        brush108.setStyle(Qt::BrushStyle::SolidPattern);
        palette20.setBrush(QPalette::ColorGroup::Active, QPalette::ColorRole::AlternateBase, brush108);
        palette20.setBrush(QPalette::ColorGroup::Active, QPalette::ColorRole::ToolTipBase, brush7);
        palette20.setBrush(QPalette::ColorGroup::Active, QPalette::ColorRole::ToolTipText, brush);
        palette20.setBrush(QPalette::ColorGroup::Inactive, QPalette::ColorRole::WindowText, brush);
        palette20.setBrush(QPalette::ColorGroup::Inactive, QPalette::ColorRole::Button, brush103);
        palette20.setBrush(QPalette::ColorGroup::Inactive, QPalette::ColorRole::Light, brush104);
        palette20.setBrush(QPalette::ColorGroup::Inactive, QPalette::ColorRole::Midlight, brush105);
        palette20.setBrush(QPalette::ColorGroup::Inactive, QPalette::ColorRole::Dark, brush106);
        palette20.setBrush(QPalette::ColorGroup::Inactive, QPalette::ColorRole::Mid, brush107);
        palette20.setBrush(QPalette::ColorGroup::Inactive, QPalette::ColorRole::Text, brush);
        palette20.setBrush(QPalette::ColorGroup::Inactive, QPalette::ColorRole::BrightText, brush6);
        palette20.setBrush(QPalette::ColorGroup::Inactive, QPalette::ColorRole::ButtonText, brush);
        palette20.setBrush(QPalette::ColorGroup::Inactive, QPalette::ColorRole::Base, brush6);
        palette20.setBrush(QPalette::ColorGroup::Inactive, QPalette::ColorRole::Window, brush103);
        palette20.setBrush(QPalette::ColorGroup::Inactive, QPalette::ColorRole::Shadow, brush);
        palette20.setBrush(QPalette::ColorGroup::Inactive, QPalette::ColorRole::AlternateBase, brush108);
        palette20.setBrush(QPalette::ColorGroup::Inactive, QPalette::ColorRole::ToolTipBase, brush7);
        palette20.setBrush(QPalette::ColorGroup::Inactive, QPalette::ColorRole::ToolTipText, brush);
        palette20.setBrush(QPalette::ColorGroup::Disabled, QPalette::ColorRole::WindowText, brush106);
        palette20.setBrush(QPalette::ColorGroup::Disabled, QPalette::ColorRole::Button, brush103);
        palette20.setBrush(QPalette::ColorGroup::Disabled, QPalette::ColorRole::Light, brush104);
        palette20.setBrush(QPalette::ColorGroup::Disabled, QPalette::ColorRole::Midlight, brush105);
        palette20.setBrush(QPalette::ColorGroup::Disabled, QPalette::ColorRole::Dark, brush106);
        palette20.setBrush(QPalette::ColorGroup::Disabled, QPalette::ColorRole::Mid, brush107);
        palette20.setBrush(QPalette::ColorGroup::Disabled, QPalette::ColorRole::Text, brush106);
        palette20.setBrush(QPalette::ColorGroup::Disabled, QPalette::ColorRole::BrightText, brush6);
        palette20.setBrush(QPalette::ColorGroup::Disabled, QPalette::ColorRole::ButtonText, brush106);
        palette20.setBrush(QPalette::ColorGroup::Disabled, QPalette::ColorRole::Base, brush103);
        palette20.setBrush(QPalette::ColorGroup::Disabled, QPalette::ColorRole::Window, brush103);
        palette20.setBrush(QPalette::ColorGroup::Disabled, QPalette::ColorRole::Shadow, brush);
        palette20.setBrush(QPalette::ColorGroup::Disabled, QPalette::ColorRole::AlternateBase, brush103);
        palette20.setBrush(QPalette::ColorGroup::Disabled, QPalette::ColorRole::ToolTipBase, brush7);
        palette20.setBrush(QPalette::ColorGroup::Disabled, QPalette::ColorRole::ToolTipText, brush);
        primaryColorLabel_28->setPalette(palette20);
        primaryColorLabel_28->setAutoFillBackground(true);
        primaryColorLabel_28->setFrameShape(QFrame::Panel);
        primaryColorLabel_28->setFrameShadow(QFrame::Plain);
        primaryColorLabel_28->setLineWidth(0);
        primaryColorLabel_29 = new QLabel(page);
        primaryColorLabel_29->setObjectName("primaryColorLabel_29");
        primaryColorLabel_29->setGeometry(QRect(122, 56, 15, 15));
        sizePolicy1.setHeightForWidth(primaryColorLabel_29->sizePolicy().hasHeightForWidth());
        primaryColorLabel_29->setSizePolicy(sizePolicy1);
        primaryColorLabel_29->setMinimumSize(QSize(15, 15));
        primaryColorLabel_29->setMaximumSize(QSize(5, 5));
        QPalette palette21;
        palette21.setBrush(QPalette::ColorGroup::Active, QPalette::ColorRole::WindowText, brush);
        palette21.setBrush(QPalette::ColorGroup::Active, QPalette::ColorRole::Button, brush89);
        QBrush brush109(QColor(255, 255, 127, 255));
        brush109.setStyle(Qt::BrushStyle::SolidPattern);
        palette21.setBrush(QPalette::ColorGroup::Active, QPalette::ColorRole::Light, brush109);
        QBrush brush110(QColor(255, 255, 63, 255));
        brush110.setStyle(Qt::BrushStyle::SolidPattern);
        palette21.setBrush(QPalette::ColorGroup::Active, QPalette::ColorRole::Midlight, brush110);
        QBrush brush111(QColor(127, 127, 0, 255));
        brush111.setStyle(Qt::BrushStyle::SolidPattern);
        palette21.setBrush(QPalette::ColorGroup::Active, QPalette::ColorRole::Dark, brush111);
        palette21.setBrush(QPalette::ColorGroup::Active, QPalette::ColorRole::Mid, brush88);
        palette21.setBrush(QPalette::ColorGroup::Active, QPalette::ColorRole::Text, brush);
        palette21.setBrush(QPalette::ColorGroup::Active, QPalette::ColorRole::BrightText, brush6);
        palette21.setBrush(QPalette::ColorGroup::Active, QPalette::ColorRole::ButtonText, brush);
        palette21.setBrush(QPalette::ColorGroup::Active, QPalette::ColorRole::Base, brush6);
        palette21.setBrush(QPalette::ColorGroup::Active, QPalette::ColorRole::Window, brush89);
        palette21.setBrush(QPalette::ColorGroup::Active, QPalette::ColorRole::Shadow, brush);
        palette21.setBrush(QPalette::ColorGroup::Active, QPalette::ColorRole::AlternateBase, brush109);
        palette21.setBrush(QPalette::ColorGroup::Active, QPalette::ColorRole::ToolTipBase, brush7);
        palette21.setBrush(QPalette::ColorGroup::Active, QPalette::ColorRole::ToolTipText, brush);
        palette21.setBrush(QPalette::ColorGroup::Inactive, QPalette::ColorRole::WindowText, brush);
        palette21.setBrush(QPalette::ColorGroup::Inactive, QPalette::ColorRole::Button, brush89);
        palette21.setBrush(QPalette::ColorGroup::Inactive, QPalette::ColorRole::Light, brush109);
        palette21.setBrush(QPalette::ColorGroup::Inactive, QPalette::ColorRole::Midlight, brush110);
        palette21.setBrush(QPalette::ColorGroup::Inactive, QPalette::ColorRole::Dark, brush111);
        palette21.setBrush(QPalette::ColorGroup::Inactive, QPalette::ColorRole::Mid, brush88);
        palette21.setBrush(QPalette::ColorGroup::Inactive, QPalette::ColorRole::Text, brush);
        palette21.setBrush(QPalette::ColorGroup::Inactive, QPalette::ColorRole::BrightText, brush6);
        palette21.setBrush(QPalette::ColorGroup::Inactive, QPalette::ColorRole::ButtonText, brush);
        palette21.setBrush(QPalette::ColorGroup::Inactive, QPalette::ColorRole::Base, brush6);
        palette21.setBrush(QPalette::ColorGroup::Inactive, QPalette::ColorRole::Window, brush89);
        palette21.setBrush(QPalette::ColorGroup::Inactive, QPalette::ColorRole::Shadow, brush);
        palette21.setBrush(QPalette::ColorGroup::Inactive, QPalette::ColorRole::AlternateBase, brush109);
        palette21.setBrush(QPalette::ColorGroup::Inactive, QPalette::ColorRole::ToolTipBase, brush7);
        palette21.setBrush(QPalette::ColorGroup::Inactive, QPalette::ColorRole::ToolTipText, brush);
        palette21.setBrush(QPalette::ColorGroup::Disabled, QPalette::ColorRole::WindowText, brush111);
        palette21.setBrush(QPalette::ColorGroup::Disabled, QPalette::ColorRole::Button, brush89);
        palette21.setBrush(QPalette::ColorGroup::Disabled, QPalette::ColorRole::Light, brush109);
        palette21.setBrush(QPalette::ColorGroup::Disabled, QPalette::ColorRole::Midlight, brush110);
        palette21.setBrush(QPalette::ColorGroup::Disabled, QPalette::ColorRole::Dark, brush111);
        palette21.setBrush(QPalette::ColorGroup::Disabled, QPalette::ColorRole::Mid, brush88);
        palette21.setBrush(QPalette::ColorGroup::Disabled, QPalette::ColorRole::Text, brush111);
        palette21.setBrush(QPalette::ColorGroup::Disabled, QPalette::ColorRole::BrightText, brush6);
        palette21.setBrush(QPalette::ColorGroup::Disabled, QPalette::ColorRole::ButtonText, brush111);
        palette21.setBrush(QPalette::ColorGroup::Disabled, QPalette::ColorRole::Base, brush89);
        palette21.setBrush(QPalette::ColorGroup::Disabled, QPalette::ColorRole::Window, brush89);
        palette21.setBrush(QPalette::ColorGroup::Disabled, QPalette::ColorRole::Shadow, brush);
        palette21.setBrush(QPalette::ColorGroup::Disabled, QPalette::ColorRole::AlternateBase, brush89);
        palette21.setBrush(QPalette::ColorGroup::Disabled, QPalette::ColorRole::ToolTipBase, brush7);
        palette21.setBrush(QPalette::ColorGroup::Disabled, QPalette::ColorRole::ToolTipText, brush);
        primaryColorLabel_29->setPalette(palette21);
        primaryColorLabel_29->setAutoFillBackground(true);
        primaryColorLabel_29->setFrameShape(QFrame::Panel);
        primaryColorLabel_29->setFrameShadow(QFrame::Plain);
        primaryColorLabel_29->setLineWidth(0);
        primaryColorLabel_2 = new QLabel(page);
        primaryColorLabel_2->setObjectName("primaryColorLabel_2");
        primaryColorLabel_2->setGeometry(QRect(10, 8, 15, 15));
        sizePolicy1.setHeightForWidth(primaryColorLabel_2->sizePolicy().hasHeightForWidth());
        primaryColorLabel_2->setSizePolicy(sizePolicy1);
        primaryColorLabel_2->setMinimumSize(QSize(15, 15));
        primaryColorLabel_2->setMaximumSize(QSize(5, 5));
        QPalette palette22;
        palette22.setBrush(QPalette::ColorGroup::Active, QPalette::ColorRole::WindowText, brush6);
        palette22.setBrush(QPalette::ColorGroup::Active, QPalette::ColorRole::Button, brush);
        palette22.setBrush(QPalette::ColorGroup::Active, QPalette::ColorRole::Light, brush);
        palette22.setBrush(QPalette::ColorGroup::Active, QPalette::ColorRole::Midlight, brush);
        palette22.setBrush(QPalette::ColorGroup::Active, QPalette::ColorRole::Dark, brush);
        palette22.setBrush(QPalette::ColorGroup::Active, QPalette::ColorRole::Mid, brush);
        palette22.setBrush(QPalette::ColorGroup::Active, QPalette::ColorRole::Text, brush6);
        palette22.setBrush(QPalette::ColorGroup::Active, QPalette::ColorRole::BrightText, brush6);
        palette22.setBrush(QPalette::ColorGroup::Active, QPalette::ColorRole::ButtonText, brush6);
        palette22.setBrush(QPalette::ColorGroup::Active, QPalette::ColorRole::Base, brush);
        palette22.setBrush(QPalette::ColorGroup::Active, QPalette::ColorRole::Window, brush);
        palette22.setBrush(QPalette::ColorGroup::Active, QPalette::ColorRole::Shadow, brush);
        palette22.setBrush(QPalette::ColorGroup::Active, QPalette::ColorRole::AlternateBase, brush);
        palette22.setBrush(QPalette::ColorGroup::Active, QPalette::ColorRole::ToolTipBase, brush7);
        palette22.setBrush(QPalette::ColorGroup::Active, QPalette::ColorRole::ToolTipText, brush);
        palette22.setBrush(QPalette::ColorGroup::Inactive, QPalette::ColorRole::WindowText, brush6);
        palette22.setBrush(QPalette::ColorGroup::Inactive, QPalette::ColorRole::Button, brush);
        palette22.setBrush(QPalette::ColorGroup::Inactive, QPalette::ColorRole::Light, brush);
        palette22.setBrush(QPalette::ColorGroup::Inactive, QPalette::ColorRole::Midlight, brush);
        palette22.setBrush(QPalette::ColorGroup::Inactive, QPalette::ColorRole::Dark, brush);
        palette22.setBrush(QPalette::ColorGroup::Inactive, QPalette::ColorRole::Mid, brush);
        palette22.setBrush(QPalette::ColorGroup::Inactive, QPalette::ColorRole::Text, brush6);
        palette22.setBrush(QPalette::ColorGroup::Inactive, QPalette::ColorRole::BrightText, brush6);
        palette22.setBrush(QPalette::ColorGroup::Inactive, QPalette::ColorRole::ButtonText, brush6);
        palette22.setBrush(QPalette::ColorGroup::Inactive, QPalette::ColorRole::Base, brush);
        palette22.setBrush(QPalette::ColorGroup::Inactive, QPalette::ColorRole::Window, brush);
        palette22.setBrush(QPalette::ColorGroup::Inactive, QPalette::ColorRole::Shadow, brush);
        palette22.setBrush(QPalette::ColorGroup::Inactive, QPalette::ColorRole::AlternateBase, brush);
        palette22.setBrush(QPalette::ColorGroup::Inactive, QPalette::ColorRole::ToolTipBase, brush7);
        palette22.setBrush(QPalette::ColorGroup::Inactive, QPalette::ColorRole::ToolTipText, brush);
        palette22.setBrush(QPalette::ColorGroup::Disabled, QPalette::ColorRole::WindowText, brush);
        palette22.setBrush(QPalette::ColorGroup::Disabled, QPalette::ColorRole::Button, brush);
        palette22.setBrush(QPalette::ColorGroup::Disabled, QPalette::ColorRole::Light, brush);
        palette22.setBrush(QPalette::ColorGroup::Disabled, QPalette::ColorRole::Midlight, brush);
        palette22.setBrush(QPalette::ColorGroup::Disabled, QPalette::ColorRole::Dark, brush);
        palette22.setBrush(QPalette::ColorGroup::Disabled, QPalette::ColorRole::Mid, brush);
        palette22.setBrush(QPalette::ColorGroup::Disabled, QPalette::ColorRole::Text, brush);
        palette22.setBrush(QPalette::ColorGroup::Disabled, QPalette::ColorRole::BrightText, brush6);
        palette22.setBrush(QPalette::ColorGroup::Disabled, QPalette::ColorRole::ButtonText, brush);
        palette22.setBrush(QPalette::ColorGroup::Disabled, QPalette::ColorRole::Base, brush);
        palette22.setBrush(QPalette::ColorGroup::Disabled, QPalette::ColorRole::Window, brush);
        palette22.setBrush(QPalette::ColorGroup::Disabled, QPalette::ColorRole::Shadow, brush);
        palette22.setBrush(QPalette::ColorGroup::Disabled, QPalette::ColorRole::AlternateBase, brush);
        palette22.setBrush(QPalette::ColorGroup::Disabled, QPalette::ColorRole::ToolTipBase, brush7);
        palette22.setBrush(QPalette::ColorGroup::Disabled, QPalette::ColorRole::ToolTipText, brush);
        primaryColorLabel_2->setPalette(palette22);
        primaryColorLabel_2->setAutoFillBackground(true);
        primaryColorLabel_2->setFrameShape(QFrame::Panel);
        primaryColorLabel_2->setFrameShadow(QFrame::Plain);
        primaryColorLabel_2->setLineWidth(0);
        primaryColorLabel_23 = new QLabel(page);
        primaryColorLabel_23->setObjectName("primaryColorLabel_23");
        primaryColorLabel_23->setGeometry(QRect(10, 40, 15, 15));
        sizePolicy1.setHeightForWidth(primaryColorLabel_23->sizePolicy().hasHeightForWidth());
        primaryColorLabel_23->setSizePolicy(sizePolicy1);
        primaryColorLabel_23->setMinimumSize(QSize(15, 15));
        primaryColorLabel_23->setMaximumSize(QSize(5, 5));
        QPalette palette23;
        palette23.setBrush(QPalette::ColorGroup::Active, QPalette::ColorRole::WindowText, brush);
        QBrush brush112(QColor(0, 0, 255, 255));
        brush112.setStyle(Qt::BrushStyle::SolidPattern);
        palette23.setBrush(QPalette::ColorGroup::Active, QPalette::ColorRole::Button, brush112);
        QBrush brush113(QColor(127, 127, 255, 255));
        brush113.setStyle(Qt::BrushStyle::SolidPattern);
        palette23.setBrush(QPalette::ColorGroup::Active, QPalette::ColorRole::Light, brush113);
        QBrush brush114(QColor(63, 63, 255, 255));
        brush114.setStyle(Qt::BrushStyle::SolidPattern);
        palette23.setBrush(QPalette::ColorGroup::Active, QPalette::ColorRole::Midlight, brush114);
        QBrush brush115(QColor(0, 0, 127, 255));
        brush115.setStyle(Qt::BrushStyle::SolidPattern);
        palette23.setBrush(QPalette::ColorGroup::Active, QPalette::ColorRole::Dark, brush115);
        QBrush brush116(QColor(0, 0, 170, 255));
        brush116.setStyle(Qt::BrushStyle::SolidPattern);
        palette23.setBrush(QPalette::ColorGroup::Active, QPalette::ColorRole::Mid, brush116);
        palette23.setBrush(QPalette::ColorGroup::Active, QPalette::ColorRole::Text, brush);
        palette23.setBrush(QPalette::ColorGroup::Active, QPalette::ColorRole::BrightText, brush6);
        palette23.setBrush(QPalette::ColorGroup::Active, QPalette::ColorRole::ButtonText, brush);
        palette23.setBrush(QPalette::ColorGroup::Active, QPalette::ColorRole::Base, brush6);
        palette23.setBrush(QPalette::ColorGroup::Active, QPalette::ColorRole::Window, brush112);
        palette23.setBrush(QPalette::ColorGroup::Active, QPalette::ColorRole::Shadow, brush);
        palette23.setBrush(QPalette::ColorGroup::Active, QPalette::ColorRole::AlternateBase, brush113);
        palette23.setBrush(QPalette::ColorGroup::Active, QPalette::ColorRole::ToolTipBase, brush7);
        palette23.setBrush(QPalette::ColorGroup::Active, QPalette::ColorRole::ToolTipText, brush);
        palette23.setBrush(QPalette::ColorGroup::Inactive, QPalette::ColorRole::WindowText, brush);
        palette23.setBrush(QPalette::ColorGroup::Inactive, QPalette::ColorRole::Button, brush112);
        palette23.setBrush(QPalette::ColorGroup::Inactive, QPalette::ColorRole::Light, brush113);
        palette23.setBrush(QPalette::ColorGroup::Inactive, QPalette::ColorRole::Midlight, brush114);
        palette23.setBrush(QPalette::ColorGroup::Inactive, QPalette::ColorRole::Dark, brush115);
        palette23.setBrush(QPalette::ColorGroup::Inactive, QPalette::ColorRole::Mid, brush116);
        palette23.setBrush(QPalette::ColorGroup::Inactive, QPalette::ColorRole::Text, brush);
        palette23.setBrush(QPalette::ColorGroup::Inactive, QPalette::ColorRole::BrightText, brush6);
        palette23.setBrush(QPalette::ColorGroup::Inactive, QPalette::ColorRole::ButtonText, brush);
        palette23.setBrush(QPalette::ColorGroup::Inactive, QPalette::ColorRole::Base, brush6);
        palette23.setBrush(QPalette::ColorGroup::Inactive, QPalette::ColorRole::Window, brush112);
        palette23.setBrush(QPalette::ColorGroup::Inactive, QPalette::ColorRole::Shadow, brush);
        palette23.setBrush(QPalette::ColorGroup::Inactive, QPalette::ColorRole::AlternateBase, brush113);
        palette23.setBrush(QPalette::ColorGroup::Inactive, QPalette::ColorRole::ToolTipBase, brush7);
        palette23.setBrush(QPalette::ColorGroup::Inactive, QPalette::ColorRole::ToolTipText, brush);
        palette23.setBrush(QPalette::ColorGroup::Disabled, QPalette::ColorRole::WindowText, brush115);
        palette23.setBrush(QPalette::ColorGroup::Disabled, QPalette::ColorRole::Button, brush112);
        palette23.setBrush(QPalette::ColorGroup::Disabled, QPalette::ColorRole::Light, brush113);
        palette23.setBrush(QPalette::ColorGroup::Disabled, QPalette::ColorRole::Midlight, brush114);
        palette23.setBrush(QPalette::ColorGroup::Disabled, QPalette::ColorRole::Dark, brush115);
        palette23.setBrush(QPalette::ColorGroup::Disabled, QPalette::ColorRole::Mid, brush116);
        palette23.setBrush(QPalette::ColorGroup::Disabled, QPalette::ColorRole::Text, brush115);
        palette23.setBrush(QPalette::ColorGroup::Disabled, QPalette::ColorRole::BrightText, brush6);
        palette23.setBrush(QPalette::ColorGroup::Disabled, QPalette::ColorRole::ButtonText, brush115);
        palette23.setBrush(QPalette::ColorGroup::Disabled, QPalette::ColorRole::Base, brush112);
        palette23.setBrush(QPalette::ColorGroup::Disabled, QPalette::ColorRole::Window, brush112);
        palette23.setBrush(QPalette::ColorGroup::Disabled, QPalette::ColorRole::Shadow, brush);
        palette23.setBrush(QPalette::ColorGroup::Disabled, QPalette::ColorRole::AlternateBase, brush112);
        palette23.setBrush(QPalette::ColorGroup::Disabled, QPalette::ColorRole::ToolTipBase, brush7);
        palette23.setBrush(QPalette::ColorGroup::Disabled, QPalette::ColorRole::ToolTipText, brush);
        primaryColorLabel_23->setPalette(palette23);
        primaryColorLabel_23->setAutoFillBackground(true);
        primaryColorLabel_23->setFrameShape(QFrame::Panel);
        primaryColorLabel_23->setFrameShadow(QFrame::Plain);
        primaryColorLabel_23->setLineWidth(0);
        primaryColorLabel_19 = new QLabel(page);
        primaryColorLabel_19->setObjectName("primaryColorLabel_19");
        primaryColorLabel_19->setGeometry(QRect(26, 40, 15, 15));
        sizePolicy1.setHeightForWidth(primaryColorLabel_19->sizePolicy().hasHeightForWidth());
        primaryColorLabel_19->setSizePolicy(sizePolicy1);
        primaryColorLabel_19->setMinimumSize(QSize(15, 15));
        primaryColorLabel_19->setMaximumSize(QSize(5, 5));
        QPalette palette24;
        palette24.setBrush(QPalette::ColorGroup::Active, QPalette::ColorRole::WindowText, brush);
        QBrush brush117(QColor(170, 0, 255, 255));
        brush117.setStyle(Qt::BrushStyle::SolidPattern);
        palette24.setBrush(QPalette::ColorGroup::Active, QPalette::ColorRole::Button, brush117);
        QBrush brush118(QColor(213, 127, 255, 255));
        brush118.setStyle(Qt::BrushStyle::SolidPattern);
        palette24.setBrush(QPalette::ColorGroup::Active, QPalette::ColorRole::Light, brush118);
        QBrush brush119(QColor(191, 63, 255, 255));
        brush119.setStyle(Qt::BrushStyle::SolidPattern);
        palette24.setBrush(QPalette::ColorGroup::Active, QPalette::ColorRole::Midlight, brush119);
        QBrush brush120(QColor(85, 0, 127, 255));
        brush120.setStyle(Qt::BrushStyle::SolidPattern);
        palette24.setBrush(QPalette::ColorGroup::Active, QPalette::ColorRole::Dark, brush120);
        QBrush brush121(QColor(113, 0, 170, 255));
        brush121.setStyle(Qt::BrushStyle::SolidPattern);
        palette24.setBrush(QPalette::ColorGroup::Active, QPalette::ColorRole::Mid, brush121);
        palette24.setBrush(QPalette::ColorGroup::Active, QPalette::ColorRole::Text, brush);
        palette24.setBrush(QPalette::ColorGroup::Active, QPalette::ColorRole::BrightText, brush6);
        palette24.setBrush(QPalette::ColorGroup::Active, QPalette::ColorRole::ButtonText, brush);
        palette24.setBrush(QPalette::ColorGroup::Active, QPalette::ColorRole::Base, brush6);
        palette24.setBrush(QPalette::ColorGroup::Active, QPalette::ColorRole::Window, brush117);
        palette24.setBrush(QPalette::ColorGroup::Active, QPalette::ColorRole::Shadow, brush);
        QBrush brush122(QColor(212, 127, 255, 255));
        brush122.setStyle(Qt::BrushStyle::SolidPattern);
        palette24.setBrush(QPalette::ColorGroup::Active, QPalette::ColorRole::AlternateBase, brush122);
        palette24.setBrush(QPalette::ColorGroup::Active, QPalette::ColorRole::ToolTipBase, brush7);
        palette24.setBrush(QPalette::ColorGroup::Active, QPalette::ColorRole::ToolTipText, brush);
        palette24.setBrush(QPalette::ColorGroup::Inactive, QPalette::ColorRole::WindowText, brush);
        palette24.setBrush(QPalette::ColorGroup::Inactive, QPalette::ColorRole::Button, brush117);
        palette24.setBrush(QPalette::ColorGroup::Inactive, QPalette::ColorRole::Light, brush118);
        palette24.setBrush(QPalette::ColorGroup::Inactive, QPalette::ColorRole::Midlight, brush119);
        palette24.setBrush(QPalette::ColorGroup::Inactive, QPalette::ColorRole::Dark, brush120);
        palette24.setBrush(QPalette::ColorGroup::Inactive, QPalette::ColorRole::Mid, brush121);
        palette24.setBrush(QPalette::ColorGroup::Inactive, QPalette::ColorRole::Text, brush);
        palette24.setBrush(QPalette::ColorGroup::Inactive, QPalette::ColorRole::BrightText, brush6);
        palette24.setBrush(QPalette::ColorGroup::Inactive, QPalette::ColorRole::ButtonText, brush);
        palette24.setBrush(QPalette::ColorGroup::Inactive, QPalette::ColorRole::Base, brush6);
        palette24.setBrush(QPalette::ColorGroup::Inactive, QPalette::ColorRole::Window, brush117);
        palette24.setBrush(QPalette::ColorGroup::Inactive, QPalette::ColorRole::Shadow, brush);
        palette24.setBrush(QPalette::ColorGroup::Inactive, QPalette::ColorRole::AlternateBase, brush122);
        palette24.setBrush(QPalette::ColorGroup::Inactive, QPalette::ColorRole::ToolTipBase, brush7);
        palette24.setBrush(QPalette::ColorGroup::Inactive, QPalette::ColorRole::ToolTipText, brush);
        palette24.setBrush(QPalette::ColorGroup::Disabled, QPalette::ColorRole::WindowText, brush120);
        palette24.setBrush(QPalette::ColorGroup::Disabled, QPalette::ColorRole::Button, brush117);
        palette24.setBrush(QPalette::ColorGroup::Disabled, QPalette::ColorRole::Light, brush118);
        palette24.setBrush(QPalette::ColorGroup::Disabled, QPalette::ColorRole::Midlight, brush119);
        palette24.setBrush(QPalette::ColorGroup::Disabled, QPalette::ColorRole::Dark, brush120);
        palette24.setBrush(QPalette::ColorGroup::Disabled, QPalette::ColorRole::Mid, brush121);
        palette24.setBrush(QPalette::ColorGroup::Disabled, QPalette::ColorRole::Text, brush120);
        palette24.setBrush(QPalette::ColorGroup::Disabled, QPalette::ColorRole::BrightText, brush6);
        palette24.setBrush(QPalette::ColorGroup::Disabled, QPalette::ColorRole::ButtonText, brush120);
        palette24.setBrush(QPalette::ColorGroup::Disabled, QPalette::ColorRole::Base, brush117);
        palette24.setBrush(QPalette::ColorGroup::Disabled, QPalette::ColorRole::Window, brush117);
        palette24.setBrush(QPalette::ColorGroup::Disabled, QPalette::ColorRole::Shadow, brush);
        palette24.setBrush(QPalette::ColorGroup::Disabled, QPalette::ColorRole::AlternateBase, brush117);
        palette24.setBrush(QPalette::ColorGroup::Disabled, QPalette::ColorRole::ToolTipBase, brush7);
        palette24.setBrush(QPalette::ColorGroup::Disabled, QPalette::ColorRole::ToolTipText, brush);
        primaryColorLabel_19->setPalette(palette24);
        primaryColorLabel_19->setAutoFillBackground(true);
        primaryColorLabel_19->setFrameShape(QFrame::Panel);
        primaryColorLabel_19->setFrameShadow(QFrame::Plain);
        primaryColorLabel_19->setLineWidth(0);
        primaryColorLabel_5 = new QLabel(page);
        primaryColorLabel_5->setObjectName("primaryColorLabel_5");
        primaryColorLabel_5->setGeometry(QRect(42, 8, 15, 15));
        sizePolicy1.setHeightForWidth(primaryColorLabel_5->sizePolicy().hasHeightForWidth());
        primaryColorLabel_5->setSizePolicy(sizePolicy1);
        primaryColorLabel_5->setMinimumSize(QSize(15, 15));
        primaryColorLabel_5->setMaximumSize(QSize(5, 5));
        QPalette palette25;
        palette25.setBrush(QPalette::ColorGroup::Active, QPalette::ColorRole::WindowText, brush6);
        QBrush brush123(QColor(0, 85, 0, 255));
        brush123.setStyle(Qt::BrushStyle::SolidPattern);
        palette25.setBrush(QPalette::ColorGroup::Active, QPalette::ColorRole::Button, brush123);
        palette25.setBrush(QPalette::ColorGroup::Active, QPalette::ColorRole::Light, brush42);
        QBrush brush124(QColor(0, 106, 0, 255));
        brush124.setStyle(Qt::BrushStyle::SolidPattern);
        palette25.setBrush(QPalette::ColorGroup::Active, QPalette::ColorRole::Midlight, brush124);
        QBrush brush125(QColor(0, 42, 0, 255));
        brush125.setStyle(Qt::BrushStyle::SolidPattern);
        palette25.setBrush(QPalette::ColorGroup::Active, QPalette::ColorRole::Dark, brush125);
        QBrush brush126(QColor(0, 56, 0, 255));
        brush126.setStyle(Qt::BrushStyle::SolidPattern);
        palette25.setBrush(QPalette::ColorGroup::Active, QPalette::ColorRole::Mid, brush126);
        palette25.setBrush(QPalette::ColorGroup::Active, QPalette::ColorRole::Text, brush6);
        palette25.setBrush(QPalette::ColorGroup::Active, QPalette::ColorRole::BrightText, brush6);
        palette25.setBrush(QPalette::ColorGroup::Active, QPalette::ColorRole::ButtonText, brush6);
        palette25.setBrush(QPalette::ColorGroup::Active, QPalette::ColorRole::Base, brush);
        palette25.setBrush(QPalette::ColorGroup::Active, QPalette::ColorRole::Window, brush123);
        palette25.setBrush(QPalette::ColorGroup::Active, QPalette::ColorRole::Shadow, brush);
        palette25.setBrush(QPalette::ColorGroup::Active, QPalette::ColorRole::AlternateBase, brush125);
        palette25.setBrush(QPalette::ColorGroup::Active, QPalette::ColorRole::ToolTipBase, brush7);
        palette25.setBrush(QPalette::ColorGroup::Active, QPalette::ColorRole::ToolTipText, brush);
        palette25.setBrush(QPalette::ColorGroup::Inactive, QPalette::ColorRole::WindowText, brush6);
        palette25.setBrush(QPalette::ColorGroup::Inactive, QPalette::ColorRole::Button, brush123);
        palette25.setBrush(QPalette::ColorGroup::Inactive, QPalette::ColorRole::Light, brush42);
        palette25.setBrush(QPalette::ColorGroup::Inactive, QPalette::ColorRole::Midlight, brush124);
        palette25.setBrush(QPalette::ColorGroup::Inactive, QPalette::ColorRole::Dark, brush125);
        palette25.setBrush(QPalette::ColorGroup::Inactive, QPalette::ColorRole::Mid, brush126);
        palette25.setBrush(QPalette::ColorGroup::Inactive, QPalette::ColorRole::Text, brush6);
        palette25.setBrush(QPalette::ColorGroup::Inactive, QPalette::ColorRole::BrightText, brush6);
        palette25.setBrush(QPalette::ColorGroup::Inactive, QPalette::ColorRole::ButtonText, brush6);
        palette25.setBrush(QPalette::ColorGroup::Inactive, QPalette::ColorRole::Base, brush);
        palette25.setBrush(QPalette::ColorGroup::Inactive, QPalette::ColorRole::Window, brush123);
        palette25.setBrush(QPalette::ColorGroup::Inactive, QPalette::ColorRole::Shadow, brush);
        palette25.setBrush(QPalette::ColorGroup::Inactive, QPalette::ColorRole::AlternateBase, brush125);
        palette25.setBrush(QPalette::ColorGroup::Inactive, QPalette::ColorRole::ToolTipBase, brush7);
        palette25.setBrush(QPalette::ColorGroup::Inactive, QPalette::ColorRole::ToolTipText, brush);
        palette25.setBrush(QPalette::ColorGroup::Disabled, QPalette::ColorRole::WindowText, brush125);
        palette25.setBrush(QPalette::ColorGroup::Disabled, QPalette::ColorRole::Button, brush123);
        palette25.setBrush(QPalette::ColorGroup::Disabled, QPalette::ColorRole::Light, brush42);
        palette25.setBrush(QPalette::ColorGroup::Disabled, QPalette::ColorRole::Midlight, brush124);
        palette25.setBrush(QPalette::ColorGroup::Disabled, QPalette::ColorRole::Dark, brush125);
        palette25.setBrush(QPalette::ColorGroup::Disabled, QPalette::ColorRole::Mid, brush126);
        palette25.setBrush(QPalette::ColorGroup::Disabled, QPalette::ColorRole::Text, brush125);
        palette25.setBrush(QPalette::ColorGroup::Disabled, QPalette::ColorRole::BrightText, brush6);
        palette25.setBrush(QPalette::ColorGroup::Disabled, QPalette::ColorRole::ButtonText, brush125);
        palette25.setBrush(QPalette::ColorGroup::Disabled, QPalette::ColorRole::Base, brush123);
        palette25.setBrush(QPalette::ColorGroup::Disabled, QPalette::ColorRole::Window, brush123);
        palette25.setBrush(QPalette::ColorGroup::Disabled, QPalette::ColorRole::Shadow, brush);
        palette25.setBrush(QPalette::ColorGroup::Disabled, QPalette::ColorRole::AlternateBase, brush123);
        palette25.setBrush(QPalette::ColorGroup::Disabled, QPalette::ColorRole::ToolTipBase, brush7);
        palette25.setBrush(QPalette::ColorGroup::Disabled, QPalette::ColorRole::ToolTipText, brush);
        primaryColorLabel_5->setPalette(palette25);
        primaryColorLabel_5->setAutoFillBackground(true);
        primaryColorLabel_5->setFrameShape(QFrame::Panel);
        primaryColorLabel_5->setFrameShadow(QFrame::Plain);
        primaryColorLabel_5->setLineWidth(0);
        primaryColorLabel_31 = new QLabel(page);
        primaryColorLabel_31->setObjectName("primaryColorLabel_31");
        primaryColorLabel_31->setGeometry(QRect(10, 56, 15, 15));
        sizePolicy1.setHeightForWidth(primaryColorLabel_31->sizePolicy().hasHeightForWidth());
        primaryColorLabel_31->setSizePolicy(sizePolicy1);
        primaryColorLabel_31->setMinimumSize(QSize(15, 15));
        primaryColorLabel_31->setMaximumSize(QSize(5, 5));
        QPalette palette26;
        palette26.setBrush(QPalette::ColorGroup::Active, QPalette::ColorRole::WindowText, brush6);
        palette26.setBrush(QPalette::ColorGroup::Active, QPalette::ColorRole::Button, brush68);
        palette26.setBrush(QPalette::ColorGroup::Active, QPalette::ColorRole::Light, brush4);
        QBrush brush127(QColor(106, 0, 0, 255));
        brush127.setStyle(Qt::BrushStyle::SolidPattern);
        palette26.setBrush(QPalette::ColorGroup::Active, QPalette::ColorRole::Midlight, brush127);
        QBrush brush128(QColor(42, 0, 0, 255));
        brush128.setStyle(Qt::BrushStyle::SolidPattern);
        palette26.setBrush(QPalette::ColorGroup::Active, QPalette::ColorRole::Dark, brush128);
        QBrush brush129(QColor(56, 0, 0, 255));
        brush129.setStyle(Qt::BrushStyle::SolidPattern);
        palette26.setBrush(QPalette::ColorGroup::Active, QPalette::ColorRole::Mid, brush129);
        palette26.setBrush(QPalette::ColorGroup::Active, QPalette::ColorRole::Text, brush6);
        palette26.setBrush(QPalette::ColorGroup::Active, QPalette::ColorRole::BrightText, brush6);
        palette26.setBrush(QPalette::ColorGroup::Active, QPalette::ColorRole::ButtonText, brush6);
        palette26.setBrush(QPalette::ColorGroup::Active, QPalette::ColorRole::Base, brush);
        palette26.setBrush(QPalette::ColorGroup::Active, QPalette::ColorRole::Window, brush68);
        palette26.setBrush(QPalette::ColorGroup::Active, QPalette::ColorRole::Shadow, brush);
        palette26.setBrush(QPalette::ColorGroup::Active, QPalette::ColorRole::AlternateBase, brush128);
        palette26.setBrush(QPalette::ColorGroup::Active, QPalette::ColorRole::ToolTipBase, brush7);
        palette26.setBrush(QPalette::ColorGroup::Active, QPalette::ColorRole::ToolTipText, brush);
        palette26.setBrush(QPalette::ColorGroup::Inactive, QPalette::ColorRole::WindowText, brush6);
        palette26.setBrush(QPalette::ColorGroup::Inactive, QPalette::ColorRole::Button, brush68);
        palette26.setBrush(QPalette::ColorGroup::Inactive, QPalette::ColorRole::Light, brush4);
        palette26.setBrush(QPalette::ColorGroup::Inactive, QPalette::ColorRole::Midlight, brush127);
        palette26.setBrush(QPalette::ColorGroup::Inactive, QPalette::ColorRole::Dark, brush128);
        palette26.setBrush(QPalette::ColorGroup::Inactive, QPalette::ColorRole::Mid, brush129);
        palette26.setBrush(QPalette::ColorGroup::Inactive, QPalette::ColorRole::Text, brush6);
        palette26.setBrush(QPalette::ColorGroup::Inactive, QPalette::ColorRole::BrightText, brush6);
        palette26.setBrush(QPalette::ColorGroup::Inactive, QPalette::ColorRole::ButtonText, brush6);
        palette26.setBrush(QPalette::ColorGroup::Inactive, QPalette::ColorRole::Base, brush);
        palette26.setBrush(QPalette::ColorGroup::Inactive, QPalette::ColorRole::Window, brush68);
        palette26.setBrush(QPalette::ColorGroup::Inactive, QPalette::ColorRole::Shadow, brush);
        palette26.setBrush(QPalette::ColorGroup::Inactive, QPalette::ColorRole::AlternateBase, brush128);
        palette26.setBrush(QPalette::ColorGroup::Inactive, QPalette::ColorRole::ToolTipBase, brush7);
        palette26.setBrush(QPalette::ColorGroup::Inactive, QPalette::ColorRole::ToolTipText, brush);
        palette26.setBrush(QPalette::ColorGroup::Disabled, QPalette::ColorRole::WindowText, brush128);
        palette26.setBrush(QPalette::ColorGroup::Disabled, QPalette::ColorRole::Button, brush68);
        palette26.setBrush(QPalette::ColorGroup::Disabled, QPalette::ColorRole::Light, brush4);
        palette26.setBrush(QPalette::ColorGroup::Disabled, QPalette::ColorRole::Midlight, brush127);
        palette26.setBrush(QPalette::ColorGroup::Disabled, QPalette::ColorRole::Dark, brush128);
        palette26.setBrush(QPalette::ColorGroup::Disabled, QPalette::ColorRole::Mid, brush129);
        palette26.setBrush(QPalette::ColorGroup::Disabled, QPalette::ColorRole::Text, brush128);
        palette26.setBrush(QPalette::ColorGroup::Disabled, QPalette::ColorRole::BrightText, brush6);
        palette26.setBrush(QPalette::ColorGroup::Disabled, QPalette::ColorRole::ButtonText, brush128);
        palette26.setBrush(QPalette::ColorGroup::Disabled, QPalette::ColorRole::Base, brush68);
        palette26.setBrush(QPalette::ColorGroup::Disabled, QPalette::ColorRole::Window, brush68);
        palette26.setBrush(QPalette::ColorGroup::Disabled, QPalette::ColorRole::Shadow, brush);
        palette26.setBrush(QPalette::ColorGroup::Disabled, QPalette::ColorRole::AlternateBase, brush68);
        palette26.setBrush(QPalette::ColorGroup::Disabled, QPalette::ColorRole::ToolTipBase, brush7);
        palette26.setBrush(QPalette::ColorGroup::Disabled, QPalette::ColorRole::ToolTipText, brush);
        primaryColorLabel_31->setPalette(palette26);
        primaryColorLabel_31->setAutoFillBackground(true);
        primaryColorLabel_31->setFrameShape(QFrame::Panel);
        primaryColorLabel_31->setFrameShadow(QFrame::Plain);
        primaryColorLabel_31->setLineWidth(0);
        primaryColorLabel_20 = new QLabel(page);
        primaryColorLabel_20->setObjectName("primaryColorLabel_20");
        primaryColorLabel_20->setGeometry(QRect(74, 40, 15, 15));
        sizePolicy1.setHeightForWidth(primaryColorLabel_20->sizePolicy().hasHeightForWidth());
        primaryColorLabel_20->setSizePolicy(sizePolicy1);
        primaryColorLabel_20->setMinimumSize(QSize(15, 15));
        primaryColorLabel_20->setMaximumSize(QSize(5, 5));
        QPalette palette27;
        palette27.setBrush(QPalette::ColorGroup::Active, QPalette::ColorRole::WindowText, brush);
        QBrush brush130(QColor(0, 170, 255, 255));
        brush130.setStyle(Qt::BrushStyle::SolidPattern);
        palette27.setBrush(QPalette::ColorGroup::Active, QPalette::ColorRole::Button, brush130);
        QBrush brush131(QColor(127, 213, 255, 255));
        brush131.setStyle(Qt::BrushStyle::SolidPattern);
        palette27.setBrush(QPalette::ColorGroup::Active, QPalette::ColorRole::Light, brush131);
        QBrush brush132(QColor(63, 191, 255, 255));
        brush132.setStyle(Qt::BrushStyle::SolidPattern);
        palette27.setBrush(QPalette::ColorGroup::Active, QPalette::ColorRole::Midlight, brush132);
        palette27.setBrush(QPalette::ColorGroup::Active, QPalette::ColorRole::Dark, brush23);
        QBrush brush133(QColor(0, 113, 170, 255));
        brush133.setStyle(Qt::BrushStyle::SolidPattern);
        palette27.setBrush(QPalette::ColorGroup::Active, QPalette::ColorRole::Mid, brush133);
        palette27.setBrush(QPalette::ColorGroup::Active, QPalette::ColorRole::Text, brush);
        palette27.setBrush(QPalette::ColorGroup::Active, QPalette::ColorRole::BrightText, brush6);
        palette27.setBrush(QPalette::ColorGroup::Active, QPalette::ColorRole::ButtonText, brush);
        palette27.setBrush(QPalette::ColorGroup::Active, QPalette::ColorRole::Base, brush6);
        palette27.setBrush(QPalette::ColorGroup::Active, QPalette::ColorRole::Window, brush130);
        palette27.setBrush(QPalette::ColorGroup::Active, QPalette::ColorRole::Shadow, brush);
        QBrush brush134(QColor(127, 212, 255, 255));
        brush134.setStyle(Qt::BrushStyle::SolidPattern);
        palette27.setBrush(QPalette::ColorGroup::Active, QPalette::ColorRole::AlternateBase, brush134);
        palette27.setBrush(QPalette::ColorGroup::Active, QPalette::ColorRole::ToolTipBase, brush7);
        palette27.setBrush(QPalette::ColorGroup::Active, QPalette::ColorRole::ToolTipText, brush);
        palette27.setBrush(QPalette::ColorGroup::Inactive, QPalette::ColorRole::WindowText, brush);
        palette27.setBrush(QPalette::ColorGroup::Inactive, QPalette::ColorRole::Button, brush130);
        palette27.setBrush(QPalette::ColorGroup::Inactive, QPalette::ColorRole::Light, brush131);
        palette27.setBrush(QPalette::ColorGroup::Inactive, QPalette::ColorRole::Midlight, brush132);
        palette27.setBrush(QPalette::ColorGroup::Inactive, QPalette::ColorRole::Dark, brush23);
        palette27.setBrush(QPalette::ColorGroup::Inactive, QPalette::ColorRole::Mid, brush133);
        palette27.setBrush(QPalette::ColorGroup::Inactive, QPalette::ColorRole::Text, brush);
        palette27.setBrush(QPalette::ColorGroup::Inactive, QPalette::ColorRole::BrightText, brush6);
        palette27.setBrush(QPalette::ColorGroup::Inactive, QPalette::ColorRole::ButtonText, brush);
        palette27.setBrush(QPalette::ColorGroup::Inactive, QPalette::ColorRole::Base, brush6);
        palette27.setBrush(QPalette::ColorGroup::Inactive, QPalette::ColorRole::Window, brush130);
        palette27.setBrush(QPalette::ColorGroup::Inactive, QPalette::ColorRole::Shadow, brush);
        palette27.setBrush(QPalette::ColorGroup::Inactive, QPalette::ColorRole::AlternateBase, brush134);
        palette27.setBrush(QPalette::ColorGroup::Inactive, QPalette::ColorRole::ToolTipBase, brush7);
        palette27.setBrush(QPalette::ColorGroup::Inactive, QPalette::ColorRole::ToolTipText, brush);
        palette27.setBrush(QPalette::ColorGroup::Disabled, QPalette::ColorRole::WindowText, brush23);
        palette27.setBrush(QPalette::ColorGroup::Disabled, QPalette::ColorRole::Button, brush130);
        palette27.setBrush(QPalette::ColorGroup::Disabled, QPalette::ColorRole::Light, brush131);
        palette27.setBrush(QPalette::ColorGroup::Disabled, QPalette::ColorRole::Midlight, brush132);
        palette27.setBrush(QPalette::ColorGroup::Disabled, QPalette::ColorRole::Dark, brush23);
        palette27.setBrush(QPalette::ColorGroup::Disabled, QPalette::ColorRole::Mid, brush133);
        palette27.setBrush(QPalette::ColorGroup::Disabled, QPalette::ColorRole::Text, brush23);
        palette27.setBrush(QPalette::ColorGroup::Disabled, QPalette::ColorRole::BrightText, brush6);
        palette27.setBrush(QPalette::ColorGroup::Disabled, QPalette::ColorRole::ButtonText, brush23);
        palette27.setBrush(QPalette::ColorGroup::Disabled, QPalette::ColorRole::Base, brush130);
        palette27.setBrush(QPalette::ColorGroup::Disabled, QPalette::ColorRole::Window, brush130);
        palette27.setBrush(QPalette::ColorGroup::Disabled, QPalette::ColorRole::Shadow, brush);
        palette27.setBrush(QPalette::ColorGroup::Disabled, QPalette::ColorRole::AlternateBase, brush130);
        palette27.setBrush(QPalette::ColorGroup::Disabled, QPalette::ColorRole::ToolTipBase, brush7);
        palette27.setBrush(QPalette::ColorGroup::Disabled, QPalette::ColorRole::ToolTipText, brush);
        primaryColorLabel_20->setPalette(palette27);
        primaryColorLabel_20->setAutoFillBackground(true);
        primaryColorLabel_20->setFrameShape(QFrame::Panel);
        primaryColorLabel_20->setFrameShadow(QFrame::Plain);
        primaryColorLabel_20->setLineWidth(0);
        primaryColorLabel_24 = new QLabel(page);
        primaryColorLabel_24->setObjectName("primaryColorLabel_24");
        primaryColorLabel_24->setGeometry(QRect(42, 40, 15, 15));
        sizePolicy1.setHeightForWidth(primaryColorLabel_24->sizePolicy().hasHeightForWidth());
        primaryColorLabel_24->setSizePolicy(sizePolicy1);
        primaryColorLabel_24->setMinimumSize(QSize(15, 15));
        primaryColorLabel_24->setMaximumSize(QSize(5, 5));
        QPalette palette28;
        palette28.setBrush(QPalette::ColorGroup::Active, QPalette::ColorRole::WindowText, brush);
        QBrush brush135(QColor(0, 85, 255, 255));
        brush135.setStyle(Qt::BrushStyle::SolidPattern);
        palette28.setBrush(QPalette::ColorGroup::Active, QPalette::ColorRole::Button, brush135);
        QBrush brush136(QColor(127, 170, 255, 255));
        brush136.setStyle(Qt::BrushStyle::SolidPattern);
        palette28.setBrush(QPalette::ColorGroup::Active, QPalette::ColorRole::Light, brush136);
        QBrush brush137(QColor(63, 127, 255, 255));
        brush137.setStyle(Qt::BrushStyle::SolidPattern);
        palette28.setBrush(QPalette::ColorGroup::Active, QPalette::ColorRole::Midlight, brush137);
        QBrush brush138(QColor(0, 42, 127, 255));
        brush138.setStyle(Qt::BrushStyle::SolidPattern);
        palette28.setBrush(QPalette::ColorGroup::Active, QPalette::ColorRole::Dark, brush138);
        QBrush brush139(QColor(0, 56, 170, 255));
        brush139.setStyle(Qt::BrushStyle::SolidPattern);
        palette28.setBrush(QPalette::ColorGroup::Active, QPalette::ColorRole::Mid, brush139);
        palette28.setBrush(QPalette::ColorGroup::Active, QPalette::ColorRole::Text, brush);
        palette28.setBrush(QPalette::ColorGroup::Active, QPalette::ColorRole::BrightText, brush6);
        palette28.setBrush(QPalette::ColorGroup::Active, QPalette::ColorRole::ButtonText, brush);
        palette28.setBrush(QPalette::ColorGroup::Active, QPalette::ColorRole::Base, brush6);
        palette28.setBrush(QPalette::ColorGroup::Active, QPalette::ColorRole::Window, brush135);
        palette28.setBrush(QPalette::ColorGroup::Active, QPalette::ColorRole::Shadow, brush);
        palette28.setBrush(QPalette::ColorGroup::Active, QPalette::ColorRole::AlternateBase, brush136);
        palette28.setBrush(QPalette::ColorGroup::Active, QPalette::ColorRole::ToolTipBase, brush7);
        palette28.setBrush(QPalette::ColorGroup::Active, QPalette::ColorRole::ToolTipText, brush);
        palette28.setBrush(QPalette::ColorGroup::Inactive, QPalette::ColorRole::WindowText, brush);
        palette28.setBrush(QPalette::ColorGroup::Inactive, QPalette::ColorRole::Button, brush135);
        palette28.setBrush(QPalette::ColorGroup::Inactive, QPalette::ColorRole::Light, brush136);
        palette28.setBrush(QPalette::ColorGroup::Inactive, QPalette::ColorRole::Midlight, brush137);
        palette28.setBrush(QPalette::ColorGroup::Inactive, QPalette::ColorRole::Dark, brush138);
        palette28.setBrush(QPalette::ColorGroup::Inactive, QPalette::ColorRole::Mid, brush139);
        palette28.setBrush(QPalette::ColorGroup::Inactive, QPalette::ColorRole::Text, brush);
        palette28.setBrush(QPalette::ColorGroup::Inactive, QPalette::ColorRole::BrightText, brush6);
        palette28.setBrush(QPalette::ColorGroup::Inactive, QPalette::ColorRole::ButtonText, brush);
        palette28.setBrush(QPalette::ColorGroup::Inactive, QPalette::ColorRole::Base, brush6);
        palette28.setBrush(QPalette::ColorGroup::Inactive, QPalette::ColorRole::Window, brush135);
        palette28.setBrush(QPalette::ColorGroup::Inactive, QPalette::ColorRole::Shadow, brush);
        palette28.setBrush(QPalette::ColorGroup::Inactive, QPalette::ColorRole::AlternateBase, brush136);
        palette28.setBrush(QPalette::ColorGroup::Inactive, QPalette::ColorRole::ToolTipBase, brush7);
        palette28.setBrush(QPalette::ColorGroup::Inactive, QPalette::ColorRole::ToolTipText, brush);
        palette28.setBrush(QPalette::ColorGroup::Disabled, QPalette::ColorRole::WindowText, brush138);
        palette28.setBrush(QPalette::ColorGroup::Disabled, QPalette::ColorRole::Button, brush135);
        palette28.setBrush(QPalette::ColorGroup::Disabled, QPalette::ColorRole::Light, brush136);
        palette28.setBrush(QPalette::ColorGroup::Disabled, QPalette::ColorRole::Midlight, brush137);
        palette28.setBrush(QPalette::ColorGroup::Disabled, QPalette::ColorRole::Dark, brush138);
        palette28.setBrush(QPalette::ColorGroup::Disabled, QPalette::ColorRole::Mid, brush139);
        palette28.setBrush(QPalette::ColorGroup::Disabled, QPalette::ColorRole::Text, brush138);
        palette28.setBrush(QPalette::ColorGroup::Disabled, QPalette::ColorRole::BrightText, brush6);
        palette28.setBrush(QPalette::ColorGroup::Disabled, QPalette::ColorRole::ButtonText, brush138);
        palette28.setBrush(QPalette::ColorGroup::Disabled, QPalette::ColorRole::Base, brush135);
        palette28.setBrush(QPalette::ColorGroup::Disabled, QPalette::ColorRole::Window, brush135);
        palette28.setBrush(QPalette::ColorGroup::Disabled, QPalette::ColorRole::Shadow, brush);
        palette28.setBrush(QPalette::ColorGroup::Disabled, QPalette::ColorRole::AlternateBase, brush135);
        palette28.setBrush(QPalette::ColorGroup::Disabled, QPalette::ColorRole::ToolTipBase, brush7);
        palette28.setBrush(QPalette::ColorGroup::Disabled, QPalette::ColorRole::ToolTipText, brush);
        primaryColorLabel_24->setPalette(palette28);
        primaryColorLabel_24->setAutoFillBackground(true);
        primaryColorLabel_24->setFrameShape(QFrame::Panel);
        primaryColorLabel_24->setFrameShadow(QFrame::Plain);
        primaryColorLabel_24->setLineWidth(0);
        primaryColorLabel_32 = new QLabel(page);
        primaryColorLabel_32->setObjectName("primaryColorLabel_32");
        primaryColorLabel_32->setGeometry(QRect(42, 56, 15, 15));
        sizePolicy1.setHeightForWidth(primaryColorLabel_32->sizePolicy().hasHeightForWidth());
        primaryColorLabel_32->setSizePolicy(sizePolicy1);
        primaryColorLabel_32->setMinimumSize(QSize(15, 15));
        primaryColorLabel_32->setMaximumSize(QSize(5, 5));
        QPalette palette29;
        palette29.setBrush(QPalette::ColorGroup::Active, QPalette::ColorRole::WindowText, brush6);
        palette29.setBrush(QPalette::ColorGroup::Active, QPalette::ColorRole::Button, brush91);
        palette29.setBrush(QPalette::ColorGroup::Active, QPalette::ColorRole::Light, brush111);
        QBrush brush140(QColor(106, 106, 0, 255));
        brush140.setStyle(Qt::BrushStyle::SolidPattern);
        palette29.setBrush(QPalette::ColorGroup::Active, QPalette::ColorRole::Midlight, brush140);
        QBrush brush141(QColor(42, 42, 0, 255));
        brush141.setStyle(Qt::BrushStyle::SolidPattern);
        palette29.setBrush(QPalette::ColorGroup::Active, QPalette::ColorRole::Dark, brush141);
        QBrush brush142(QColor(56, 56, 0, 255));
        brush142.setStyle(Qt::BrushStyle::SolidPattern);
        palette29.setBrush(QPalette::ColorGroup::Active, QPalette::ColorRole::Mid, brush142);
        palette29.setBrush(QPalette::ColorGroup::Active, QPalette::ColorRole::Text, brush6);
        palette29.setBrush(QPalette::ColorGroup::Active, QPalette::ColorRole::BrightText, brush6);
        palette29.setBrush(QPalette::ColorGroup::Active, QPalette::ColorRole::ButtonText, brush6);
        palette29.setBrush(QPalette::ColorGroup::Active, QPalette::ColorRole::Base, brush);
        palette29.setBrush(QPalette::ColorGroup::Active, QPalette::ColorRole::Window, brush91);
        palette29.setBrush(QPalette::ColorGroup::Active, QPalette::ColorRole::Shadow, brush);
        palette29.setBrush(QPalette::ColorGroup::Active, QPalette::ColorRole::AlternateBase, brush141);
        palette29.setBrush(QPalette::ColorGroup::Active, QPalette::ColorRole::ToolTipBase, brush7);
        palette29.setBrush(QPalette::ColorGroup::Active, QPalette::ColorRole::ToolTipText, brush);
        palette29.setBrush(QPalette::ColorGroup::Inactive, QPalette::ColorRole::WindowText, brush6);
        palette29.setBrush(QPalette::ColorGroup::Inactive, QPalette::ColorRole::Button, brush91);
        palette29.setBrush(QPalette::ColorGroup::Inactive, QPalette::ColorRole::Light, brush111);
        palette29.setBrush(QPalette::ColorGroup::Inactive, QPalette::ColorRole::Midlight, brush140);
        palette29.setBrush(QPalette::ColorGroup::Inactive, QPalette::ColorRole::Dark, brush141);
        palette29.setBrush(QPalette::ColorGroup::Inactive, QPalette::ColorRole::Mid, brush142);
        palette29.setBrush(QPalette::ColorGroup::Inactive, QPalette::ColorRole::Text, brush6);
        palette29.setBrush(QPalette::ColorGroup::Inactive, QPalette::ColorRole::BrightText, brush6);
        palette29.setBrush(QPalette::ColorGroup::Inactive, QPalette::ColorRole::ButtonText, brush6);
        palette29.setBrush(QPalette::ColorGroup::Inactive, QPalette::ColorRole::Base, brush);
        palette29.setBrush(QPalette::ColorGroup::Inactive, QPalette::ColorRole::Window, brush91);
        palette29.setBrush(QPalette::ColorGroup::Inactive, QPalette::ColorRole::Shadow, brush);
        palette29.setBrush(QPalette::ColorGroup::Inactive, QPalette::ColorRole::AlternateBase, brush141);
        palette29.setBrush(QPalette::ColorGroup::Inactive, QPalette::ColorRole::ToolTipBase, brush7);
        palette29.setBrush(QPalette::ColorGroup::Inactive, QPalette::ColorRole::ToolTipText, brush);
        palette29.setBrush(QPalette::ColorGroup::Disabled, QPalette::ColorRole::WindowText, brush141);
        palette29.setBrush(QPalette::ColorGroup::Disabled, QPalette::ColorRole::Button, brush91);
        palette29.setBrush(QPalette::ColorGroup::Disabled, QPalette::ColorRole::Light, brush111);
        palette29.setBrush(QPalette::ColorGroup::Disabled, QPalette::ColorRole::Midlight, brush140);
        palette29.setBrush(QPalette::ColorGroup::Disabled, QPalette::ColorRole::Dark, brush141);
        palette29.setBrush(QPalette::ColorGroup::Disabled, QPalette::ColorRole::Mid, brush142);
        palette29.setBrush(QPalette::ColorGroup::Disabled, QPalette::ColorRole::Text, brush141);
        palette29.setBrush(QPalette::ColorGroup::Disabled, QPalette::ColorRole::BrightText, brush6);
        palette29.setBrush(QPalette::ColorGroup::Disabled, QPalette::ColorRole::ButtonText, brush141);
        palette29.setBrush(QPalette::ColorGroup::Disabled, QPalette::ColorRole::Base, brush91);
        palette29.setBrush(QPalette::ColorGroup::Disabled, QPalette::ColorRole::Window, brush91);
        palette29.setBrush(QPalette::ColorGroup::Disabled, QPalette::ColorRole::Shadow, brush);
        palette29.setBrush(QPalette::ColorGroup::Disabled, QPalette::ColorRole::AlternateBase, brush91);
        palette29.setBrush(QPalette::ColorGroup::Disabled, QPalette::ColorRole::ToolTipBase, brush7);
        palette29.setBrush(QPalette::ColorGroup::Disabled, QPalette::ColorRole::ToolTipText, brush);
        primaryColorLabel_32->setPalette(palette29);
        primaryColorLabel_32->setAutoFillBackground(true);
        primaryColorLabel_32->setFrameShape(QFrame::Panel);
        primaryColorLabel_32->setFrameShadow(QFrame::Plain);
        primaryColorLabel_32->setLineWidth(0);
        primaryColorLabel_17 = new QLabel(page);
        primaryColorLabel_17->setObjectName("primaryColorLabel_17");
        primaryColorLabel_17->setGeometry(QRect(90, 24, 15, 15));
        sizePolicy1.setHeightForWidth(primaryColorLabel_17->sizePolicy().hasHeightForWidth());
        primaryColorLabel_17->setSizePolicy(sizePolicy1);
        primaryColorLabel_17->setMinimumSize(QSize(15, 15));
        primaryColorLabel_17->setMaximumSize(QSize(5, 5));
        QPalette palette30;
        palette30.setBrush(QPalette::ColorGroup::Active, QPalette::ColorRole::WindowText, brush);
        QBrush brush143(QColor(170, 170, 127, 255));
        brush143.setStyle(Qt::BrushStyle::SolidPattern);
        palette30.setBrush(QPalette::ColorGroup::Active, QPalette::ColorRole::Button, brush143);
        QBrush brush144(QColor(255, 255, 191, 255));
        brush144.setStyle(Qt::BrushStyle::SolidPattern);
        palette30.setBrush(QPalette::ColorGroup::Active, QPalette::ColorRole::Light, brush144);
        QBrush brush145(QColor(212, 212, 159, 255));
        brush145.setStyle(Qt::BrushStyle::SolidPattern);
        palette30.setBrush(QPalette::ColorGroup::Active, QPalette::ColorRole::Midlight, brush145);
        QBrush brush146(QColor(85, 85, 63, 255));
        brush146.setStyle(Qt::BrushStyle::SolidPattern);
        palette30.setBrush(QPalette::ColorGroup::Active, QPalette::ColorRole::Dark, brush146);
        QBrush brush147(QColor(113, 113, 84, 255));
        brush147.setStyle(Qt::BrushStyle::SolidPattern);
        palette30.setBrush(QPalette::ColorGroup::Active, QPalette::ColorRole::Mid, brush147);
        palette30.setBrush(QPalette::ColorGroup::Active, QPalette::ColorRole::Text, brush);
        palette30.setBrush(QPalette::ColorGroup::Active, QPalette::ColorRole::BrightText, brush6);
        palette30.setBrush(QPalette::ColorGroup::Active, QPalette::ColorRole::ButtonText, brush);
        palette30.setBrush(QPalette::ColorGroup::Active, QPalette::ColorRole::Base, brush6);
        palette30.setBrush(QPalette::ColorGroup::Active, QPalette::ColorRole::Window, brush143);
        palette30.setBrush(QPalette::ColorGroup::Active, QPalette::ColorRole::Shadow, brush);
        QBrush brush148(QColor(212, 212, 191, 255));
        brush148.setStyle(Qt::BrushStyle::SolidPattern);
        palette30.setBrush(QPalette::ColorGroup::Active, QPalette::ColorRole::AlternateBase, brush148);
        palette30.setBrush(QPalette::ColorGroup::Active, QPalette::ColorRole::ToolTipBase, brush7);
        palette30.setBrush(QPalette::ColorGroup::Active, QPalette::ColorRole::ToolTipText, brush);
        palette30.setBrush(QPalette::ColorGroup::Inactive, QPalette::ColorRole::WindowText, brush);
        palette30.setBrush(QPalette::ColorGroup::Inactive, QPalette::ColorRole::Button, brush143);
        palette30.setBrush(QPalette::ColorGroup::Inactive, QPalette::ColorRole::Light, brush144);
        palette30.setBrush(QPalette::ColorGroup::Inactive, QPalette::ColorRole::Midlight, brush145);
        palette30.setBrush(QPalette::ColorGroup::Inactive, QPalette::ColorRole::Dark, brush146);
        palette30.setBrush(QPalette::ColorGroup::Inactive, QPalette::ColorRole::Mid, brush147);
        palette30.setBrush(QPalette::ColorGroup::Inactive, QPalette::ColorRole::Text, brush);
        palette30.setBrush(QPalette::ColorGroup::Inactive, QPalette::ColorRole::BrightText, brush6);
        palette30.setBrush(QPalette::ColorGroup::Inactive, QPalette::ColorRole::ButtonText, brush);
        palette30.setBrush(QPalette::ColorGroup::Inactive, QPalette::ColorRole::Base, brush6);
        palette30.setBrush(QPalette::ColorGroup::Inactive, QPalette::ColorRole::Window, brush143);
        palette30.setBrush(QPalette::ColorGroup::Inactive, QPalette::ColorRole::Shadow, brush);
        palette30.setBrush(QPalette::ColorGroup::Inactive, QPalette::ColorRole::AlternateBase, brush148);
        palette30.setBrush(QPalette::ColorGroup::Inactive, QPalette::ColorRole::ToolTipBase, brush7);
        palette30.setBrush(QPalette::ColorGroup::Inactive, QPalette::ColorRole::ToolTipText, brush);
        palette30.setBrush(QPalette::ColorGroup::Disabled, QPalette::ColorRole::WindowText, brush146);
        palette30.setBrush(QPalette::ColorGroup::Disabled, QPalette::ColorRole::Button, brush143);
        palette30.setBrush(QPalette::ColorGroup::Disabled, QPalette::ColorRole::Light, brush144);
        palette30.setBrush(QPalette::ColorGroup::Disabled, QPalette::ColorRole::Midlight, brush145);
        palette30.setBrush(QPalette::ColorGroup::Disabled, QPalette::ColorRole::Dark, brush146);
        palette30.setBrush(QPalette::ColorGroup::Disabled, QPalette::ColorRole::Mid, brush147);
        palette30.setBrush(QPalette::ColorGroup::Disabled, QPalette::ColorRole::Text, brush146);
        palette30.setBrush(QPalette::ColorGroup::Disabled, QPalette::ColorRole::BrightText, brush6);
        palette30.setBrush(QPalette::ColorGroup::Disabled, QPalette::ColorRole::ButtonText, brush146);
        palette30.setBrush(QPalette::ColorGroup::Disabled, QPalette::ColorRole::Base, brush143);
        palette30.setBrush(QPalette::ColorGroup::Disabled, QPalette::ColorRole::Window, brush143);
        palette30.setBrush(QPalette::ColorGroup::Disabled, QPalette::ColorRole::Shadow, brush);
        palette30.setBrush(QPalette::ColorGroup::Disabled, QPalette::ColorRole::AlternateBase, brush143);
        palette30.setBrush(QPalette::ColorGroup::Disabled, QPalette::ColorRole::ToolTipBase, brush7);
        palette30.setBrush(QPalette::ColorGroup::Disabled, QPalette::ColorRole::ToolTipText, brush);
        primaryColorLabel_17->setPalette(palette30);
        primaryColorLabel_17->setAutoFillBackground(true);
        primaryColorLabel_17->setFrameShape(QFrame::Panel);
        primaryColorLabel_17->setFrameShadow(QFrame::Plain);
        primaryColorLabel_17->setLineWidth(0);
        primaryColorLabel_6 = new QLabel(page);
        primaryColorLabel_6->setObjectName("primaryColorLabel_6");
        primaryColorLabel_6->setGeometry(QRect(122, 8, 15, 15));
        sizePolicy1.setHeightForWidth(primaryColorLabel_6->sizePolicy().hasHeightForWidth());
        primaryColorLabel_6->setSizePolicy(sizePolicy1);
        primaryColorLabel_6->setMinimumSize(QSize(15, 15));
        primaryColorLabel_6->setMaximumSize(QSize(5, 5));
        QPalette palette31;
        palette31.setBrush(QPalette::ColorGroup::Active, QPalette::ColorRole::WindowText, brush);
        QBrush brush149(QColor(170, 255, 0, 255));
        brush149.setStyle(Qt::BrushStyle::SolidPattern);
        palette31.setBrush(QPalette::ColorGroup::Active, QPalette::ColorRole::Button, brush149);
        QBrush brush150(QColor(213, 255, 127, 255));
        brush150.setStyle(Qt::BrushStyle::SolidPattern);
        palette31.setBrush(QPalette::ColorGroup::Active, QPalette::ColorRole::Light, brush150);
        QBrush brush151(QColor(191, 255, 63, 255));
        brush151.setStyle(Qt::BrushStyle::SolidPattern);
        palette31.setBrush(QPalette::ColorGroup::Active, QPalette::ColorRole::Midlight, brush151);
        QBrush brush152(QColor(85, 127, 0, 255));
        brush152.setStyle(Qt::BrushStyle::SolidPattern);
        palette31.setBrush(QPalette::ColorGroup::Active, QPalette::ColorRole::Dark, brush152);
        QBrush brush153(QColor(113, 170, 0, 255));
        brush153.setStyle(Qt::BrushStyle::SolidPattern);
        palette31.setBrush(QPalette::ColorGroup::Active, QPalette::ColorRole::Mid, brush153);
        palette31.setBrush(QPalette::ColorGroup::Active, QPalette::ColorRole::Text, brush);
        palette31.setBrush(QPalette::ColorGroup::Active, QPalette::ColorRole::BrightText, brush6);
        palette31.setBrush(QPalette::ColorGroup::Active, QPalette::ColorRole::ButtonText, brush);
        palette31.setBrush(QPalette::ColorGroup::Active, QPalette::ColorRole::Base, brush6);
        palette31.setBrush(QPalette::ColorGroup::Active, QPalette::ColorRole::Window, brush149);
        palette31.setBrush(QPalette::ColorGroup::Active, QPalette::ColorRole::Shadow, brush);
        QBrush brush154(QColor(212, 255, 127, 255));
        brush154.setStyle(Qt::BrushStyle::SolidPattern);
        palette31.setBrush(QPalette::ColorGroup::Active, QPalette::ColorRole::AlternateBase, brush154);
        palette31.setBrush(QPalette::ColorGroup::Active, QPalette::ColorRole::ToolTipBase, brush7);
        palette31.setBrush(QPalette::ColorGroup::Active, QPalette::ColorRole::ToolTipText, brush);
        palette31.setBrush(QPalette::ColorGroup::Inactive, QPalette::ColorRole::WindowText, brush);
        palette31.setBrush(QPalette::ColorGroup::Inactive, QPalette::ColorRole::Button, brush149);
        palette31.setBrush(QPalette::ColorGroup::Inactive, QPalette::ColorRole::Light, brush150);
        palette31.setBrush(QPalette::ColorGroup::Inactive, QPalette::ColorRole::Midlight, brush151);
        palette31.setBrush(QPalette::ColorGroup::Inactive, QPalette::ColorRole::Dark, brush152);
        palette31.setBrush(QPalette::ColorGroup::Inactive, QPalette::ColorRole::Mid, brush153);
        palette31.setBrush(QPalette::ColorGroup::Inactive, QPalette::ColorRole::Text, brush);
        palette31.setBrush(QPalette::ColorGroup::Inactive, QPalette::ColorRole::BrightText, brush6);
        palette31.setBrush(QPalette::ColorGroup::Inactive, QPalette::ColorRole::ButtonText, brush);
        palette31.setBrush(QPalette::ColorGroup::Inactive, QPalette::ColorRole::Base, brush6);
        palette31.setBrush(QPalette::ColorGroup::Inactive, QPalette::ColorRole::Window, brush149);
        palette31.setBrush(QPalette::ColorGroup::Inactive, QPalette::ColorRole::Shadow, brush);
        palette31.setBrush(QPalette::ColorGroup::Inactive, QPalette::ColorRole::AlternateBase, brush154);
        palette31.setBrush(QPalette::ColorGroup::Inactive, QPalette::ColorRole::ToolTipBase, brush7);
        palette31.setBrush(QPalette::ColorGroup::Inactive, QPalette::ColorRole::ToolTipText, brush);
        palette31.setBrush(QPalette::ColorGroup::Disabled, QPalette::ColorRole::WindowText, brush152);
        palette31.setBrush(QPalette::ColorGroup::Disabled, QPalette::ColorRole::Button, brush149);
        palette31.setBrush(QPalette::ColorGroup::Disabled, QPalette::ColorRole::Light, brush150);
        palette31.setBrush(QPalette::ColorGroup::Disabled, QPalette::ColorRole::Midlight, brush151);
        palette31.setBrush(QPalette::ColorGroup::Disabled, QPalette::ColorRole::Dark, brush152);
        palette31.setBrush(QPalette::ColorGroup::Disabled, QPalette::ColorRole::Mid, brush153);
        palette31.setBrush(QPalette::ColorGroup::Disabled, QPalette::ColorRole::Text, brush152);
        palette31.setBrush(QPalette::ColorGroup::Disabled, QPalette::ColorRole::BrightText, brush6);
        palette31.setBrush(QPalette::ColorGroup::Disabled, QPalette::ColorRole::ButtonText, brush152);
        palette31.setBrush(QPalette::ColorGroup::Disabled, QPalette::ColorRole::Base, brush149);
        palette31.setBrush(QPalette::ColorGroup::Disabled, QPalette::ColorRole::Window, brush149);
        palette31.setBrush(QPalette::ColorGroup::Disabled, QPalette::ColorRole::Shadow, brush);
        palette31.setBrush(QPalette::ColorGroup::Disabled, QPalette::ColorRole::AlternateBase, brush149);
        palette31.setBrush(QPalette::ColorGroup::Disabled, QPalette::ColorRole::ToolTipBase, brush7);
        palette31.setBrush(QPalette::ColorGroup::Disabled, QPalette::ColorRole::ToolTipText, brush);
        primaryColorLabel_6->setPalette(palette31);
        primaryColorLabel_6->setAutoFillBackground(true);
        primaryColorLabel_6->setFrameShape(QFrame::Panel);
        primaryColorLabel_6->setFrameShadow(QFrame::Plain);
        primaryColorLabel_6->setLineWidth(0);
        primaryColorLabel_41 = new QLabel(page);
        primaryColorLabel_41->setObjectName("primaryColorLabel_41");
        primaryColorLabel_41->setGeometry(QRect(90, 72, 15, 15));
        sizePolicy1.setHeightForWidth(primaryColorLabel_41->sizePolicy().hasHeightForWidth());
        primaryColorLabel_41->setSizePolicy(sizePolicy1);
        primaryColorLabel_41->setMinimumSize(QSize(15, 15));
        primaryColorLabel_41->setMaximumSize(QSize(5, 5));
        QPalette palette32;
        palette32.setBrush(QPalette::ColorGroup::Active, QPalette::ColorRole::WindowText, brush);
        palette32.setBrush(QPalette::ColorGroup::Active, QPalette::ColorRole::Button, brush81);
        palette32.setBrush(QPalette::ColorGroup::Active, QPalette::ColorRole::Light, brush6);
        QBrush brush155(QColor(255, 212, 255, 255));
        brush155.setStyle(Qt::BrushStyle::SolidPattern);
        palette32.setBrush(QPalette::ColorGroup::Active, QPalette::ColorRole::Midlight, brush155);
        QBrush brush156(QColor(127, 85, 127, 255));
        brush156.setStyle(Qt::BrushStyle::SolidPattern);
        palette32.setBrush(QPalette::ColorGroup::Active, QPalette::ColorRole::Dark, brush156);
        QBrush brush157(QColor(170, 113, 170, 255));
        brush157.setStyle(Qt::BrushStyle::SolidPattern);
        palette32.setBrush(QPalette::ColorGroup::Active, QPalette::ColorRole::Mid, brush157);
        palette32.setBrush(QPalette::ColorGroup::Active, QPalette::ColorRole::Text, brush);
        palette32.setBrush(QPalette::ColorGroup::Active, QPalette::ColorRole::BrightText, brush6);
        palette32.setBrush(QPalette::ColorGroup::Active, QPalette::ColorRole::ButtonText, brush);
        palette32.setBrush(QPalette::ColorGroup::Active, QPalette::ColorRole::Base, brush6);
        palette32.setBrush(QPalette::ColorGroup::Active, QPalette::ColorRole::Window, brush81);
        palette32.setBrush(QPalette::ColorGroup::Active, QPalette::ColorRole::Shadow, brush);
        palette32.setBrush(QPalette::ColorGroup::Active, QPalette::ColorRole::AlternateBase, brush155);
        palette32.setBrush(QPalette::ColorGroup::Active, QPalette::ColorRole::ToolTipBase, brush7);
        palette32.setBrush(QPalette::ColorGroup::Active, QPalette::ColorRole::ToolTipText, brush);
        palette32.setBrush(QPalette::ColorGroup::Inactive, QPalette::ColorRole::WindowText, brush);
        palette32.setBrush(QPalette::ColorGroup::Inactive, QPalette::ColorRole::Button, brush81);
        palette32.setBrush(QPalette::ColorGroup::Inactive, QPalette::ColorRole::Light, brush6);
        palette32.setBrush(QPalette::ColorGroup::Inactive, QPalette::ColorRole::Midlight, brush155);
        palette32.setBrush(QPalette::ColorGroup::Inactive, QPalette::ColorRole::Dark, brush156);
        palette32.setBrush(QPalette::ColorGroup::Inactive, QPalette::ColorRole::Mid, brush157);
        palette32.setBrush(QPalette::ColorGroup::Inactive, QPalette::ColorRole::Text, brush);
        palette32.setBrush(QPalette::ColorGroup::Inactive, QPalette::ColorRole::BrightText, brush6);
        palette32.setBrush(QPalette::ColorGroup::Inactive, QPalette::ColorRole::ButtonText, brush);
        palette32.setBrush(QPalette::ColorGroup::Inactive, QPalette::ColorRole::Base, brush6);
        palette32.setBrush(QPalette::ColorGroup::Inactive, QPalette::ColorRole::Window, brush81);
        palette32.setBrush(QPalette::ColorGroup::Inactive, QPalette::ColorRole::Shadow, brush);
        palette32.setBrush(QPalette::ColorGroup::Inactive, QPalette::ColorRole::AlternateBase, brush155);
        palette32.setBrush(QPalette::ColorGroup::Inactive, QPalette::ColorRole::ToolTipBase, brush7);
        palette32.setBrush(QPalette::ColorGroup::Inactive, QPalette::ColorRole::ToolTipText, brush);
        palette32.setBrush(QPalette::ColorGroup::Disabled, QPalette::ColorRole::WindowText, brush156);
        palette32.setBrush(QPalette::ColorGroup::Disabled, QPalette::ColorRole::Button, brush81);
        palette32.setBrush(QPalette::ColorGroup::Disabled, QPalette::ColorRole::Light, brush6);
        palette32.setBrush(QPalette::ColorGroup::Disabled, QPalette::ColorRole::Midlight, brush155);
        palette32.setBrush(QPalette::ColorGroup::Disabled, QPalette::ColorRole::Dark, brush156);
        palette32.setBrush(QPalette::ColorGroup::Disabled, QPalette::ColorRole::Mid, brush157);
        palette32.setBrush(QPalette::ColorGroup::Disabled, QPalette::ColorRole::Text, brush156);
        palette32.setBrush(QPalette::ColorGroup::Disabled, QPalette::ColorRole::BrightText, brush6);
        palette32.setBrush(QPalette::ColorGroup::Disabled, QPalette::ColorRole::ButtonText, brush156);
        palette32.setBrush(QPalette::ColorGroup::Disabled, QPalette::ColorRole::Base, brush81);
        palette32.setBrush(QPalette::ColorGroup::Disabled, QPalette::ColorRole::Window, brush81);
        palette32.setBrush(QPalette::ColorGroup::Disabled, QPalette::ColorRole::Shadow, brush);
        palette32.setBrush(QPalette::ColorGroup::Disabled, QPalette::ColorRole::AlternateBase, brush81);
        palette32.setBrush(QPalette::ColorGroup::Disabled, QPalette::ColorRole::ToolTipBase, brush7);
        palette32.setBrush(QPalette::ColorGroup::Disabled, QPalette::ColorRole::ToolTipText, brush);
        primaryColorLabel_41->setPalette(palette32);
        primaryColorLabel_41->setAutoFillBackground(true);
        primaryColorLabel_41->setFrameShape(QFrame::Panel);
        primaryColorLabel_41->setFrameShadow(QFrame::Plain);
        primaryColorLabel_41->setLineWidth(0);
        primaryColorLabel_30 = new QLabel(page);
        primaryColorLabel_30->setObjectName("primaryColorLabel_30");
        primaryColorLabel_30->setGeometry(QRect(106, 56, 15, 15));
        sizePolicy1.setHeightForWidth(primaryColorLabel_30->sizePolicy().hasHeightForWidth());
        primaryColorLabel_30->setSizePolicy(sizePolicy1);
        primaryColorLabel_30->setMinimumSize(QSize(15, 15));
        primaryColorLabel_30->setMaximumSize(QSize(5, 5));
        QPalette palette33;
        palette33.setBrush(QPalette::ColorGroup::Active, QPalette::ColorRole::WindowText, brush);
        QBrush brush158(QColor(85, 255, 0, 255));
        brush158.setStyle(Qt::BrushStyle::SolidPattern);
        palette33.setBrush(QPalette::ColorGroup::Active, QPalette::ColorRole::Button, brush158);
        palette33.setBrush(QPalette::ColorGroup::Active, QPalette::ColorRole::Light, brush49);
        QBrush brush159(QColor(127, 255, 63, 255));
        brush159.setStyle(Qt::BrushStyle::SolidPattern);
        palette33.setBrush(QPalette::ColorGroup::Active, QPalette::ColorRole::Midlight, brush159);
        QBrush brush160(QColor(42, 127, 0, 255));
        brush160.setStyle(Qt::BrushStyle::SolidPattern);
        palette33.setBrush(QPalette::ColorGroup::Active, QPalette::ColorRole::Dark, brush160);
        QBrush brush161(QColor(56, 170, 0, 255));
        brush161.setStyle(Qt::BrushStyle::SolidPattern);
        palette33.setBrush(QPalette::ColorGroup::Active, QPalette::ColorRole::Mid, brush161);
        palette33.setBrush(QPalette::ColorGroup::Active, QPalette::ColorRole::Text, brush);
        palette33.setBrush(QPalette::ColorGroup::Active, QPalette::ColorRole::BrightText, brush6);
        palette33.setBrush(QPalette::ColorGroup::Active, QPalette::ColorRole::ButtonText, brush);
        palette33.setBrush(QPalette::ColorGroup::Active, QPalette::ColorRole::Base, brush6);
        palette33.setBrush(QPalette::ColorGroup::Active, QPalette::ColorRole::Window, brush158);
        palette33.setBrush(QPalette::ColorGroup::Active, QPalette::ColorRole::Shadow, brush);
        palette33.setBrush(QPalette::ColorGroup::Active, QPalette::ColorRole::AlternateBase, brush49);
        palette33.setBrush(QPalette::ColorGroup::Active, QPalette::ColorRole::ToolTipBase, brush7);
        palette33.setBrush(QPalette::ColorGroup::Active, QPalette::ColorRole::ToolTipText, brush);
        palette33.setBrush(QPalette::ColorGroup::Inactive, QPalette::ColorRole::WindowText, brush);
        palette33.setBrush(QPalette::ColorGroup::Inactive, QPalette::ColorRole::Button, brush158);
        palette33.setBrush(QPalette::ColorGroup::Inactive, QPalette::ColorRole::Light, brush49);
        palette33.setBrush(QPalette::ColorGroup::Inactive, QPalette::ColorRole::Midlight, brush159);
        palette33.setBrush(QPalette::ColorGroup::Inactive, QPalette::ColorRole::Dark, brush160);
        palette33.setBrush(QPalette::ColorGroup::Inactive, QPalette::ColorRole::Mid, brush161);
        palette33.setBrush(QPalette::ColorGroup::Inactive, QPalette::ColorRole::Text, brush);
        palette33.setBrush(QPalette::ColorGroup::Inactive, QPalette::ColorRole::BrightText, brush6);
        palette33.setBrush(QPalette::ColorGroup::Inactive, QPalette::ColorRole::ButtonText, brush);
        palette33.setBrush(QPalette::ColorGroup::Inactive, QPalette::ColorRole::Base, brush6);
        palette33.setBrush(QPalette::ColorGroup::Inactive, QPalette::ColorRole::Window, brush158);
        palette33.setBrush(QPalette::ColorGroup::Inactive, QPalette::ColorRole::Shadow, brush);
        palette33.setBrush(QPalette::ColorGroup::Inactive, QPalette::ColorRole::AlternateBase, brush49);
        palette33.setBrush(QPalette::ColorGroup::Inactive, QPalette::ColorRole::ToolTipBase, brush7);
        palette33.setBrush(QPalette::ColorGroup::Inactive, QPalette::ColorRole::ToolTipText, brush);
        palette33.setBrush(QPalette::ColorGroup::Disabled, QPalette::ColorRole::WindowText, brush160);
        palette33.setBrush(QPalette::ColorGroup::Disabled, QPalette::ColorRole::Button, brush158);
        palette33.setBrush(QPalette::ColorGroup::Disabled, QPalette::ColorRole::Light, brush49);
        palette33.setBrush(QPalette::ColorGroup::Disabled, QPalette::ColorRole::Midlight, brush159);
        palette33.setBrush(QPalette::ColorGroup::Disabled, QPalette::ColorRole::Dark, brush160);
        palette33.setBrush(QPalette::ColorGroup::Disabled, QPalette::ColorRole::Mid, brush161);
        palette33.setBrush(QPalette::ColorGroup::Disabled, QPalette::ColorRole::Text, brush160);
        palette33.setBrush(QPalette::ColorGroup::Disabled, QPalette::ColorRole::BrightText, brush6);
        palette33.setBrush(QPalette::ColorGroup::Disabled, QPalette::ColorRole::ButtonText, brush160);
        palette33.setBrush(QPalette::ColorGroup::Disabled, QPalette::ColorRole::Base, brush158);
        palette33.setBrush(QPalette::ColorGroup::Disabled, QPalette::ColorRole::Window, brush158);
        palette33.setBrush(QPalette::ColorGroup::Disabled, QPalette::ColorRole::Shadow, brush);
        palette33.setBrush(QPalette::ColorGroup::Disabled, QPalette::ColorRole::AlternateBase, brush158);
        palette33.setBrush(QPalette::ColorGroup::Disabled, QPalette::ColorRole::ToolTipBase, brush7);
        palette33.setBrush(QPalette::ColorGroup::Disabled, QPalette::ColorRole::ToolTipText, brush);
        primaryColorLabel_30->setPalette(palette33);
        primaryColorLabel_30->setAutoFillBackground(true);
        primaryColorLabel_30->setFrameShape(QFrame::Panel);
        primaryColorLabel_30->setFrameShadow(QFrame::Plain);
        primaryColorLabel_30->setLineWidth(0);
        primaryColorLabel_14 = new QLabel(page);
        primaryColorLabel_14->setObjectName("primaryColorLabel_14");
        primaryColorLabel_14->setGeometry(QRect(106, 24, 15, 15));
        sizePolicy1.setHeightForWidth(primaryColorLabel_14->sizePolicy().hasHeightForWidth());
        primaryColorLabel_14->setSizePolicy(sizePolicy1);
        primaryColorLabel_14->setMinimumSize(QSize(15, 15));
        primaryColorLabel_14->setMaximumSize(QSize(5, 5));
        QPalette palette34;
        palette34.setBrush(QPalette::ColorGroup::Active, QPalette::ColorRole::WindowText, brush);
        QBrush brush162(QColor(0, 255, 127, 255));
        brush162.setStyle(Qt::BrushStyle::SolidPattern);
        palette34.setBrush(QPalette::ColorGroup::Active, QPalette::ColorRole::Button, brush162);
        QBrush brush163(QColor(127, 255, 191, 255));
        brush163.setStyle(Qt::BrushStyle::SolidPattern);
        palette34.setBrush(QPalette::ColorGroup::Active, QPalette::ColorRole::Light, brush163);
        QBrush brush164(QColor(63, 255, 159, 255));
        brush164.setStyle(Qt::BrushStyle::SolidPattern);
        palette34.setBrush(QPalette::ColorGroup::Active, QPalette::ColorRole::Midlight, brush164);
        QBrush brush165(QColor(0, 127, 63, 255));
        brush165.setStyle(Qt::BrushStyle::SolidPattern);
        palette34.setBrush(QPalette::ColorGroup::Active, QPalette::ColorRole::Dark, brush165);
        QBrush brush166(QColor(0, 170, 84, 255));
        brush166.setStyle(Qt::BrushStyle::SolidPattern);
        palette34.setBrush(QPalette::ColorGroup::Active, QPalette::ColorRole::Mid, brush166);
        palette34.setBrush(QPalette::ColorGroup::Active, QPalette::ColorRole::Text, brush);
        palette34.setBrush(QPalette::ColorGroup::Active, QPalette::ColorRole::BrightText, brush6);
        palette34.setBrush(QPalette::ColorGroup::Active, QPalette::ColorRole::ButtonText, brush);
        palette34.setBrush(QPalette::ColorGroup::Active, QPalette::ColorRole::Base, brush6);
        palette34.setBrush(QPalette::ColorGroup::Active, QPalette::ColorRole::Window, brush162);
        palette34.setBrush(QPalette::ColorGroup::Active, QPalette::ColorRole::Shadow, brush);
        palette34.setBrush(QPalette::ColorGroup::Active, QPalette::ColorRole::AlternateBase, brush163);
        palette34.setBrush(QPalette::ColorGroup::Active, QPalette::ColorRole::ToolTipBase, brush7);
        palette34.setBrush(QPalette::ColorGroup::Active, QPalette::ColorRole::ToolTipText, brush);
        palette34.setBrush(QPalette::ColorGroup::Inactive, QPalette::ColorRole::WindowText, brush);
        palette34.setBrush(QPalette::ColorGroup::Inactive, QPalette::ColorRole::Button, brush162);
        palette34.setBrush(QPalette::ColorGroup::Inactive, QPalette::ColorRole::Light, brush163);
        palette34.setBrush(QPalette::ColorGroup::Inactive, QPalette::ColorRole::Midlight, brush164);
        palette34.setBrush(QPalette::ColorGroup::Inactive, QPalette::ColorRole::Dark, brush165);
        palette34.setBrush(QPalette::ColorGroup::Inactive, QPalette::ColorRole::Mid, brush166);
        palette34.setBrush(QPalette::ColorGroup::Inactive, QPalette::ColorRole::Text, brush);
        palette34.setBrush(QPalette::ColorGroup::Inactive, QPalette::ColorRole::BrightText, brush6);
        palette34.setBrush(QPalette::ColorGroup::Inactive, QPalette::ColorRole::ButtonText, brush);
        palette34.setBrush(QPalette::ColorGroup::Inactive, QPalette::ColorRole::Base, brush6);
        palette34.setBrush(QPalette::ColorGroup::Inactive, QPalette::ColorRole::Window, brush162);
        palette34.setBrush(QPalette::ColorGroup::Inactive, QPalette::ColorRole::Shadow, brush);
        palette34.setBrush(QPalette::ColorGroup::Inactive, QPalette::ColorRole::AlternateBase, brush163);
        palette34.setBrush(QPalette::ColorGroup::Inactive, QPalette::ColorRole::ToolTipBase, brush7);
        palette34.setBrush(QPalette::ColorGroup::Inactive, QPalette::ColorRole::ToolTipText, brush);
        palette34.setBrush(QPalette::ColorGroup::Disabled, QPalette::ColorRole::WindowText, brush165);
        palette34.setBrush(QPalette::ColorGroup::Disabled, QPalette::ColorRole::Button, brush162);
        palette34.setBrush(QPalette::ColorGroup::Disabled, QPalette::ColorRole::Light, brush163);
        palette34.setBrush(QPalette::ColorGroup::Disabled, QPalette::ColorRole::Midlight, brush164);
        palette34.setBrush(QPalette::ColorGroup::Disabled, QPalette::ColorRole::Dark, brush165);
        palette34.setBrush(QPalette::ColorGroup::Disabled, QPalette::ColorRole::Mid, brush166);
        palette34.setBrush(QPalette::ColorGroup::Disabled, QPalette::ColorRole::Text, brush165);
        palette34.setBrush(QPalette::ColorGroup::Disabled, QPalette::ColorRole::BrightText, brush6);
        palette34.setBrush(QPalette::ColorGroup::Disabled, QPalette::ColorRole::ButtonText, brush165);
        palette34.setBrush(QPalette::ColorGroup::Disabled, QPalette::ColorRole::Base, brush162);
        palette34.setBrush(QPalette::ColorGroup::Disabled, QPalette::ColorRole::Window, brush162);
        palette34.setBrush(QPalette::ColorGroup::Disabled, QPalette::ColorRole::Shadow, brush);
        palette34.setBrush(QPalette::ColorGroup::Disabled, QPalette::ColorRole::AlternateBase, brush162);
        palette34.setBrush(QPalette::ColorGroup::Disabled, QPalette::ColorRole::ToolTipBase, brush7);
        palette34.setBrush(QPalette::ColorGroup::Disabled, QPalette::ColorRole::ToolTipText, brush);
        primaryColorLabel_14->setPalette(palette34);
        primaryColorLabel_14->setAutoFillBackground(true);
        primaryColorLabel_14->setFrameShape(QFrame::Panel);
        primaryColorLabel_14->setFrameShadow(QFrame::Plain);
        primaryColorLabel_14->setLineWidth(0);
        primaryColorLabel_15 = new QLabel(page);
        primaryColorLabel_15->setObjectName("primaryColorLabel_15");
        primaryColorLabel_15->setGeometry(QRect(10, 24, 15, 15));
        sizePolicy1.setHeightForWidth(primaryColorLabel_15->sizePolicy().hasHeightForWidth());
        primaryColorLabel_15->setSizePolicy(sizePolicy1);
        primaryColorLabel_15->setMinimumSize(QSize(15, 15));
        primaryColorLabel_15->setMaximumSize(QSize(5, 5));
        QPalette palette35;
        palette35.setBrush(QPalette::ColorGroup::Active, QPalette::ColorRole::WindowText, brush6);
        palette35.setBrush(QPalette::ColorGroup::Active, QPalette::ColorRole::Button, brush115);
        QBrush brush167(QColor(0, 0, 191, 255));
        brush167.setStyle(Qt::BrushStyle::SolidPattern);
        palette35.setBrush(QPalette::ColorGroup::Active, QPalette::ColorRole::Light, brush167);
        QBrush brush168(QColor(0, 0, 159, 255));
        brush168.setStyle(Qt::BrushStyle::SolidPattern);
        palette35.setBrush(QPalette::ColorGroup::Active, QPalette::ColorRole::Midlight, brush168);
        QBrush brush169(QColor(0, 0, 63, 255));
        brush169.setStyle(Qt::BrushStyle::SolidPattern);
        palette35.setBrush(QPalette::ColorGroup::Active, QPalette::ColorRole::Dark, brush169);
        QBrush brush170(QColor(0, 0, 84, 255));
        brush170.setStyle(Qt::BrushStyle::SolidPattern);
        palette35.setBrush(QPalette::ColorGroup::Active, QPalette::ColorRole::Mid, brush170);
        palette35.setBrush(QPalette::ColorGroup::Active, QPalette::ColorRole::Text, brush6);
        palette35.setBrush(QPalette::ColorGroup::Active, QPalette::ColorRole::BrightText, brush6);
        palette35.setBrush(QPalette::ColorGroup::Active, QPalette::ColorRole::ButtonText, brush6);
        palette35.setBrush(QPalette::ColorGroup::Active, QPalette::ColorRole::Base, brush);
        palette35.setBrush(QPalette::ColorGroup::Active, QPalette::ColorRole::Window, brush115);
        palette35.setBrush(QPalette::ColorGroup::Active, QPalette::ColorRole::Shadow, brush);
        palette35.setBrush(QPalette::ColorGroup::Active, QPalette::ColorRole::AlternateBase, brush169);
        palette35.setBrush(QPalette::ColorGroup::Active, QPalette::ColorRole::ToolTipBase, brush7);
        palette35.setBrush(QPalette::ColorGroup::Active, QPalette::ColorRole::ToolTipText, brush);
        palette35.setBrush(QPalette::ColorGroup::Inactive, QPalette::ColorRole::WindowText, brush6);
        palette35.setBrush(QPalette::ColorGroup::Inactive, QPalette::ColorRole::Button, brush115);
        palette35.setBrush(QPalette::ColorGroup::Inactive, QPalette::ColorRole::Light, brush167);
        palette35.setBrush(QPalette::ColorGroup::Inactive, QPalette::ColorRole::Midlight, brush168);
        palette35.setBrush(QPalette::ColorGroup::Inactive, QPalette::ColorRole::Dark, brush169);
        palette35.setBrush(QPalette::ColorGroup::Inactive, QPalette::ColorRole::Mid, brush170);
        palette35.setBrush(QPalette::ColorGroup::Inactive, QPalette::ColorRole::Text, brush6);
        palette35.setBrush(QPalette::ColorGroup::Inactive, QPalette::ColorRole::BrightText, brush6);
        palette35.setBrush(QPalette::ColorGroup::Inactive, QPalette::ColorRole::ButtonText, brush6);
        palette35.setBrush(QPalette::ColorGroup::Inactive, QPalette::ColorRole::Base, brush);
        palette35.setBrush(QPalette::ColorGroup::Inactive, QPalette::ColorRole::Window, brush115);
        palette35.setBrush(QPalette::ColorGroup::Inactive, QPalette::ColorRole::Shadow, brush);
        palette35.setBrush(QPalette::ColorGroup::Inactive, QPalette::ColorRole::AlternateBase, brush169);
        palette35.setBrush(QPalette::ColorGroup::Inactive, QPalette::ColorRole::ToolTipBase, brush7);
        palette35.setBrush(QPalette::ColorGroup::Inactive, QPalette::ColorRole::ToolTipText, brush);
        palette35.setBrush(QPalette::ColorGroup::Disabled, QPalette::ColorRole::WindowText, brush169);
        palette35.setBrush(QPalette::ColorGroup::Disabled, QPalette::ColorRole::Button, brush115);
        palette35.setBrush(QPalette::ColorGroup::Disabled, QPalette::ColorRole::Light, brush167);
        palette35.setBrush(QPalette::ColorGroup::Disabled, QPalette::ColorRole::Midlight, brush168);
        palette35.setBrush(QPalette::ColorGroup::Disabled, QPalette::ColorRole::Dark, brush169);
        palette35.setBrush(QPalette::ColorGroup::Disabled, QPalette::ColorRole::Mid, brush170);
        palette35.setBrush(QPalette::ColorGroup::Disabled, QPalette::ColorRole::Text, brush169);
        palette35.setBrush(QPalette::ColorGroup::Disabled, QPalette::ColorRole::BrightText, brush6);
        palette35.setBrush(QPalette::ColorGroup::Disabled, QPalette::ColorRole::ButtonText, brush169);
        palette35.setBrush(QPalette::ColorGroup::Disabled, QPalette::ColorRole::Base, brush115);
        palette35.setBrush(QPalette::ColorGroup::Disabled, QPalette::ColorRole::Window, brush115);
        palette35.setBrush(QPalette::ColorGroup::Disabled, QPalette::ColorRole::Shadow, brush);
        palette35.setBrush(QPalette::ColorGroup::Disabled, QPalette::ColorRole::AlternateBase, brush115);
        palette35.setBrush(QPalette::ColorGroup::Disabled, QPalette::ColorRole::ToolTipBase, brush7);
        palette35.setBrush(QPalette::ColorGroup::Disabled, QPalette::ColorRole::ToolTipText, brush);
        primaryColorLabel_15->setPalette(palette35);
        primaryColorLabel_15->setAutoFillBackground(true);
        primaryColorLabel_15->setFrameShape(QFrame::Panel);
        primaryColorLabel_15->setFrameShadow(QFrame::Plain);
        primaryColorLabel_15->setLineWidth(0);
        primaryColorLabel_11 = new QLabel(page);
        primaryColorLabel_11->setObjectName("primaryColorLabel_11");
        primaryColorLabel_11->setGeometry(QRect(26, 24, 15, 15));
        sizePolicy1.setHeightForWidth(primaryColorLabel_11->sizePolicy().hasHeightForWidth());
        primaryColorLabel_11->setSizePolicy(sizePolicy1);
        primaryColorLabel_11->setMinimumSize(QSize(15, 15));
        primaryColorLabel_11->setMaximumSize(QSize(5, 5));
        QPalette palette36;
        palette36.setBrush(QPalette::ColorGroup::Active, QPalette::ColorRole::WindowText, brush);
        QBrush brush171(QColor(170, 0, 127, 255));
        brush171.setStyle(Qt::BrushStyle::SolidPattern);
        palette36.setBrush(QPalette::ColorGroup::Active, QPalette::ColorRole::Button, brush171);
        QBrush brush172(QColor(255, 0, 191, 255));
        brush172.setStyle(Qt::BrushStyle::SolidPattern);
        palette36.setBrush(QPalette::ColorGroup::Active, QPalette::ColorRole::Light, brush172);
        QBrush brush173(QColor(212, 0, 159, 255));
        brush173.setStyle(Qt::BrushStyle::SolidPattern);
        palette36.setBrush(QPalette::ColorGroup::Active, QPalette::ColorRole::Midlight, brush173);
        QBrush brush174(QColor(85, 0, 63, 255));
        brush174.setStyle(Qt::BrushStyle::SolidPattern);
        palette36.setBrush(QPalette::ColorGroup::Active, QPalette::ColorRole::Dark, brush174);
        QBrush brush175(QColor(113, 0, 84, 255));
        brush175.setStyle(Qt::BrushStyle::SolidPattern);
        palette36.setBrush(QPalette::ColorGroup::Active, QPalette::ColorRole::Mid, brush175);
        palette36.setBrush(QPalette::ColorGroup::Active, QPalette::ColorRole::Text, brush);
        palette36.setBrush(QPalette::ColorGroup::Active, QPalette::ColorRole::BrightText, brush6);
        palette36.setBrush(QPalette::ColorGroup::Active, QPalette::ColorRole::ButtonText, brush);
        palette36.setBrush(QPalette::ColorGroup::Active, QPalette::ColorRole::Base, brush6);
        palette36.setBrush(QPalette::ColorGroup::Active, QPalette::ColorRole::Window, brush171);
        palette36.setBrush(QPalette::ColorGroup::Active, QPalette::ColorRole::Shadow, brush);
        QBrush brush176(QColor(212, 127, 191, 255));
        brush176.setStyle(Qt::BrushStyle::SolidPattern);
        palette36.setBrush(QPalette::ColorGroup::Active, QPalette::ColorRole::AlternateBase, brush176);
        palette36.setBrush(QPalette::ColorGroup::Active, QPalette::ColorRole::ToolTipBase, brush7);
        palette36.setBrush(QPalette::ColorGroup::Active, QPalette::ColorRole::ToolTipText, brush);
        palette36.setBrush(QPalette::ColorGroup::Inactive, QPalette::ColorRole::WindowText, brush);
        palette36.setBrush(QPalette::ColorGroup::Inactive, QPalette::ColorRole::Button, brush171);
        palette36.setBrush(QPalette::ColorGroup::Inactive, QPalette::ColorRole::Light, brush172);
        palette36.setBrush(QPalette::ColorGroup::Inactive, QPalette::ColorRole::Midlight, brush173);
        palette36.setBrush(QPalette::ColorGroup::Inactive, QPalette::ColorRole::Dark, brush174);
        palette36.setBrush(QPalette::ColorGroup::Inactive, QPalette::ColorRole::Mid, brush175);
        palette36.setBrush(QPalette::ColorGroup::Inactive, QPalette::ColorRole::Text, brush);
        palette36.setBrush(QPalette::ColorGroup::Inactive, QPalette::ColorRole::BrightText, brush6);
        palette36.setBrush(QPalette::ColorGroup::Inactive, QPalette::ColorRole::ButtonText, brush);
        palette36.setBrush(QPalette::ColorGroup::Inactive, QPalette::ColorRole::Base, brush6);
        palette36.setBrush(QPalette::ColorGroup::Inactive, QPalette::ColorRole::Window, brush171);
        palette36.setBrush(QPalette::ColorGroup::Inactive, QPalette::ColorRole::Shadow, brush);
        palette36.setBrush(QPalette::ColorGroup::Inactive, QPalette::ColorRole::AlternateBase, brush176);
        palette36.setBrush(QPalette::ColorGroup::Inactive, QPalette::ColorRole::ToolTipBase, brush7);
        palette36.setBrush(QPalette::ColorGroup::Inactive, QPalette::ColorRole::ToolTipText, brush);
        palette36.setBrush(QPalette::ColorGroup::Disabled, QPalette::ColorRole::WindowText, brush174);
        palette36.setBrush(QPalette::ColorGroup::Disabled, QPalette::ColorRole::Button, brush171);
        palette36.setBrush(QPalette::ColorGroup::Disabled, QPalette::ColorRole::Light, brush172);
        palette36.setBrush(QPalette::ColorGroup::Disabled, QPalette::ColorRole::Midlight, brush173);
        palette36.setBrush(QPalette::ColorGroup::Disabled, QPalette::ColorRole::Dark, brush174);
        palette36.setBrush(QPalette::ColorGroup::Disabled, QPalette::ColorRole::Mid, brush175);
        palette36.setBrush(QPalette::ColorGroup::Disabled, QPalette::ColorRole::Text, brush174);
        palette36.setBrush(QPalette::ColorGroup::Disabled, QPalette::ColorRole::BrightText, brush6);
        palette36.setBrush(QPalette::ColorGroup::Disabled, QPalette::ColorRole::ButtonText, brush174);
        palette36.setBrush(QPalette::ColorGroup::Disabled, QPalette::ColorRole::Base, brush171);
        palette36.setBrush(QPalette::ColorGroup::Disabled, QPalette::ColorRole::Window, brush171);
        palette36.setBrush(QPalette::ColorGroup::Disabled, QPalette::ColorRole::Shadow, brush);
        palette36.setBrush(QPalette::ColorGroup::Disabled, QPalette::ColorRole::AlternateBase, brush171);
        palette36.setBrush(QPalette::ColorGroup::Disabled, QPalette::ColorRole::ToolTipBase, brush7);
        palette36.setBrush(QPalette::ColorGroup::Disabled, QPalette::ColorRole::ToolTipText, brush);
        primaryColorLabel_11->setPalette(palette36);
        primaryColorLabel_11->setAutoFillBackground(true);
        primaryColorLabel_11->setFrameShape(QFrame::Panel);
        primaryColorLabel_11->setFrameShadow(QFrame::Plain);
        primaryColorLabel_11->setLineWidth(0);
        primaryColorLabel_26 = new QLabel(page);
        primaryColorLabel_26->setObjectName("primaryColorLabel_26");
        primaryColorLabel_26->setGeometry(QRect(58, 56, 15, 15));
        sizePolicy1.setHeightForWidth(primaryColorLabel_26->sizePolicy().hasHeightForWidth());
        primaryColorLabel_26->setSizePolicy(sizePolicy1);
        primaryColorLabel_26->setMinimumSize(QSize(15, 15));
        primaryColorLabel_26->setMaximumSize(QSize(5, 5));
        QPalette palette37;
        palette37.setBrush(QPalette::ColorGroup::Active, QPalette::ColorRole::WindowText, brush);
        QBrush brush177(QColor(255, 85, 0, 255));
        brush177.setStyle(Qt::BrushStyle::SolidPattern);
        palette37.setBrush(QPalette::ColorGroup::Active, QPalette::ColorRole::Button, brush177);
        QBrush brush178(QColor(255, 170, 127, 255));
        brush178.setStyle(Qt::BrushStyle::SolidPattern);
        palette37.setBrush(QPalette::ColorGroup::Active, QPalette::ColorRole::Light, brush178);
        QBrush brush179(QColor(255, 127, 63, 255));
        brush179.setStyle(Qt::BrushStyle::SolidPattern);
        palette37.setBrush(QPalette::ColorGroup::Active, QPalette::ColorRole::Midlight, brush179);
        QBrush brush180(QColor(127, 42, 0, 255));
        brush180.setStyle(Qt::BrushStyle::SolidPattern);
        palette37.setBrush(QPalette::ColorGroup::Active, QPalette::ColorRole::Dark, brush180);
        QBrush brush181(QColor(170, 56, 0, 255));
        brush181.setStyle(Qt::BrushStyle::SolidPattern);
        palette37.setBrush(QPalette::ColorGroup::Active, QPalette::ColorRole::Mid, brush181);
        palette37.setBrush(QPalette::ColorGroup::Active, QPalette::ColorRole::Text, brush);
        palette37.setBrush(QPalette::ColorGroup::Active, QPalette::ColorRole::BrightText, brush6);
        palette37.setBrush(QPalette::ColorGroup::Active, QPalette::ColorRole::ButtonText, brush);
        palette37.setBrush(QPalette::ColorGroup::Active, QPalette::ColorRole::Base, brush6);
        palette37.setBrush(QPalette::ColorGroup::Active, QPalette::ColorRole::Window, brush177);
        palette37.setBrush(QPalette::ColorGroup::Active, QPalette::ColorRole::Shadow, brush);
        palette37.setBrush(QPalette::ColorGroup::Active, QPalette::ColorRole::AlternateBase, brush178);
        palette37.setBrush(QPalette::ColorGroup::Active, QPalette::ColorRole::ToolTipBase, brush7);
        palette37.setBrush(QPalette::ColorGroup::Active, QPalette::ColorRole::ToolTipText, brush);
        palette37.setBrush(QPalette::ColorGroup::Inactive, QPalette::ColorRole::WindowText, brush);
        palette37.setBrush(QPalette::ColorGroup::Inactive, QPalette::ColorRole::Button, brush177);
        palette37.setBrush(QPalette::ColorGroup::Inactive, QPalette::ColorRole::Light, brush178);
        palette37.setBrush(QPalette::ColorGroup::Inactive, QPalette::ColorRole::Midlight, brush179);
        palette37.setBrush(QPalette::ColorGroup::Inactive, QPalette::ColorRole::Dark, brush180);
        palette37.setBrush(QPalette::ColorGroup::Inactive, QPalette::ColorRole::Mid, brush181);
        palette37.setBrush(QPalette::ColorGroup::Inactive, QPalette::ColorRole::Text, brush);
        palette37.setBrush(QPalette::ColorGroup::Inactive, QPalette::ColorRole::BrightText, brush6);
        palette37.setBrush(QPalette::ColorGroup::Inactive, QPalette::ColorRole::ButtonText, brush);
        palette37.setBrush(QPalette::ColorGroup::Inactive, QPalette::ColorRole::Base, brush6);
        palette37.setBrush(QPalette::ColorGroup::Inactive, QPalette::ColorRole::Window, brush177);
        palette37.setBrush(QPalette::ColorGroup::Inactive, QPalette::ColorRole::Shadow, brush);
        palette37.setBrush(QPalette::ColorGroup::Inactive, QPalette::ColorRole::AlternateBase, brush178);
        palette37.setBrush(QPalette::ColorGroup::Inactive, QPalette::ColorRole::ToolTipBase, brush7);
        palette37.setBrush(QPalette::ColorGroup::Inactive, QPalette::ColorRole::ToolTipText, brush);
        palette37.setBrush(QPalette::ColorGroup::Disabled, QPalette::ColorRole::WindowText, brush180);
        palette37.setBrush(QPalette::ColorGroup::Disabled, QPalette::ColorRole::Button, brush177);
        palette37.setBrush(QPalette::ColorGroup::Disabled, QPalette::ColorRole::Light, brush178);
        palette37.setBrush(QPalette::ColorGroup::Disabled, QPalette::ColorRole::Midlight, brush179);
        palette37.setBrush(QPalette::ColorGroup::Disabled, QPalette::ColorRole::Dark, brush180);
        palette37.setBrush(QPalette::ColorGroup::Disabled, QPalette::ColorRole::Mid, brush181);
        palette37.setBrush(QPalette::ColorGroup::Disabled, QPalette::ColorRole::Text, brush180);
        palette37.setBrush(QPalette::ColorGroup::Disabled, QPalette::ColorRole::BrightText, brush6);
        palette37.setBrush(QPalette::ColorGroup::Disabled, QPalette::ColorRole::ButtonText, brush180);
        palette37.setBrush(QPalette::ColorGroup::Disabled, QPalette::ColorRole::Base, brush177);
        palette37.setBrush(QPalette::ColorGroup::Disabled, QPalette::ColorRole::Window, brush177);
        palette37.setBrush(QPalette::ColorGroup::Disabled, QPalette::ColorRole::Shadow, brush);
        palette37.setBrush(QPalette::ColorGroup::Disabled, QPalette::ColorRole::AlternateBase, brush177);
        palette37.setBrush(QPalette::ColorGroup::Disabled, QPalette::ColorRole::ToolTipBase, brush7);
        palette37.setBrush(QPalette::ColorGroup::Disabled, QPalette::ColorRole::ToolTipText, brush);
        primaryColorLabel_26->setPalette(palette37);
        primaryColorLabel_26->setAutoFillBackground(true);
        primaryColorLabel_26->setFrameShape(QFrame::Panel);
        primaryColorLabel_26->setFrameShadow(QFrame::Plain);
        primaryColorLabel_26->setLineWidth(0);
        primaryColorLabel_4 = new QLabel(page);
        primaryColorLabel_4->setObjectName("primaryColorLabel_4");
        primaryColorLabel_4->setGeometry(QRect(58, 8, 15, 15));
        sizePolicy1.setHeightForWidth(primaryColorLabel_4->sizePolicy().hasHeightForWidth());
        primaryColorLabel_4->setSizePolicy(sizePolicy1);
        primaryColorLabel_4->setMinimumSize(QSize(15, 15));
        primaryColorLabel_4->setMaximumSize(QSize(5, 5));
        QPalette palette38;
        palette38.setBrush(QPalette::ColorGroup::Active, QPalette::ColorRole::WindowText, brush);
        QBrush brush182(QColor(170, 85, 0, 255));
        brush182.setStyle(Qt::BrushStyle::SolidPattern);
        palette38.setBrush(QPalette::ColorGroup::Active, QPalette::ColorRole::Button, brush182);
        QBrush brush183(QColor(255, 128, 0, 255));
        brush183.setStyle(Qt::BrushStyle::SolidPattern);
        palette38.setBrush(QPalette::ColorGroup::Active, QPalette::ColorRole::Light, brush183);
        QBrush brush184(QColor(212, 106, 0, 255));
        brush184.setStyle(Qt::BrushStyle::SolidPattern);
        palette38.setBrush(QPalette::ColorGroup::Active, QPalette::ColorRole::Midlight, brush184);
        QBrush brush185(QColor(85, 42, 0, 255));
        brush185.setStyle(Qt::BrushStyle::SolidPattern);
        palette38.setBrush(QPalette::ColorGroup::Active, QPalette::ColorRole::Dark, brush185);
        QBrush brush186(QColor(113, 56, 0, 255));
        brush186.setStyle(Qt::BrushStyle::SolidPattern);
        palette38.setBrush(QPalette::ColorGroup::Active, QPalette::ColorRole::Mid, brush186);
        palette38.setBrush(QPalette::ColorGroup::Active, QPalette::ColorRole::Text, brush);
        palette38.setBrush(QPalette::ColorGroup::Active, QPalette::ColorRole::BrightText, brush6);
        palette38.setBrush(QPalette::ColorGroup::Active, QPalette::ColorRole::ButtonText, brush);
        palette38.setBrush(QPalette::ColorGroup::Active, QPalette::ColorRole::Base, brush6);
        palette38.setBrush(QPalette::ColorGroup::Active, QPalette::ColorRole::Window, brush182);
        palette38.setBrush(QPalette::ColorGroup::Active, QPalette::ColorRole::Shadow, brush);
        QBrush brush187(QColor(212, 170, 127, 255));
        brush187.setStyle(Qt::BrushStyle::SolidPattern);
        palette38.setBrush(QPalette::ColorGroup::Active, QPalette::ColorRole::AlternateBase, brush187);
        palette38.setBrush(QPalette::ColorGroup::Active, QPalette::ColorRole::ToolTipBase, brush7);
        palette38.setBrush(QPalette::ColorGroup::Active, QPalette::ColorRole::ToolTipText, brush);
        palette38.setBrush(QPalette::ColorGroup::Inactive, QPalette::ColorRole::WindowText, brush);
        palette38.setBrush(QPalette::ColorGroup::Inactive, QPalette::ColorRole::Button, brush182);
        palette38.setBrush(QPalette::ColorGroup::Inactive, QPalette::ColorRole::Light, brush183);
        palette38.setBrush(QPalette::ColorGroup::Inactive, QPalette::ColorRole::Midlight, brush184);
        palette38.setBrush(QPalette::ColorGroup::Inactive, QPalette::ColorRole::Dark, brush185);
        palette38.setBrush(QPalette::ColorGroup::Inactive, QPalette::ColorRole::Mid, brush186);
        palette38.setBrush(QPalette::ColorGroup::Inactive, QPalette::ColorRole::Text, brush);
        palette38.setBrush(QPalette::ColorGroup::Inactive, QPalette::ColorRole::BrightText, brush6);
        palette38.setBrush(QPalette::ColorGroup::Inactive, QPalette::ColorRole::ButtonText, brush);
        palette38.setBrush(QPalette::ColorGroup::Inactive, QPalette::ColorRole::Base, brush6);
        palette38.setBrush(QPalette::ColorGroup::Inactive, QPalette::ColorRole::Window, brush182);
        palette38.setBrush(QPalette::ColorGroup::Inactive, QPalette::ColorRole::Shadow, brush);
        palette38.setBrush(QPalette::ColorGroup::Inactive, QPalette::ColorRole::AlternateBase, brush187);
        palette38.setBrush(QPalette::ColorGroup::Inactive, QPalette::ColorRole::ToolTipBase, brush7);
        palette38.setBrush(QPalette::ColorGroup::Inactive, QPalette::ColorRole::ToolTipText, brush);
        palette38.setBrush(QPalette::ColorGroup::Disabled, QPalette::ColorRole::WindowText, brush185);
        palette38.setBrush(QPalette::ColorGroup::Disabled, QPalette::ColorRole::Button, brush182);
        palette38.setBrush(QPalette::ColorGroup::Disabled, QPalette::ColorRole::Light, brush183);
        palette38.setBrush(QPalette::ColorGroup::Disabled, QPalette::ColorRole::Midlight, brush184);
        palette38.setBrush(QPalette::ColorGroup::Disabled, QPalette::ColorRole::Dark, brush185);
        palette38.setBrush(QPalette::ColorGroup::Disabled, QPalette::ColorRole::Mid, brush186);
        palette38.setBrush(QPalette::ColorGroup::Disabled, QPalette::ColorRole::Text, brush185);
        palette38.setBrush(QPalette::ColorGroup::Disabled, QPalette::ColorRole::BrightText, brush6);
        palette38.setBrush(QPalette::ColorGroup::Disabled, QPalette::ColorRole::ButtonText, brush185);
        palette38.setBrush(QPalette::ColorGroup::Disabled, QPalette::ColorRole::Base, brush182);
        palette38.setBrush(QPalette::ColorGroup::Disabled, QPalette::ColorRole::Window, brush182);
        palette38.setBrush(QPalette::ColorGroup::Disabled, QPalette::ColorRole::Shadow, brush);
        palette38.setBrush(QPalette::ColorGroup::Disabled, QPalette::ColorRole::AlternateBase, brush182);
        palette38.setBrush(QPalette::ColorGroup::Disabled, QPalette::ColorRole::ToolTipBase, brush7);
        palette38.setBrush(QPalette::ColorGroup::Disabled, QPalette::ColorRole::ToolTipText, brush);
        primaryColorLabel_4->setPalette(palette38);
        primaryColorLabel_4->setAutoFillBackground(true);
        primaryColorLabel_4->setFrameShape(QFrame::Panel);
        primaryColorLabel_4->setFrameShadow(QFrame::Plain);
        primaryColorLabel_4->setLineWidth(0);
        primaryColorLabel_8 = new QLabel(page);
        primaryColorLabel_8->setObjectName("primaryColorLabel_8");
        primaryColorLabel_8->setGeometry(QRect(74, 8, 15, 15));
        sizePolicy1.setHeightForWidth(primaryColorLabel_8->sizePolicy().hasHeightForWidth());
        primaryColorLabel_8->setSizePolicy(sizePolicy1);
        primaryColorLabel_8->setMinimumSize(QSize(15, 15));
        primaryColorLabel_8->setMaximumSize(QSize(5, 5));
        QPalette palette39;
        palette39.setBrush(QPalette::ColorGroup::Active, QPalette::ColorRole::WindowText, brush);
        palette39.setBrush(QPalette::ColorGroup::Active, QPalette::ColorRole::Button, brush43);
        palette39.setBrush(QPalette::ColorGroup::Active, QPalette::ColorRole::Light, brush39);
        QBrush brush188(QColor(0, 212, 0, 255));
        brush188.setStyle(Qt::BrushStyle::SolidPattern);
        palette39.setBrush(QPalette::ColorGroup::Active, QPalette::ColorRole::Midlight, brush188);
        palette39.setBrush(QPalette::ColorGroup::Active, QPalette::ColorRole::Dark, brush123);
        QBrush brush189(QColor(0, 113, 0, 255));
        brush189.setStyle(Qt::BrushStyle::SolidPattern);
        palette39.setBrush(QPalette::ColorGroup::Active, QPalette::ColorRole::Mid, brush189);
        palette39.setBrush(QPalette::ColorGroup::Active, QPalette::ColorRole::Text, brush);
        palette39.setBrush(QPalette::ColorGroup::Active, QPalette::ColorRole::BrightText, brush6);
        palette39.setBrush(QPalette::ColorGroup::Active, QPalette::ColorRole::ButtonText, brush);
        palette39.setBrush(QPalette::ColorGroup::Active, QPalette::ColorRole::Base, brush6);
        palette39.setBrush(QPalette::ColorGroup::Active, QPalette::ColorRole::Window, brush43);
        palette39.setBrush(QPalette::ColorGroup::Active, QPalette::ColorRole::Shadow, brush);
        QBrush brush190(QColor(127, 212, 127, 255));
        brush190.setStyle(Qt::BrushStyle::SolidPattern);
        palette39.setBrush(QPalette::ColorGroup::Active, QPalette::ColorRole::AlternateBase, brush190);
        palette39.setBrush(QPalette::ColorGroup::Active, QPalette::ColorRole::ToolTipBase, brush7);
        palette39.setBrush(QPalette::ColorGroup::Active, QPalette::ColorRole::ToolTipText, brush);
        palette39.setBrush(QPalette::ColorGroup::Inactive, QPalette::ColorRole::WindowText, brush);
        palette39.setBrush(QPalette::ColorGroup::Inactive, QPalette::ColorRole::Button, brush43);
        palette39.setBrush(QPalette::ColorGroup::Inactive, QPalette::ColorRole::Light, brush39);
        palette39.setBrush(QPalette::ColorGroup::Inactive, QPalette::ColorRole::Midlight, brush188);
        palette39.setBrush(QPalette::ColorGroup::Inactive, QPalette::ColorRole::Dark, brush123);
        palette39.setBrush(QPalette::ColorGroup::Inactive, QPalette::ColorRole::Mid, brush189);
        palette39.setBrush(QPalette::ColorGroup::Inactive, QPalette::ColorRole::Text, brush);
        palette39.setBrush(QPalette::ColorGroup::Inactive, QPalette::ColorRole::BrightText, brush6);
        palette39.setBrush(QPalette::ColorGroup::Inactive, QPalette::ColorRole::ButtonText, brush);
        palette39.setBrush(QPalette::ColorGroup::Inactive, QPalette::ColorRole::Base, brush6);
        palette39.setBrush(QPalette::ColorGroup::Inactive, QPalette::ColorRole::Window, brush43);
        palette39.setBrush(QPalette::ColorGroup::Inactive, QPalette::ColorRole::Shadow, brush);
        palette39.setBrush(QPalette::ColorGroup::Inactive, QPalette::ColorRole::AlternateBase, brush190);
        palette39.setBrush(QPalette::ColorGroup::Inactive, QPalette::ColorRole::ToolTipBase, brush7);
        palette39.setBrush(QPalette::ColorGroup::Inactive, QPalette::ColorRole::ToolTipText, brush);
        palette39.setBrush(QPalette::ColorGroup::Disabled, QPalette::ColorRole::WindowText, brush123);
        palette39.setBrush(QPalette::ColorGroup::Disabled, QPalette::ColorRole::Button, brush43);
        palette39.setBrush(QPalette::ColorGroup::Disabled, QPalette::ColorRole::Light, brush39);
        palette39.setBrush(QPalette::ColorGroup::Disabled, QPalette::ColorRole::Midlight, brush188);
        palette39.setBrush(QPalette::ColorGroup::Disabled, QPalette::ColorRole::Dark, brush123);
        palette39.setBrush(QPalette::ColorGroup::Disabled, QPalette::ColorRole::Mid, brush189);
        palette39.setBrush(QPalette::ColorGroup::Disabled, QPalette::ColorRole::Text, brush123);
        palette39.setBrush(QPalette::ColorGroup::Disabled, QPalette::ColorRole::BrightText, brush6);
        palette39.setBrush(QPalette::ColorGroup::Disabled, QPalette::ColorRole::ButtonText, brush123);
        palette39.setBrush(QPalette::ColorGroup::Disabled, QPalette::ColorRole::Base, brush43);
        palette39.setBrush(QPalette::ColorGroup::Disabled, QPalette::ColorRole::Window, brush43);
        palette39.setBrush(QPalette::ColorGroup::Disabled, QPalette::ColorRole::Shadow, brush);
        palette39.setBrush(QPalette::ColorGroup::Disabled, QPalette::ColorRole::AlternateBase, brush43);
        palette39.setBrush(QPalette::ColorGroup::Disabled, QPalette::ColorRole::ToolTipBase, brush7);
        palette39.setBrush(QPalette::ColorGroup::Disabled, QPalette::ColorRole::ToolTipText, brush);
        primaryColorLabel_8->setPalette(palette39);
        primaryColorLabel_8->setAutoFillBackground(true);
        primaryColorLabel_8->setFrameShape(QFrame::Panel);
        primaryColorLabel_8->setFrameShadow(QFrame::Plain);
        primaryColorLabel_8->setLineWidth(0);
        stackedWidget->addWidget(page);
        page_2 = new QWidget();
        page_2->setObjectName("page_2");
        spectrumLabel = new QLabel(page_2);
        spectrumLabel->setObjectName("spectrumLabel");
        spectrumLabel->setGeometry(QRect(10, 8, 131, 81));
        QPalette palette40;
        palette40.setBrush(QPalette::ColorGroup::Active, QPalette::ColorRole::WindowText, brush);
        palette40.setBrush(QPalette::ColorGroup::Active, QPalette::ColorRole::Button, brush6);
        palette40.setBrush(QPalette::ColorGroup::Active, QPalette::ColorRole::Light, brush6);
        palette40.setBrush(QPalette::ColorGroup::Active, QPalette::ColorRole::Midlight, brush6);
        palette40.setBrush(QPalette::ColorGroup::Active, QPalette::ColorRole::Dark, brush59);
        palette40.setBrush(QPalette::ColorGroup::Active, QPalette::ColorRole::Mid, brush60);
        palette40.setBrush(QPalette::ColorGroup::Active, QPalette::ColorRole::Text, brush);
        palette40.setBrush(QPalette::ColorGroup::Active, QPalette::ColorRole::BrightText, brush6);
        palette40.setBrush(QPalette::ColorGroup::Active, QPalette::ColorRole::ButtonText, brush);
        palette40.setBrush(QPalette::ColorGroup::Active, QPalette::ColorRole::Base, brush6);
        palette40.setBrush(QPalette::ColorGroup::Active, QPalette::ColorRole::Window, brush6);
        palette40.setBrush(QPalette::ColorGroup::Active, QPalette::ColorRole::Shadow, brush);
        palette40.setBrush(QPalette::ColorGroup::Active, QPalette::ColorRole::AlternateBase, brush6);
        palette40.setBrush(QPalette::ColorGroup::Active, QPalette::ColorRole::ToolTipBase, brush7);
        palette40.setBrush(QPalette::ColorGroup::Active, QPalette::ColorRole::ToolTipText, brush);
        palette40.setBrush(QPalette::ColorGroup::Inactive, QPalette::ColorRole::WindowText, brush);
        palette40.setBrush(QPalette::ColorGroup::Inactive, QPalette::ColorRole::Button, brush6);
        palette40.setBrush(QPalette::ColorGroup::Inactive, QPalette::ColorRole::Light, brush6);
        palette40.setBrush(QPalette::ColorGroup::Inactive, QPalette::ColorRole::Midlight, brush6);
        palette40.setBrush(QPalette::ColorGroup::Inactive, QPalette::ColorRole::Dark, brush59);
        palette40.setBrush(QPalette::ColorGroup::Inactive, QPalette::ColorRole::Mid, brush60);
        palette40.setBrush(QPalette::ColorGroup::Inactive, QPalette::ColorRole::Text, brush);
        palette40.setBrush(QPalette::ColorGroup::Inactive, QPalette::ColorRole::BrightText, brush6);
        palette40.setBrush(QPalette::ColorGroup::Inactive, QPalette::ColorRole::ButtonText, brush);
        palette40.setBrush(QPalette::ColorGroup::Inactive, QPalette::ColorRole::Base, brush6);
        palette40.setBrush(QPalette::ColorGroup::Inactive, QPalette::ColorRole::Window, brush6);
        palette40.setBrush(QPalette::ColorGroup::Inactive, QPalette::ColorRole::Shadow, brush);
        palette40.setBrush(QPalette::ColorGroup::Inactive, QPalette::ColorRole::AlternateBase, brush6);
        palette40.setBrush(QPalette::ColorGroup::Inactive, QPalette::ColorRole::ToolTipBase, brush7);
        palette40.setBrush(QPalette::ColorGroup::Inactive, QPalette::ColorRole::ToolTipText, brush);
        palette40.setBrush(QPalette::ColorGroup::Disabled, QPalette::ColorRole::WindowText, brush59);
        palette40.setBrush(QPalette::ColorGroup::Disabled, QPalette::ColorRole::Button, brush6);
        palette40.setBrush(QPalette::ColorGroup::Disabled, QPalette::ColorRole::Light, brush6);
        palette40.setBrush(QPalette::ColorGroup::Disabled, QPalette::ColorRole::Midlight, brush6);
        palette40.setBrush(QPalette::ColorGroup::Disabled, QPalette::ColorRole::Dark, brush59);
        palette40.setBrush(QPalette::ColorGroup::Disabled, QPalette::ColorRole::Mid, brush60);
        palette40.setBrush(QPalette::ColorGroup::Disabled, QPalette::ColorRole::Text, brush59);
        palette40.setBrush(QPalette::ColorGroup::Disabled, QPalette::ColorRole::BrightText, brush6);
        palette40.setBrush(QPalette::ColorGroup::Disabled, QPalette::ColorRole::ButtonText, brush59);
        palette40.setBrush(QPalette::ColorGroup::Disabled, QPalette::ColorRole::Base, brush6);
        palette40.setBrush(QPalette::ColorGroup::Disabled, QPalette::ColorRole::Window, brush6);
        palette40.setBrush(QPalette::ColorGroup::Disabled, QPalette::ColorRole::Shadow, brush);
        palette40.setBrush(QPalette::ColorGroup::Disabled, QPalette::ColorRole::AlternateBase, brush6);
        palette40.setBrush(QPalette::ColorGroup::Disabled, QPalette::ColorRole::ToolTipBase, brush7);
        palette40.setBrush(QPalette::ColorGroup::Disabled, QPalette::ColorRole::ToolTipText, brush);
        spectrumLabel->setPalette(palette40);
        spectrumLabel->setAutoFillBackground(true);
        stackedWidget->addWidget(page_2);
        page_3 = new QWidget();
        page_3->setObjectName("page_3");
        bwGradientLabel = new QLabel(page_3);
        bwGradientLabel->setObjectName("bwGradientLabel");
        bwGradientLabel->setGeometry(QRect(10, 8, 131, 81));
        QPalette palette41;
        palette41.setBrush(QPalette::ColorGroup::Active, QPalette::ColorRole::WindowText, brush);
        palette41.setBrush(QPalette::ColorGroup::Active, QPalette::ColorRole::Button, brush6);
        palette41.setBrush(QPalette::ColorGroup::Active, QPalette::ColorRole::Light, brush6);
        palette41.setBrush(QPalette::ColorGroup::Active, QPalette::ColorRole::Midlight, brush6);
        palette41.setBrush(QPalette::ColorGroup::Active, QPalette::ColorRole::Dark, brush59);
        palette41.setBrush(QPalette::ColorGroup::Active, QPalette::ColorRole::Mid, brush60);
        palette41.setBrush(QPalette::ColorGroup::Active, QPalette::ColorRole::Text, brush);
        palette41.setBrush(QPalette::ColorGroup::Active, QPalette::ColorRole::BrightText, brush6);
        palette41.setBrush(QPalette::ColorGroup::Active, QPalette::ColorRole::ButtonText, brush);
        palette41.setBrush(QPalette::ColorGroup::Active, QPalette::ColorRole::Base, brush6);
        palette41.setBrush(QPalette::ColorGroup::Active, QPalette::ColorRole::Window, brush6);
        palette41.setBrush(QPalette::ColorGroup::Active, QPalette::ColorRole::Shadow, brush);
        palette41.setBrush(QPalette::ColorGroup::Active, QPalette::ColorRole::AlternateBase, brush6);
        palette41.setBrush(QPalette::ColorGroup::Active, QPalette::ColorRole::ToolTipBase, brush7);
        palette41.setBrush(QPalette::ColorGroup::Active, QPalette::ColorRole::ToolTipText, brush);
        palette41.setBrush(QPalette::ColorGroup::Inactive, QPalette::ColorRole::WindowText, brush);
        palette41.setBrush(QPalette::ColorGroup::Inactive, QPalette::ColorRole::Button, brush6);
        palette41.setBrush(QPalette::ColorGroup::Inactive, QPalette::ColorRole::Light, brush6);
        palette41.setBrush(QPalette::ColorGroup::Inactive, QPalette::ColorRole::Midlight, brush6);
        palette41.setBrush(QPalette::ColorGroup::Inactive, QPalette::ColorRole::Dark, brush59);
        palette41.setBrush(QPalette::ColorGroup::Inactive, QPalette::ColorRole::Mid, brush60);
        palette41.setBrush(QPalette::ColorGroup::Inactive, QPalette::ColorRole::Text, brush);
        palette41.setBrush(QPalette::ColorGroup::Inactive, QPalette::ColorRole::BrightText, brush6);
        palette41.setBrush(QPalette::ColorGroup::Inactive, QPalette::ColorRole::ButtonText, brush);
        palette41.setBrush(QPalette::ColorGroup::Inactive, QPalette::ColorRole::Base, brush6);
        palette41.setBrush(QPalette::ColorGroup::Inactive, QPalette::ColorRole::Window, brush6);
        palette41.setBrush(QPalette::ColorGroup::Inactive, QPalette::ColorRole::Shadow, brush);
        palette41.setBrush(QPalette::ColorGroup::Inactive, QPalette::ColorRole::AlternateBase, brush6);
        palette41.setBrush(QPalette::ColorGroup::Inactive, QPalette::ColorRole::ToolTipBase, brush7);
        palette41.setBrush(QPalette::ColorGroup::Inactive, QPalette::ColorRole::ToolTipText, brush);
        palette41.setBrush(QPalette::ColorGroup::Disabled, QPalette::ColorRole::WindowText, brush59);
        palette41.setBrush(QPalette::ColorGroup::Disabled, QPalette::ColorRole::Button, brush6);
        palette41.setBrush(QPalette::ColorGroup::Disabled, QPalette::ColorRole::Light, brush6);
        palette41.setBrush(QPalette::ColorGroup::Disabled, QPalette::ColorRole::Midlight, brush6);
        palette41.setBrush(QPalette::ColorGroup::Disabled, QPalette::ColorRole::Dark, brush59);
        palette41.setBrush(QPalette::ColorGroup::Disabled, QPalette::ColorRole::Mid, brush60);
        palette41.setBrush(QPalette::ColorGroup::Disabled, QPalette::ColorRole::Text, brush59);
        palette41.setBrush(QPalette::ColorGroup::Disabled, QPalette::ColorRole::BrightText, brush6);
        palette41.setBrush(QPalette::ColorGroup::Disabled, QPalette::ColorRole::ButtonText, brush59);
        palette41.setBrush(QPalette::ColorGroup::Disabled, QPalette::ColorRole::Base, brush6);
        palette41.setBrush(QPalette::ColorGroup::Disabled, QPalette::ColorRole::Window, brush6);
        palette41.setBrush(QPalette::ColorGroup::Disabled, QPalette::ColorRole::Shadow, brush);
        palette41.setBrush(QPalette::ColorGroup::Disabled, QPalette::ColorRole::AlternateBase, brush6);
        palette41.setBrush(QPalette::ColorGroup::Disabled, QPalette::ColorRole::ToolTipBase, brush7);
        palette41.setBrush(QPalette::ColorGroup::Disabled, QPalette::ColorRole::ToolTipText, brush);
        bwGradientLabel->setPalette(palette41);
        bwGradientLabel->setAutoFillBackground(true);
        stackedWidget->addWidget(page_3);
        prevPage = new QPushButton(ColorBoxWidget);
        prevPage->setObjectName("prevPage");
        prevPage->setGeometry(QRect(0, 150, 51, 23));
        nextPage = new QPushButton(ColorBoxWidget);
        nextPage->setObjectName("nextPage");
        nextPage->setGeometry(QRect(80, 150, 51, 23));
        colourManageButton = new QPushButton(ColorBoxWidget);
        colourManageButton->setObjectName("colourManageButton");
        colourManageButton->setGeometry(QRect(80, 40, 41, 25));
        QIcon icon1;
        icon1.addFile(QString::fromUtf8(":/icons/assets/icons/palettemanager.png"), QSize(), QIcon::Mode::Normal, QIcon::State::Off);
        colourManageButton->setIcon(icon1);

        retranslateUi(ColorBoxWidget);

        stackedWidget->setCurrentIndex(0);


        QMetaObject::connectSlotsByName(ColorBoxWidget);
    } // setupUi

    void retranslateUi(QWidget *ColorBoxWidget)
    {
        ColorBoxWidget->setWindowTitle(QString());
        secondaryColorLabel->setText(QString());
        primaryColorLabel->setText(QString());
        swapColorButton->setText(QString());
        primaryColorLabel_27->setText(QString());
        primaryColorLabel_21->setText(QString());
        primaryColorLabel_38->setText(QString());
        primaryColorLabel_40->setText(QString());
        primaryColorLabel_16->setText(QString());
        primaryColorLabel_12->setText(QString());
        primaryColorLabel_35->setText(QString());
        primaryColorLabel_9->setText(QString());
        primaryColorLabel_22->setText(QString());
        primaryColorLabel_13->setText(QString());
        primaryColorLabel_36->setText(QString());
        primaryColorLabel_37->setText(QString());
        primaryColorLabel_33->setText(QString());
        primaryColorLabel_3->setText(QString());
        primaryColorLabel_39->setText(QString());
        primaryColorLabel_34->setText(QString());
        primaryColorLabel_10->setText(QString());
        primaryColorLabel_7->setText(QString());
        primaryColorLabel_18->setText(QString());
        primaryColorLabel_25->setText(QString());
        primaryColorLabel_28->setText(QString());
        primaryColorLabel_29->setText(QString());
        primaryColorLabel_2->setText(QString());
        primaryColorLabel_23->setText(QString());
        primaryColorLabel_19->setText(QString());
        primaryColorLabel_5->setText(QString());
        primaryColorLabel_31->setText(QString());
        primaryColorLabel_20->setText(QString());
        primaryColorLabel_24->setText(QString());
        primaryColorLabel_32->setText(QString());
        primaryColorLabel_17->setText(QString());
        primaryColorLabel_6->setText(QString());
        primaryColorLabel_41->setText(QString());
        primaryColorLabel_30->setText(QString());
        primaryColorLabel_14->setText(QString());
        primaryColorLabel_15->setText(QString());
        primaryColorLabel_11->setText(QString());
        primaryColorLabel_26->setText(QString());
        primaryColorLabel_4->setText(QString());
        primaryColorLabel_8->setText(QString());
        spectrumLabel->setText(QString());
        bwGradientLabel->setText(QString());
        prevPage->setText(QCoreApplication::translate("ColorBoxWidget", "<", nullptr));
        nextPage->setText(QCoreApplication::translate("ColorBoxWidget", ">", nullptr));
        colourManageButton->setText(QString());
    } // retranslateUi

};

namespace Ui {
    class ColorBoxWidget: public Ui_ColorBoxWidget {};
} // namespace Ui

QT_END_NAMESPACE

#endif // UI_COLORBOXWIDGET_H
